/* Common */
(function($) {
	"use strict";

	window.BMCW = window.BMCW || {};

	$.extend(BMCW, {
		/**
		 * 版本号
		 */
		version: "1.0.0",
		/**
		 * tab遮罩
		 */
		tabMask: null,
		/**
		 * 请求基地址
		 */
		baseUrl: "http://cgappapi.banmachewu.com/api",
		bmcwBaseUrl: "http://api.banmachewu.com/bmcwapi/api",
		/*测试环境地址*/
		//baseUrl: "http://dev.banmachewu.com/cgapi/api",
		//bmcwBaseUrl: "http://dev.banmachewu.com/bmcwapi/api",
		/**
		 * 获取用户id
		 */
		getCurrentUserID: function() {
			return localStorage.getItem("CurrentUserID") || 0;
		},
		/**
		 * 设置用户id
		 * @param {Object} userId
		 */
		setCurrentUserID: function(userId) {
			var usrId = userId || 0;
			localStorage.setItem("CurrentUserID", usrId);
		},
		/**
		 * 是否字符串
		 * @param {String} value
		 */
		isString: function(value) {
			return typeof value === "string";
		},
		/**
		 * 是否数字
		 * @param {Number} value
		 */
		isNumber: function(value) {
			return typeof value === "number";
		},
		/**
		 * 是否bool类型
		 * @param {Boolean} value
		 */
		isBoolean: function(value) {
			return typeof value === "boolean";
		},
		/**
		 * 将s1的属性或方法复制到r的原型链上面
		 * @param {Function} 目标函数
		 * @param {Object} 对象数组或者对象实体
		 */
		augment: function(r, s1) {
			if(!$.isFunction(r)) {
				return r;
			}
			for(var i = 1; i < arguments.length; i++) {
				$.extend(r.prototype, arguments[i]);
			}
			return r;
		},
		/**
		 * 替换字符串中的字段   
		 * substitute('<li>{text}</li>',{text:'BMCW'}) =>  <li>BMCW</li>
		 * @param {Object} 模版字符串
		 * @param {Object} JSON对象
		 * @param {Object} 替换正则
		 */
		substitute: function(str, o, regexp) {
			if(!BMCW.isString(str) || !$.isObject(o) && !$.isArray(o)) {
				return str;
			}
			return str.replace(regexp || /\\?\{([^{}]+)\}/g, function(match, name) {
				if(match.charAt(0) === "\\") {
					return match.slice(1);
				}
				return o[name] === undefined ? "" : o[name];
			});
		},
		/**
		 * 替换字符串中的字段
		 **/
		format: function() {
			if(arguments.length == 0) {
				return "";
			}

			var str = arguments[0];
			for(var i = 1; i < arguments.length; i++) {
				var valtemp = arguments[i] === undefined ? "" : arguments[i];
				var reg = new RegExp('\\{' + (i - 1) + '\\}', 'gm');
				str = str.replace(reg, valtemp);
			}
			return str;
		},
		/**
		 * 根据id获取webview
		 * @param {string} id
		 */
		getWebviewById: function(webviewid) {
			return plus.webview.getWebviewById(webviewid);
		},
		/**
		 * 关闭指定id的窗体,不传递参数则默认关闭当前页
		 * @param {Object} webviewid
		 */
		closeWebview: function(webviewid, aniClose) {
			var wb;
			aniClose = aniClose || "auto";
			if(webviewid) {
				wb = plus.webview.getWebviewById(webviewid);
			} else {
				wb = plus.webview.currentWebview();
			}
			if(wb != null) {
				var wbp = wb.parent();
				if(wbp == null) {
					wb.close(aniClose);
				} else {
					wbp.close(aniClose);
				}
			}
		},
		/**
		 * 关闭非指定页面的所有页面(login也不关闭)
		 * @param {Object} webviewid
		 */
		closeOtherWebview: function(webviewid, typeClose) {
			var allWebviews = plus.webview.all();
			var wsLogin = plus.webview.getLaunchWebview();
			for(var i = 0; i < allWebviews.length; i++) {
				if(allWebviews[i].id == wsLogin.id || allWebviews[i].id == webviewid) {
					continue;
				} else {
					var wbp = allWebviews[i].parent();
					if(wbp == null || wbp.id != webviewid) {
						if(BMCW.isNullOrEmpty(typeClose)) {
							allWebviews[i].close();
						} else {
							allWebviews[i].close(typeClose);
						}
					}
				}
			}
		},
		/**
		 * 打开窗体
		 * @param {String} obj {url id }  必填:url id 
		 * @param {Object} options 可选:参数,等待,窗口,显示配置{params:{},waiting:{},styles:{},show:{}}
		 */
		openWindow: function(obj, options) {
			var opts = options || {};
			var dftShow = {
				duration: 200,
				aniShow: "slide-in-right" //动画效果
			};
			opts.createNew = false; //是否重复创建同样id的webview，默认为false:不重复创建，直接显示
			opts.waiting = {
				autoShow: false //自动显示等待框，默认为true
			};

			if(opts.show) {} else {
				opts.show = dftShow
			};

			opts.styles = opts.styles || {};
			opts.styles.popGesture = "close"; //窗口的侧滑返回功能
			opts.styles.scalable = false; //窗口是否可缩放
			opts.styles.scrollIndicator = "none"; //窗口是否显示滚动条
			opts.styles.backButtonAutoControl = "close";
			if(obj.titleNView) {
				opts.styles.titleNView = obj.titleNView;
			}

			var wb = $.openWindow(obj.url, obj.id, opts);
			return wb;
		},
		/**
		 * 创建当前页面的子webview styles:{top:'10px',bottom:'5px'}  top和bottom分别是上边距和下边距
		 * @param {Object} options 必填:url id 可选:参数,等待,窗口,显示配置
		 */
		appendWebview: function(options) {
			var opts = options || {};
			opts.styles = opts.styles || {
				bounce: "vertical"
			};
			if(typeof opts.styles.top !== 'string') {
				//父页面一般只有一个header和查询
				var top = document.getElementById("header").clientHeight;

				if(document.getElementById("search")) {
					top += document.getElementById("search").clientHeight;
				}
				opts.styles.top = top + "px";

			}
			if(typeof opts.styles.bottom !== 'string') {
				var bottom = 0;
				if(document.getElementById("footer")) {
					bottom += document.getElementById("footer").clientHeight;
				}
				opts.styles.bottom = bottom + "px";
			}
			opts.id = opts.id || opts.url;

			var childWebView = plus.webview.create(opts.url, opts.id, opts.styles, opts.extras || {});
			plus.webview.currentWebview().append(childWebView);
			return childWebView;
		},
		/**
		 * 重新加载url
		 * @param {Object} webviewid
		 * @param {Object} url
		 */
		reloadWebviewUrl: function(webviewid, url) {
			var view = plus.webview.getWebviewById(webviewid);
			if(view) {
				view.loadURL(url);
			}
		},
		/**
		 * 添加本地存储
		 * @param {Object} name
		 * @param {Object} val
		 */
		setLocalStorage: function(name, val) {
			localStorage.setItem(name, val);
		},
		/**
		 * 获取本地存储
		 * @param {Object} name
		 */
		getLocalStorage: function(name) {
			return localStorage.getItem(name);
		},
		/**
		 * 删除本地存储
		 * @param {Object} name
		 */
		removeLocalStorage: function(name) {
			localStorage.removeItem(name);
		},
		/**
		 * 获取网络信息
		 */
		networkinfo: function() {
			var info = window.plus ? plus.networkinfo.getCurrentType() : "unknow";
			switch(info) {
				case plus.networkinfo.CONNECTION_CELL2G:
					info = "twog";
					break;
				case plus.networkinfo.CONNECTION_CELL3G:
					info = "threeg";
					break;
				case plus.networkinfo.CONNECTION_CELL4G:
					info = "fourg";
					break;
				case plus.networkinfo.CONNECTION_WIFI:
					info = "wifi";
					break;
				case plus.networkinfo.CONNECTION_ETHERNET:
					info = "wired";
					break;
				case plus.networkinfo.CONNECTION_NONE:
					info = "none";
					break;
				default:
					info = "unknow";
					break;
			}
			return info;
		},
		/**
		 * @description 格式化日期
		 * @param {Date} datetimeObj
		 * @param {string} fmt
		 * @example
		 * common.formatDate("2015-01-01","yyyy-MM-dd");
		 */
		formatDate: function(datetimeObj, fmt) { //author: meizz 
			if(BMCW.isString(datetimeObj)) {
				if(datetimeObj.length > 19) {
					datetimeObj = datetimeObj.substring(0, 19)
				}
				datetimeObj = datetimeObj.replace('T', ' ').replace(/-/g, '/'); //ios不支持yyyy-MM-dd
				var ms = Date.parse(datetimeObj);
				datetimeObj = new Date(ms);
			}

			var o = {
				"M+": datetimeObj.getMonth() + 1, //月份 
				"d+": datetimeObj.getDate(), //日 
				"h+": datetimeObj.getHours() % 12 == 0 ? 12 : datetimeObj.getHours() % 12, //12进制小时 
				"H+": datetimeObj.getHours(), //24进制小时 
				"m+": datetimeObj.getMinutes(), //分 
				"s+": datetimeObj.getSeconds(), //秒 
				"q+": Math.floor((datetimeObj.getMonth() + 3) / 3), //季度 
				"S": datetimeObj.getMilliseconds() //毫秒 
			};
			if(/(y+)/.test(fmt)) fmt = fmt.replace(RegExp.$1, (datetimeObj.getFullYear() + "").substr(4 - RegExp.$1.length));
			for(var k in o)
				if(new RegExp("(" + k + ")").test(fmt)) fmt = fmt.replace(RegExp.$1, (RegExp.$1.length == 1) ? (o[k]) : (("00" + o[k]).substr(("" + o[k]).length)));
			return fmt;
		},
		/**
		 * 将字符串转化为时间
		 * @param {Object} datestr
		 */
		convertToDate: function(datestr) {
			if(BMCW.isString(datestr)) {
				if(datestr.length > 19) {
					datestr = datestr.substring(0, 19)
				}
				datestr = datestr.replace('T', ' ').replace(/-/g, '/'); //ios不支持yyyy-MM-dd
				var ms = Date.parse(datestr);
				datestr = new Date(ms);
			}
			return datestr;
		},
		/**
		 * 截取字符串,超过固定长度则用省略号代替
		 * @param {string} str 截取字符串
		 * @param {int} maxLen 最大长度
		 **/
		replaceString: function(str, maxLen) {
			if(str.length > maxLen) {
				return str.toString().substr(0, maxLen) + "...";
			}
			return str;
		},
		/**
		 * 将数值添加千分符
		 * @param {Number} num
		 **/
		formatNumber: function(num) {
			var frt = new Number(num);
			frt = frt.toFixed(2) + "";
			var re = /(\d{1,3})(?=(\d{3})+(?:$|\.))/g;
			return frt.replace(re, "$1,");
		},
		/**
		 * 将手机号格式化
		 * @param {string} mobile|手机号
		 **/
		formatTel: function(mobile) {
			var re = /(\d{3})(\d{4})(\d{4})/g;
			return mobile.replace(re, "$1-$2-$3");
		},
		/**
		 * 隐藏手机中间4位
		 * @param {Object} mobile
		 */
		hideTel: function(mobile) {
			if(mobile) {
				var m = mobile.replace(/-/g, '');
				return m.substring(0, 3) + "****" + m.substring(7);
			}
			return "";
		},
		/**
		 * 隐藏身份证
		 * @param {Object} IdCode
		 */
		hideIdentityCode: function(IdCode) {
			if(IdCode) {
				var m = IdCode.replace(/-/g, '');
				return m.substring(0, 3) + "****" + m.substring(14);
			}
			return "";
		},
		/**
		 * @description 打电话
		 * @param {string} Mobile 电话号码
		 **/
		gotoMobile: function(Mobile, event) {
			event = event || window.event;
			if(event) {
				if(document.all) {
					event.cancelBubble = true;
				} else {
					event.stopPropagation();
				}
			}
			window.location.href = "tel:" + Mobile;
		},
		/**
		 * @description 判断是否为空
		 * @param {string} str
		 * @return {Boolean} true:是 false:否
		 * */
		isNullOrEmpty: function(str) {
			if(str) {
				str = str.toString().replace(/^\s+|\s+$/g, '');
				if(str == "null" || str == "") {
					return true;
				} else {
					return false;
				}
			} else {
				return true;
			}
		},
		/**
		 * 去掉空格
		 * @param {Object} str
		 */
		trim: function(str) {
			if(str) {
				str = str.toString().replace(/^\s+|\s+$/g, '');
				return str;
			}
			return "";
		},
		/**
		 * 判断是否为手机电话
		 * @param {Object} mobile
		 */
		isMobile: function(mobile) {
			var re = /^1[3456789]\d{9}$/;
			return re.test(mobile);
		},
		/**
		 * 判断是否正确的身份证号
		 * @param {Object} str
		 */
		isIdentityCode: function(str) {
			var reg = /(^[1-9]\d{5}(18|19|([23]\d))\d{2}((0[1-9])|(10|11|12))(([0-2][1-9])|10|20|30|31)\d{3}[0-9Xx]$)|(^[1-9]\d{5}\d{2}((0[1-9])|(10|11|12))(([0-2][1-9])|10|20|30|31)\d{2}[0-9Xx]$)/;
			return reg.test(str);
		},
		/**
		 * 判断是否包含汉字
		 * @param {Object} str
		 */
		isChinese: function(str) {
			var reg = new RegExp("[\\u4E00-\\u9FFF]+", "g");
			return reg.test(str);
		},
		/**
		 * 判断是否为价格
		 * @param {Object} num
		 */
		isPrice: function(num) {
			var reg = /^[1-9][0-9]*(\.[0-9]{1,2})?$/;
			return reg.test(num);
		},
		/**
		 * 确认弹框
		 * @param {String} 提示对话框上显示的内容
		 * @param {String} 提示对话框上显示的标题
		 * @param {Array} 提示对话框上按钮显示的内容
		 * @param {Function} 提示对话框上关闭后的回调函数
		 * @param {String} 是否使用h5绘制的对话框 默认div
		 */
		confirm: function(msg, title, btnArray, callback, type) {
			if(BMCW.isNullOrEmpty(title)) {
				title = '<img src="images/bjcg-icon-tip.jpg" alt=""/>';
			}
			if(BMCW.isNullOrEmpty(btnArray)) {
				btnArray = ['取消', '确认'];
			}
			mui.confirm(msg, title, btnArray, callback, "div");
		},
		/**
		 * alert提示
		 * @param {String} 提示对话框上显示的内容
		 * @param {String} 提示对话框上显示的标题
		 * @param {String} 提示对话框上按钮显示的内容
		 * @param {Function} 提示对话框上关闭后的回调函数
		 * @param {String} 是否使用h5绘制的对话框
		 */
		alert: function(msg, title, btnValue, callback, type) {
			if(BMCW.isNullOrEmpty(msg)) {
				return false;
			}
			if(BMCW.isNullOrEmpty(title)) {
				title = "提示";
			}
			if(BMCW.isNullOrEmpty(btnValue)) {
				btnValue = "确定";
			}
			if(callback) {
				if(!$.isFunction(callback)) {
					callback = function() {};
				}
			} else {
				callback = function() {};
			}
			mui.alert(msg, title, btnValue, callback, "div");
		},
		/**
		 * 自动消失弹框
		 * @param {Object} msg
		 * @param {Object} opts
		 */
		toast: function(msg, opts) {
			plus.nativeUI.toast(msg, opts);
		},
		/**
		 * 下来刷新-單個webview
		 * @param {Object} onRefresh
		 */
		setCirclePullToRefresh: function(onRefresh) {
			//检查网络是否可用
			var netInfo = BMCW.networkinfo();
			if(netInfo == "none") {
				plus.nativeUI.alert("网络不可用，请检测网络", null, '提示');
				return false;
			}

			var ws = plus.webview.currentWebview();

			function innerRefresh() {
				onRefresh();
				ws.endPullToRefresh();
			}

			ws.setPullToRefresh({
				support: true,
				color: "#3c67c2",
				style: "circle",
				offset: "5px"
			}, innerRefresh);
		},
		/**
		 * 计算总页数
		 */
		getPageCount: function(recordCount, pageSize) {
			var pageCount = 0;
			if(recordCount > 0) {
				pageCount = (recordCount % pageSize) == 0 ? (recordCount / pageSize) : parseInt(recordCount / pageSize + 1);
			}
			return pageCount;
		},
		/**
		 * 添加loading
		 * @param {Object} msg
		 */
		showLoading: function(msg) {
			var msg = msg || ""
			var elem = document.createElement("div");
			elem.classList.add("bjcg-loading");
			elem.classList.add("mui-content");
			elem.innerHTML = '<div class="container"><div class="container-box"></div><div class="run-box"><div class="run-loader"></div></div><p>' + msg + '</p></div>'
			document.body.appendChild(elem);
			var load = {};
			load.remove = function() {
				var body = document.body;
				elem.parentNode === body && body.removeChild(elem);
			}
			return load;
		},
		/**
		 * 验证是否认证
		 */
		checkUserAuth: function() {
			var usertype = BMCW.getLocalStorage("CurrentUserType");
			if(usertype == 2) { //用户类型为代办,则判断是否认证
				var usrLevel = BMCW.getLocalStorage("UserLevel");
				if(usrLevel >= 1) {
					return true;
				} else {
					return false;
				}
			}
			return true;
		},
		/**
		 * 验证是否交押金
		 */
		checkUserPay: function() {
			var usertype = BMCW.getLocalStorage("CurrentUserType");
			if(usertype == 2) { //用户类型为代办,则判断是否认证
				var usrLevel = BMCW.getLocalStorage("UserLevel");
				if(usrLevel >= 2) {
					return true;
				} else {
					return false;
				}
			}
			return false;
		},
		/**
		 * 添加tab遮罩层
		 */
		addTabMask: function() {
			if(BMCW.tabMask == null) {
				BMCW.tabMask = new plus.nativeObj.View('Mask', {
					bottom: '0px',
					left: '0px',
					height: '63px',
					width: '100%',
					backgroundColor: '#000000',
					opacity: 0.5
				});
				BMCW.tabMask.show();
			}
			return BMCW.tabMask;
		},
		/**
		 * 删除tab遮罩
		 */
		removeTabMask: function() {
			if(BMCW.tabMask) {
				BMCW.tabMask.close();
				BMCW.tabMask = null;
			}
		},		
		/**
		 * @description 获取当前配置 baidu
		 * @param {Function} callback:维度,经度
		 **/
		getCurrentPosition: function(callback) {
			plus.geolocation.getCurrentPosition(function(p) {
				if(callback) {
					callback(p.address);
				}
			}, function(e) {
				BMCW.getSysCurrentPosition(callback);
			}, {
				provider: "baidu",
				enableHighAccuracy: true
			});
		},
		/**
		 * @description 获取当前配置 system
		 * @param {Function} callback:维度,经度
		 **/
		getSysCurrentPosition: function(callback) {
			plus.geolocation.getCurrentPosition(function(p) {
				if(callback) {
					callback(p.address);
				}
			}, function(e) {

				var info = "错误信息：code-" + e.code + " message-" + e.message;

				var msg = "获取位置失败,请确认是否开启位置服务.";
				msg += "\r\n错误原因：" + e.message + "(" + e.code + ")";

				plus.nativeUI.alert(msg, function() {
					var apperrorUrl = BMCW.baseUrl + "/Common/AddErrLog";
					var options = {
						url: apperrorUrl,
						data: {
							tk: BMCW.getLocalStorage('UserToken'),
							msg: info
						},
						type: "POST",
						showLoading: false,
						success: function(result) {},
						error: function(date) {}
					};
					BMCW.Ajax.ajax(options);
				}, "定位失败", "确定");

			}, {
				provider: "system",
				enableHighAccuracy: true
			});
		}
	});
})(mui);

/* Ajax */
(function($, BMCW) {
	"use strict";

	var h5Ajax = {
		isPost: false,
		postUrl: "",
		/**
		 * @description ajax请求
		 * @param {Object} ajaxOptions
		 * {
		 *   url:{String} 请求地址
		 * 	 type:{String} POST | GET 方法
		 *   dateType:{String} json | xml 数据类型
		 *   data:{Object}  返回数据
		 *   version:{String} v1.3.7  版本号
		 *   success:{Function}function(result){} 正确处理函数
		 *   error:{Function}function(errMsg){} 错误处理函数
		 *   errMsg:{String}  错误信息
		 *   showLoading:{Bool}  是否显示loading...
		 *   loadingMsg:{String} 请求提示语
		 * }
		 */
		ajax: function(ajaxOptions) {
			var headers = {},
				isLoading = false,
				loadElem;
			var fullUrl = BMCW.baseUrl + ajaxOptions.url;
			if(ajaxOptions.useBmcw) {
				fullUrl = BMCW.bmcwBaseUrl + ajaxOptions.url;
			}
			var setHeader = function(name, value) {
				headers[name.toLowerCase()] = [name, value];
			};
			if(ajaxOptions.headers) {
				for(var name in ajaxOptions.headers) setHeader(name, ajaxOptions.headers[name]);
			}

			//检查网络是否可用
			var netInfo = BMCW.networkinfo();
			if(netInfo == "none") {
				BMCW.toast("网络不可用，请检测网络");
				return false;
			}

			//判断url非空
			if(BMCW.isNullOrEmpty(ajaxOptions.url)) {
				BMCW.toast("网络不可用，请检测网络");
				return false;
			}

			//判断type非空
			if(ajaxOptions.type) {
				ajaxOptions.type = ajaxOptions.type.toUpperCase();
			} else {
				ajaxOptions.type = "GET";
			}
			if(ajaxOptions.type == "POST") {
				//防止双击请求多次
				if(h5Ajax.isPost) {
					if(h5Ajax.postUrl == ajaxOptions.url) {
						return false;
					}
				}
				h5Ajax.isPost = true;
				h5Ajax.postUrl = ajaxOptions.url;

			} else {
				if(ajaxOptions.data) {
					var qurl = [];
					for(var k in ajaxOptions.data) {
						qurl.push(k + "=" + encodeURIComponent(ajaxOptions.data[k]));
					}
					fullUrl = fullUrl + "?" + qurl.join("&");
				}
			}

			//默认返回值类型
			if(BMCW.isNullOrEmpty(ajaxOptions.dateType)) {
				ajaxOptions.dateType = "json";
			}

			//默认添加loading效果
			if(ajaxOptions.showLoading !== false) {
				ajaxOptions.showLoading = true;
			}

			//请求提示信息
			var loading = "加载中...";
			if(ajaxOptions.loadingMsg) {
				loading = ajaxOptions.loadingMsg;
			}

			if(ajaxOptions.showLoading) {
				isLoading = true;
				plus.nativeUI.showWaiting(loading, {
					textalign: "right",
					background: "#666666"
				});
			}

			//统一添加headr
			var headers = getCommonHeader();
			for(var k in headers) {
				setHeader(k, headers[k]);
			}

			//请求头添加
			if(ajaxOptions.dateType == "xml") {
				setHeader("Content-Type", "text/xml");
			} else {
				setHeader("Content-Type", "application/json;charset=UTF-8");
			}

			//认证权限信息
			setHeader("Authorization", "BMCW " + getUserToken(fullUrl));

			function closeX(xhr1) {
				xhr1.abort();
				xhr1 = null;
			}

			//自动设置关闭post状态
			setTimeout(function() {
				h5Ajax.isPost = false;
				h5Ajax.postUrl = "";
			}, 1000)

			//自动关闭loading
			setTimeout(function() {
				if(isLoading) {
					plus.nativeUI.closeWaiting();
					isLoading = false;
				}
			}, 10000);

			var xhr1 = new plus.net.XMLHttpRequest();
			var nativeSetHeader = xhr1.setRequestHeader;
			xhr1.setRequestHeader = setHeader;
			xhr1.onreadystatechange = function() {
				switch(xhr1.readyState) {
					case 2:
						break;
					case 4:
						if(ajaxOptions.showLoading) {
							if(isLoading) {
								plus.nativeUI.closeWaiting();
								//loadElem.remove();
								isLoading = false;
							}
						}
						if(xhr1.status == 200) {
							if(ajaxOptions.dateType == "json") {
								//如果返回值json,统一转换成对象，调用success方法
								var result = "";

								try {
									if(BMCW.isNullOrEmpty(xhr1.responseText)) {
										result = "";
									} else {
										result = JSON.parse(xhr1.responseText.replace(/[\r\n]/g, ""));
									}
								} catch(e) {
									throw new Error("转换JSON报错，URL:" + ajaxOptions.url + ",JSON字符串：" + xhr1.responseText + "报错原因：" + e.stack)
								}

								if(ajaxOptions.success) {
									ajaxOptions.success.call(ajaxOptions, result);
								}
							} else {
								//如果返回值是xml，直接返回
								if(ajaxOptions.success) {
									ajaxOptions.success.call(ajaxOptions, xhr1.responseXML);
								}
							}

						} else {

							// 登录已失效
							if(xhr1.status == 401) {
								// 跳转到首页，并调登录权限验证方法
								var wsLogin = plus.webview.getLaunchWebview()
								wsLogin.show();
							} else {
								if(ajaxOptions.error) {
									ajaxOptions.error.call(ajaxOptions, xhr1.responseText);
								} else {
									var msg = ajaxOptions.errMsg || xhr1.responseText;
									plus.nativeUI.alert(msg, null, '提示');
								}
							}
						}

						closeX(xhr1);
						break;
				}
			}
			xhr1.open(ajaxOptions.type, fullUrl);
			for(var name in headers) {
				nativeSetHeader.apply(xhr1, headers[name]);
			}
			if(ajaxOptions.type == "GET") {
				xhr1.send();
			} else {
				//如果POST并且存在方法,则数据传递
				if(ajaxOptions.data) {
					if(typeof ajaxOptions.data === "string") {
						xhr1.send(ajaxOptions.data);
					} else {
						xhr1.send(JSON.stringify(ajaxOptions.data));
					}
				} else {
					xhr1.send();
				}
			}
		}
	}

	/**
	 * @description md5验证标识
	 * @param {String} url
	 **/
	var getUserToken = function(url) {
		var result = "-99";
		try {
			var p = "cgs";
			var ms = new Date().getMilliseconds();
			if(ms < 100) {
				ms += 100;
			}
			var token;
			if(url.length > 32) {
				token = p + url.substring(8, 32) + ms;
			} else {
				token = p + url.substring(9) + ms;
			}
			if(BMCW.md5) {
				result = ms + BMCW.md5(token);
			}
		} catch(e) {
			result = "-99";
		}
		return result;
	}

	/**
	 * 获取公共的header
	 */
	var getCommonHeader = function() {
		var cltInfo = plus.push.getClientInfo();
		var data = {
			appostype: plus.os.name, //操作系统
			apposversion: plus.os.version, //系统版本
			appimei: plus.device.imei,
			appuuid: plus.device.uuid,
			appvendor: plus.device.vendor, //供应商
			appmodel: plus.device.model, //型号
			appversion: BMCW.getLocalStorage("CurrentAppVersion"), //当前版本
			apptoken: cltInfo.token, //ios推送标识
			appclientid: cltInfo.clientid, //android推送标识
			appuser: BMCW.getLocalStorage("CurrentUserID") //当前登陆人
		};
		return data;
	}

	BMCW.Ajax = h5Ajax;
})(mui, BMCW);

/* Mui Ext */
(function($, BMCW) {
	/**
	 * mui扩展单击事件
	 * @param {Object} callback
	 */
	$.fn.click = function(callback) {
		var self = this;
		for(var i = 0; i < self.length; i++) {
			self[i].addEventListener("tap", function(evt) {
				evt = evt || event;
				callback.call(evt.target, evt);
			}, false);
		}
	}

	/**
	 * mui扩展select事件
	 * @param {Object} callback
	 */
	$.fn.change = function(callback) {
		var self = this;
		for(var i = 0; i < self.length; i++) {
			self[i].addEventListener("change", function(evt) {
				evt = evt || event;
				callback.call(evt.target, evt);
			}, false);
		}
	}

	/**
	 * mui扩展赋值
	 * @param {string} value
	 */
	$.fn.val = function(value) {
		var self = this;
		for(var i = 0; i < self.length; i++) {
			if(value === undefined) {
				var val = '';
				switch(self[i].tagName.toUpperCase()) {
					case "INPUT":
					case "TEXTAREA":
						val = self[i].value;
						break;
					case "SELECT":
						for(var j = 0; j < self[i].options.length; j++) {
							if(self[i].options[j].selected) {
								val = self[i].options[j].value;
								break;
							}
						}
						break;
				}
				return val;
			} else {
				switch(self[i].tagName.toUpperCase()) {
					case "INPUT":
					case "TEXTAREA":
						self[i].value = value;
						break;
					case "SELECT":
						for(var j = 0; j < self[i].options.length; j++) {
							if(self[i].options[j].value == value) {
								self[i].options[j].selected = true;
							} else {
								self[i].options[j].selected = false;
							}
						}
						break;
				}
			}
		}
	}

	/**
	 * mui 扩展赋值
	 * @param {Object} value
	 */
	$.fn.html = function(value) {
		var self = this;
		for(var i = 0; i < self.length; i++) {
			if(value === undefined) {
				return self[i].innerHTML;
			} else {
				self[i].innerHTML = value;
			}
		}
	}

	/**
	 * mui 扩展获取焦点
	 */
	$.fn.focus = function() {
		var self = this;
		for(var i = 0; i < self.length; i++) {
			self[i].focus();
			break;
		}
	}
})(mui, BMCW);

/* BasePage */
(function($, BMCW) {
	"use strict";

	/**
	 *  页面的生命周期 init(初始化)-->initView(渲染页面)-->initEvent(绑定页面事件)-->closeView(关闭页面) 
	 * @param {Object} options
	 */
	var BasePage = function(options) {
		var self = this;
		$.plusReady(function() {
			self.init(options);
			self.initView(options);
			self.initEvent(options);
			ErrorListiner();
		});
	}

	/**
	 * 监听错误
	 */
	function ErrorListiner() {
		document.addEventListener("plusready", function() {
			// 开发环境显示错误
			if(plus.runtime.appid != "HBuilder") {
				window.onerror = function(errorMessage, scriptURI, lineNumber, columnNumber, errorObj) {
					var reg = new RegExp("html$");

					function makeSure(p) {
						return !!p ? p : "";
					}

					var info = "";
					var surl = '';
					var logTitle = plus.os.name;
					if(window.plus) {
						surl = plus.webview.currentWebview().getURL();
					}
					scriptURI = scriptURI || surl;

					//屏蔽hbuilder内置js异常
					if(reg.test(scriptURI)) {
						return false;
					}

					try {

						var info = "错误信息：" + makeSure(errorMessage) + ";" +
							"出错文件：" + makeSure(scriptURI) + ";" +
							"出错行号：" + makeSure(lineNumber) + ";" +
							"出错列号：" + makeSure(columnNumber) + ";" +
							"错误详情：" + makeSure(errorObj) + ";" +
							"系统版本：" + makeSure(plus.os.version) + ";" +
							"浏览器信息：" + navigator.userAgent + ";" +
							"APP版本:" + makeSure(plus.runtime.version) + ";" +
							"买顾标识:" + BMCW.getLocalStorage('UserToken') +
							"网络信息：" + BMCW.networkinfo() + ";";
					} catch(e) {
						info += "发生异常：" + e + ";";
					} finally {
						var apperrorUrl = BMCW.baseUrl + "/Common/AddErrLog";
						var options = {
							url: apperrorUrl,
							data: {
								tk: BMCW.getLocalStorage('UserToken'),
								msg: info
							},
							type: "POST",
							showLoading: false,
							success: function(result) {},
							error: function(date) {}
						};
						BMCW.Ajax.ajax(options);
					}

					return true;
				}
			}
		}, false);

	}

	/**
	 * 扩展BasePage
	 * 
	 */
	BMCW.augment(BasePage, {
		/**
		 * 初始化方法
		 * 页面参数初始化  页面方法初始化  等
		 * @param {Object} options
		 */
		init: function(options) {},
		/**
		 * 渲染页面
		 * 通过ajax对页面加载显示
		 * @param {Object} options
		 */
		initView: function(options) {},
		/**
		 * 绑定事件
		 * 绑定返回事件
		 * @param {Object} options
		 */
		initEvent: function(options) {

		},
		/**
		 * 关闭当前页面
		 */
		closeView: function() {}
	});

	BMCW.BasePage = BasePage;
})(mui, BMCW);

/* MD5 */
(function(n, BMCW) {
	"use strict";

	function t(n, t) {
		var r = (65535 & n) + (65535 & t),
			e = (n >> 16) + (t >> 16) + (r >> 16);
		return e << 16 | 65535 & r
	}

	function r(n, t) {
		return n << t | n >>> 32 - t
	}

	function e(n, e, o, u, c, f) {
		return t(r(t(t(e, n), t(u, f)), c), o)
	}

	function o(n, t, r, o, u, c, f) {
		return e(t & r | ~t & o, n, t, u, c, f)
	}

	function u(n, t, r, o, u, c, f) {
		return e(t & o | r & ~o, n, t, u, c, f)
	}

	function c(n, t, r, o, u, c, f) {
		return e(t ^ r ^ o, n, t, u, c, f)
	}

	function f(n, t, r, o, u, c, f) {
		return e(r ^ (t | ~o), n, t, u, c, f)
	}

	function i(n, r) {
		n[r >> 5] |= 128 << r % 32, n[(r + 64 >>> 9 << 4) + 14] = r;
		var e, i, a, h, d, l = 1732584193,
			g = -271733879,
			v = -1732584194,
			m = 271733878;
		for(e = 0; e < n.length; e += 16) i = l, a = g, h = v, d = m, l = o(l, g, v, m, n[e], 7, -680876936), m = o(m, l, g, v, n[e + 1], 12, -389564586), v = o(v, m, l, g, n[e + 2], 17, 606105819), g = o(g, v, m, l, n[e + 3], 22, -1044525330), l = o(l, g, v, m, n[e + 4], 7, -176418897), m = o(m, l, g, v, n[e + 5], 12, 1200080426), v = o(v, m, l, g, n[e + 6], 17, -1473231341), g = o(g, v, m, l, n[e + 7], 22, -45705983), l = o(l, g, v, m, n[e + 8], 7, 1770035416), m = o(m, l, g, v, n[e + 9], 12, -1958414417), v = o(v, m, l, g, n[e + 10], 17, -42063), g = o(g, v, m, l, n[e + 11], 22, -1990404162), l = o(l, g, v, m, n[e + 12], 7, 1804603682), m = o(m, l, g, v, n[e + 13], 12, -40341101), v = o(v, m, l, g, n[e + 14], 17, -1502002290), g = o(g, v, m, l, n[e + 15], 22, 1236535329), l = u(l, g, v, m, n[e + 1], 5, -165796510), m = u(m, l, g, v, n[e + 6], 9, -1069501632), v = u(v, m, l, g, n[e + 11], 14, 643717713), g = u(g, v, m, l, n[e], 20, -373897302), l = u(l, g, v, m, n[e + 5], 5, -701558691), m = u(m, l, g, v, n[e + 10], 9, 38016083), v = u(v, m, l, g, n[e + 15], 14, -660478335), g = u(g, v, m, l, n[e + 4], 20, -405537848), l = u(l, g, v, m, n[e + 9], 5, 568446438), m = u(m, l, g, v, n[e + 14], 9, -1019803690), v = u(v, m, l, g, n[e + 3], 14, -187363961), g = u(g, v, m, l, n[e + 8], 20, 1163531501), l = u(l, g, v, m, n[e + 13], 5, -1444681467), m = u(m, l, g, v, n[e + 2], 9, -51403784), v = u(v, m, l, g, n[e + 7], 14, 1735328473), g = u(g, v, m, l, n[e + 12], 20, -1926607734), l = c(l, g, v, m, n[e + 5], 4, -378558), m = c(m, l, g, v, n[e + 8], 11, -2022574463), v = c(v, m, l, g, n[e + 11], 16, 1839030562), g = c(g, v, m, l, n[e + 14], 23, -35309556), l = c(l, g, v, m, n[e + 1], 4, -1530992060), m = c(m, l, g, v, n[e + 4], 11, 1272893353), v = c(v, m, l, g, n[e + 7], 16, -155497632), g = c(g, v, m, l, n[e + 10], 23, -1094730640), l = c(l, g, v, m, n[e + 13], 4, 681279174), m = c(m, l, g, v, n[e], 11, -358537222), v = c(v, m, l, g, n[e + 3], 16, -722521979), g = c(g, v, m, l, n[e + 6], 23, 76029189), l = c(l, g, v, m, n[e + 9], 4, -640364487), m = c(m, l, g, v, n[e + 12], 11, -421815835), v = c(v, m, l, g, n[e + 15], 16, 530742520), g = c(g, v, m, l, n[e + 2], 23, -995338651), l = f(l, g, v, m, n[e], 6, -198630844), m = f(m, l, g, v, n[e + 7], 10, 1126891415), v = f(v, m, l, g, n[e + 14], 15, -1416354905), g = f(g, v, m, l, n[e + 5], 21, -57434055), l = f(l, g, v, m, n[e + 12], 6, 1700485571), m = f(m, l, g, v, n[e + 3], 10, -1894986606), v = f(v, m, l, g, n[e + 10], 15, -1051523), g = f(g, v, m, l, n[e + 1], 21, -2054922799), l = f(l, g, v, m, n[e + 8], 6, 1873313359), m = f(m, l, g, v, n[e + 15], 10, -30611744), v = f(v, m, l, g, n[e + 6], 15, -1560198380), g = f(g, v, m, l, n[e + 13], 21, 1309151649), l = f(l, g, v, m, n[e + 4], 6, -145523070), m = f(m, l, g, v, n[e + 11], 10, -1120210379), v = f(v, m, l, g, n[e + 2], 15, 718787259), g = f(g, v, m, l, n[e + 9], 21, -343485551), l = t(l, i), g = t(g, a), v = t(v, h), m = t(m, d);
		return [l, g, v, m]
	}

	function a(n) {
		var t, r = "";
		for(t = 0; t < 32 * n.length; t += 8) r += String.fromCharCode(n[t >> 5] >>> t % 32 & 255);
		return r
	}

	function h(n) {
		var t, r = [];
		for(r[(n.length >> 2) - 1] = void 0, t = 0; t < r.length; t += 1) r[t] = 0;
		for(t = 0; t < 8 * n.length; t += 8) r[t >> 5] |= (255 & n.charCodeAt(t / 8)) << t % 32;
		return r
	}

	function d(n) {
		return a(i(h(n), 8 * n.length))
	}

	function l(n, t) {
		var r, e, o = h(n),
			u = [],
			c = [];
		for(u[15] = c[15] = void 0, o.length > 16 && (o = i(o, 8 * n.length)), r = 0; 16 > r; r += 1) u[r] = 909522486 ^ o[r], c[r] = 1549556828 ^ o[r];
		return e = i(u.concat(h(t)), 512 + 8 * t.length), a(i(c.concat(e), 640))
	}

	function g(n) {
		var t, r, e = "0123456789abcdef",
			o = "";
		for(r = 0; r < n.length; r += 1) t = n.charCodeAt(r), o += e.charAt(t >>> 4 & 15) + e.charAt(15 & t);
		return o
	}

	function v(n) {
		return unescape(encodeURIComponent(n))
	}

	function m(n) {
		return d(v(n))
	}

	function p(n) {
		return g(m(n))
	}

	function s(n, t) {
		return l(v(n), v(t))
	}

	function C(n, t) {
		return g(s(n, t))
	}

	function A(n, t, r) {
		return t ? r ? s(t, n) : C(t, n) : r ? m(n) : p(n)
	}

	BMCW.md5 = A;
})(window, BMCW);

/* BackTop */
(function($, BMCW) {
	"use strict";

	var BackTop = function(domE, distance) {
		if(!domE) return;
		var _onscroll = window.onscroll,
			_onclick = domE.onclick;

		window.onscroll = throttle(function() {
			typeof _onscroll === 'function' && _onscroll.apply(this, arguments);
			toggleDomE();
		}, 100);
		domE.onclick = function() {
			typeof _onclick === 'function' && _onclick.apply(this, arguments);
			document.documentElement.scrollTop = 0;
			document.body.scrollTop = 0;
		};

		function toggleDomE() {
			domE.style.display = (document.documentElement.scrollTop || document.body.scrollTop) > (distance || 500) ? 'block' : 'none';
		}

		function throttle(func, wait) {
			var timer = null;
			return function() {
				var self = this,
					args = arguments;
				if(timer) clearTimeout(timer);
				timer = setTimeout(function() {
					return typeof func === 'function' && func.apply(self, args);
				}, wait);
			}
		}
	};

	BMCW.BackTop = BackTop;
})(mui, BMCW);