(function($, BMCW) {
	"use strict";

	BMCW.augment(BMCW.BasePage, {
		/**
		 * 页面路由
		 */
		Route: {
			SendVerifyCode: "/Common/SendVerifyCode", //验证码
			Register: "/Login/ResetPassword" //重置密码
		},
		/**
		 * 参数
		 */
		Param: {
			isSending: false, //验证码是否发送中
			SourcePage: "", //来源页面
			CallBack: "" //回调方法
		},
		/**
		 * 初始化方法
		 * 页面参数初始化  页面方法初始化  等
		 * @param {Object} options
		 */
		init: function(options) {
			var self = this,
				wb = plus.webview.currentWebview();
			self.Param.SourcePage = wb.SourcePage;
			self.Param.CallBack = wb.CallBack;

			mui.init({
				swipeBack: true //启用右滑关闭功能
			});
		},
		/**
		 * 事件绑定
		 * @param {Object} options
		 */
		initEvent: function(options) {
			var self = this;
			//发送验证码
			$("#btn_verifycode").click(function() {
				//验证手机号码
				var usrMobile = $("#ipt_mobile").val();
				if(BMCW.isNullOrEmpty(usrMobile)) {
					BMCW.toast("请输入手机号码.");
					return false;
				}
				if(!BMCW.isMobile(usrMobile)) {
					BMCW.toast("请输入正确的手机号码");
					return false;
				}

				if(self.Param.isSending) {
					return false;
				} else {
					self.Param.isSending = true;
				}

				//后台发送验证
				self.countDown();
				BMCW.Ajax.ajax({
					url: self.Route.SendVerifyCode,
					showLoading: false,
					type: "GET",
					data: {
						mobile: usrMobile //电话
					},
					success: function(rdata) {
						if(rdata.status == -1) {
							BMCW.toast(rdata.message);
						}
					}
				})

			});

			//找回密码
			document.getElementById("btn_register").addEventListener("tap", function() {
				self.resetPassword.call(self);
			}, false);

			//立即注册
			document.getElementById("a_register").addEventListener("tap", function() {
				BMCW.openWindow(BMCW.routeCfg.register, {
					extras: {
						SourcePage: self.Param.SourcePage,
						CallBack: self.Param.CallBack
					}
				});
			}, false);
		},
		/**
		 * 渲染页面
		 * 通过ajax对页面加载显示
		 * @param {Object} options
		 */
		initView: function(options) {},
		/**
		 * 倒计时
		 */
		countDown: function() {
			var self = this;
			var idx = 59
			var btnverifycode = $("#btn_verifycode");
			btnverifycode.val("59s");
			btnverifycode[0].classList.add("bjcg-disabled");
			var t = setInterval(function() {
				idx--;
				btnverifycode.val(idx + "s");
				if(idx <= 0) {
					btnverifycode[0].classList.remove("bjcg-disabled");
					clearInterval(t);
					btnverifycode.val("请重新发送");
					self.Param.isSending = false;
				}
			}, 1000)
		},
		/**
		 * 注册
		 */
		resetPassword: function() {
			var self = this;
			var usrMobile = $("#ipt_mobile").val();
			var usrPwd = $("#ipt_password").val();
			var verifycode = $("#ipt_verifycode").val();

			if(BMCW.isNullOrEmpty(usrMobile)) {
				BMCW.toast("请输入手机号码");
				return false;
			}
			if(!BMCW.isMobile(usrMobile)) {
				BMCW.toast("请输入正确的手机号码");
				return false;
			}

			if(BMCW.isNullOrEmpty(usrPwd)) {
				BMCW.toast("请输入密码");
				return false;
			}
			if(BMCW.isChinese(usrPwd)) {
				BMCW.toast("密码不能包含汉字");
				return false;
			}
			if(usrPwd.length < 6 || usrPwd.length > 18) {
				BMCW.toast("密码长度必须在6-18位长度");
				return false;
			}

			if(BMCW.isNullOrEmpty(verifycode)) {
				BMCW.toast("请输入验证码");
				return false;
			}
			BMCW.Ajax.ajax({
				url: self.Route.Register,
				type: "Post",
				showLoading: true,
				data: {
					mobile: usrMobile, //电话
					password: BMCW.md5(usrPwd), //密码  
					verifycode: verifycode //验证码
				},
				success: function(rdata) {
					if(rdata.status == 0) {
						console.log(JSON.stringify(rdata.Data))
						BMCW.setLocalStorage("CurrentUserID", rdata.data.UserID);
						BMCW.setLocalStorage("CurrentUserMobile", rdata.data.Mobile);
						BMCW.setLocalStorage("BMCWUserID", rdata.data.BMCWUserID);

						//调用回调函数,关闭当前页  有待优化，目前关闭之后只能跳转首页
						if(self.Param.SourcePage) {
							var callMethod = BMCW.format("{0}()", self.Param.CallBack);
							var wb = BMCW.getWebviewById(self.Param.SourcePage);
							wb.evalJS(callMethod);
						}

						BMCW.closeWebview(BMCW.routeCfg.login.id, "none");
						BMCW.closeWebview(BMCW.routeCfg.register.id, "none");
						BMCW.closeWebview(BMCW.routeCfg.forget_passowrd.id);
					} else {
						BMCW.toast(rdata.message);
					}
				}
			})
		}
	});

	//实例化类
	window.page = new BMCW.BasePage();

})(mui, BMCW);