(function($, BMCW) {
	"use strict";

	BMCW.augment(BMCW.BasePage, {
		/**
		 * 页面路由
		 */
		Route: {
			GetUserInfor: "/Personal/GetUserInfor", //获取用户信息
			GetUserAuth: "/Personal/GetUserAuth", //获取认证状态
			GetLocationByName: "/Common/GetLocationByName", //获取数据库城市id
			GetIndexBanner: "/Common/GetIndexBanner"
		},
		/**
		 * 参数
		 */
		Param: {
			ActivePage: "",
			BannerList: [],
			isMaskClick: false //事件有穿透,手动添加锁
		},
		/**
		 * 初始化方法
		 * 页面参数初始化  页面方法初始化  等
		 * @param {Object} options
		 */
		init: function(options) {
			var info = plus.push.getClientInfo();

			//初始化纤细
			BMCW.setLocalStorage("LocationID", 201);
			BMCW.setLocalStorage("LocationName", "北京");

			//读取本地存储，检查是否为首次启动
			var self = this,
				wb = plus.webview.currentWebview(),
				nviews = wb.getSubNViews(),
				subpages = util.options.subpages;
			var showGuide = plus.storage.getItem("lauchFlag");
			//仅支持竖屏显示
			plus.screen.lockOrientation("portrait-primary");

			if(showGuide) {
				//关闭程序启动界面
				plus.navigator.closeSplashscreen();
				// 设置应用非全屏显示！
				plus.navigator.setFullscreen(false);
				//创建子webview窗口 并初始化
				util.initSubpage();
				self.Param.ActivePage = plus.webview.currentWebview();

				//给每个view 添加监听点击切换
				for(var i = 0; i < 5; i++) {
					nviews[i].addEventListener('click', function(e) {
						self.clickEvent(e);
					}, false);
				}

				self.initIndex(true);
			} else {

				//显示启动导航
				mui.openWindow({
					id: 'guide',
					url: 'lauchIndex.html',
					styles: {
						popGesture: "none"
					},
					show: {
						aniShow: 'none'
					},
					waiting: {
						autoShow: false
					}
				});

				//延迟的原因：优先打开启动导航页面，避免资源争夺
				setTimeout(function() {
					//创建子webview窗口 并初始化
					util.initSubpage();
					self.Param.ActivePage = plus.webview.currentWebview();

					//给每个view 添加监听点击切换
					for(var i = 0; i < 5; i++) {
						nviews[i].addEventListener('click', function(e) {
							self.clickEvent(e);
						}, false);
					}

					self.initIndex(false);
				}, 200);
			}

			FastClick.attach(document.body);
		},
		/**
		 * 初始化首页
		 * @param {Object} checkUpdate
		 */
		initIndex: function(checkUpdate) {
			var self = this,
				wb = plus.webview.currentWebview();

			//获取当前运行版本
			BMCW.setLocalStorage("CurrentAppVersion", plus.runtime.version);
			plus.runtime.getProperty(plus.runtime.appid, function(inf) {
				BMCW.setLocalStorage("CurrentAppVersion", inf.version);
			});

			//设置滚动条隐藏 不可缩放
			plus.webview.currentWebview().setStyle({
				scrollIndicator: "none",
				scalable: false
			});

			//如果没有登陆则设置userid=0
			var userID = BMCW.getCurrentUserID();
			if(userID < 1) {
				BMCW.setLocalStorage("CurrentUserID", 0);
			} else {
				self.getUserInfor();
			}

			plus.push.setAutoNotification(true);

			if(checkUpdate) {
				//检查更新
				bmcwUpdate.CheckUpdate(false);
			}

			//获取城市ID
			BMCW.getCurrentPosition(function(addr) {
				BMCW.Ajax.ajax({
					url: self.Route.GetLocationByName,
					showLoading: false,
					data: {
						pName: addr.province,
						cName: addr.city
					},
					success: function(rdata) {
						if(rdata.status == 0) {
							if(BMCW.isNullOrEmpty(rdata.data)) {
								BMCW.toast("获取定位失败,请手动定位");
							} else {
								BMCW.setLocalStorage("LocationID", rdata.data.locationId);
								BMCW.setLocalStorage("LocationName", rdata.data.cName);
								document.getElementById("spnLocName").innerHTML = BMCW.getLocalStorage('LocationName');
							}
						} else {
							BMCW.toast(rdata.message);
						}
					}
				});
			})
		},
		/**
		 * 事件绑定
		 * @param {Object} options
		 */
		initEvent: function(options) {
			var self = this;
			//点击通知栏消息时触发
			plus.push.addEventListener("click", function(msg) {
				try {
					if(msg.payload) {
						var payload = JSON.parse(msg.payload);
						BMCW.openWindow(BMCW.routeCfg.messsagedetail, {
							extras: {
								MessageID: payload.MessageID
							}
						});
					}
				} catch(e) {}
			});

			//安卓需要特殊处理
			plus.push.addEventListener("receive", function(msg) {
				try {
					if(msg.payload) {
						var payload = null;
						if(typeof(msg.payload) == "object") {
							payload = msg.payload;
						} else {
							payload = JSON.parse(msg.payload);
						}
						// android系统
						if(plus.os.name == "Android") {
							plus.push.createMessage(msg.content, msg.payload, {
								title: msg.title
							});
						}
					}
				} catch(e) {}

			});

			//充值
			document.getElementById("btnPayPrice").addEventListener('click', function() {
				document.getElementById("divPayPrice").style.display = "none";
				BMCW.removeTabMask();
				BMCW.openWindow(BMCW.routeCfg.cashDepositServer);
				self.Param.isMaskClick = true;
			}, false);
			document.getElementById("imgPayPrice").addEventListener('click', function() {
				document.getElementById("divPayPrice").style.display = "none";
				BMCW.removeTabMask();
				self.Param.isMaskClick = true;
			}, false);

			//授权
			document.getElementById("btnUsrAuth").addEventListener('click', function() {
				document.getElementById("divUsrAuth").style.display = "none";
				BMCW.removeTabMask();
				self.Param.isMaskClick = true;
				BMCW.openWindow(BMCW.routeCfg.userauthfirststep);
			}, false);
			document.getElementById("imgUsrAuth").addEventListener('click', function() {
				document.getElementById("divUsrAuth").style.display = "none";
				BMCW.removeTabMask();
				self.Param.isMaskClick = true;
			}, false);

			//定位
			document.getElementById("divLocation").addEventListener('tap', function() {
				BMCW.openWindow(BMCW.routeCfg.addresslist);
			}, false);

		},
		/**
		 * 渲染页面
		 * 通过ajax对页面加载显示
		 * @param {Object} options
		 */
		initView: function(options) {
			var self = this;
			self.getIndexBanner();
		},
		/**
		 * 获取banner图
		 */
		getIndexBanner: function() {
			var self = this;
			BMCW.Ajax.ajax({
				url: self.Route.GetIndexBanner,
				showLoading: false,
				success: function(rdata) {
					if(rdata.status == 0) {
						if(rdata.data.length > 0) {
							self.Param.BannerList = rdata.data;
							var arrs = [];
							var dots = [];
							arrs.push('<div class="mui-slider-item mui-slider-item-duplicate"><a href="#"><img id="bannerLast" src="' + rdata.data[rdata.data.length - 1].ImageUrl + '"></a></div>')
							for(var i = 0; i < rdata.data.length; i++) {
								arrs.push('<div class="mui-slider-item"><a onclick="page.bannerClick(' + rdata.data[i].Id + ');"><img src="' + rdata.data[i].ImageUrl + '"></a></div>');
								if(i == 0) {
									dots.push('<div class="mui-indicator mui-active"></div>');
								} else {
									dots.push('<div class="mui-indicator"></div>');
								}

							}
							arrs.push('<div class="mui-slider-item mui-slider-item-duplicate"><a href="#"><img id="bannerLast" src="' + rdata.data[0].ImageUrl + '"></a></div>')

							document.getElementById("bannerFirst").innerHTML = arrs.join('');
							document.getElementById("bannerDot").innerHTML = dots.join('');
						}
					}
				}
			});
		},
		/**
		 * 页面跳转
		 * @param {Object} lurl
		 */
		bannerClick: function(lurl) {
			var self = this;
			for(var i = 0; i < self.Param.BannerList.length; i++) {
				if(self.Param.BannerList[i].Id == lurl) {
					if(self.Param.BannerList[i].LinkUrl) {
						BMCW.openWindow({
							id: "BannerIndex",
							url: self.Param.BannerList[i].LinkUrl,
							titleNView: {
								titleText: "",
								backgroundColor: "#f7f7f7",
								titleColor: "#000",
								autoBackButton: true,
								splitLine: {
									color: "#ccc",
									height: "0.5px"
								}
							}
						});
					}
				}
			}

		},
		/**
		 * 添加预约
		 * @param {Object} masterID
		 * @param {Object} biztype
		 */
		addRegister: function(masterID, biztype, desc) {
			var self = this;
			//BMCW.routeCfg.registeradd.titleNView.titleText = desc;
			if(BMCW.getCurrentUserID() > 0) {
				if(biztype == 1) {
					BMCW.openWindow(BMCW.routeCfg.registeradd, {
						extras: {
							TitleDesc: desc,
							MasterID: masterID,
							MasterName: desc
						}
					});
				} else if(biztype > 1) {
					BMCW.openWindow(BMCW.routeCfg.registeradd, {
						extras: {
							TitleDesc: desc,
							MasterID: masterID,
							MasterName: '驾驶证业务',
							BizTypeID: biztype,
							BizTypeName: desc

						}
					});
				} else {
					BMCW.openWindow(BMCW.routeCfg.biztypesearch, {
						extras: {
							TitleDesc: desc,
							BizTypeID: 0,
							MasterID: masterID,
							SourcePage: plus.webview.currentWebview().id,
							CallBack: "page.openRegisterAdd"
						}
					});
				}
			} else {
				BMCW.openWindow(BMCW.routeCfg.login);
			}
		},
		/**
		 * 添加转移
		 * @param {Object} masterID
		 * @param {Object} biztype
		 * @param {Object} desc
		 */
		addTransfer: function(masterID, biztype, desc) {
			var self = this;
			BMCW.routeCfg.transferinvoice.titleNView.titleText = desc;
			if(BMCW.getCurrentUserID() > 0) {
				BMCW.openWindow(BMCW.routeCfg.transferinvoice, {
					extras: {
						MasterID: masterID,
						MasterName: 'desc',
						BizTypeID: biztype,
						BizTypeName: desc
					}
				});
			} else {
				BMCW.openWindow(BMCW.routeCfg.login);
			}
		},
		/**
		 * 直接选择2级业务调用方法
		 * @param {Object} data		
		 */
		openRegisterAdd: function(data) {
			BMCW.openWindow(BMCW.routeCfg.registeradd, {
				extras: {
					MasterID: 15,
					MasterName: '驾驶证业务',
					BizTypeID: data.BizTypeID,
					BizTypeName: data.BizTypeName,
					TitleDesc: data.BizTypeName,
				}
			});
		},
		/**
		 * 自定义 tab 点击事件
		 */
		clickEvent: function(e) {
			var self = this,
				wb = plus.webview.currentWebview(),
				nviews = wb.getSubNViews(),
				subpages = util.options.subpages,
				targetPage;
			var currId = e.target.id,
				currIndex = parseInt(currId.substr(currId.length - 1, 1) - 1),
				currView = wb.getStyle().subNViews[currIndex];

			// 匹配对应tab窗口	
			if(currIndex > 0) {
				targetPage = plus.webview.getWebviewById(subpages[currIndex - 1]);
			} else {
				targetPage = plus.webview.currentWebview();
			}

			if(targetPage == self.Param.ActivePage) {
				return;
			}

			//底部选项卡切换
			util.toggleNview(currView, currIndex);
			// 子页面切换
			util.changeSubpage(targetPage, self.Param.ActivePage);
			//更改当前活跃的页面
			self.Param.ActivePage = targetPage;
		},
		/**
		 * 红点显示隐藏
		 */
		updateSubNview: function(ishow) {
			var self = this;
			var wb = plus.webview.currentWebview(),
				nviews = wb.getStyle().subNViews;
			var color = util.options.normal_color;
			if(self.Param.ActivePage.id == "tabMessage3" || self.Param.ActivePage.id == "/module/message/page/messagelist.html") {
				color = util.options.active_color;
			}
			for(var i = 0; i < nviews.length; i++) {
				if(nviews[i].id == "tabMessage3") {
					var currObj = nviews[i];
					var subNview = {
						id: currObj.id,
						tags: [{
							tag: 'font', //currObj.tag
							id: currObj.id + 1,
							position: currObj.tags[0].position,
							text: currObj.tags[0].text,
							textStyles: util.changeColor(currObj.tags[0].textStyles, color)
						}, {
							tag: 'font',
							id: currObj.id + 2,
							position: currObj.tags[1].position,
							text: currObj.tags[1].text,
							textStyles: util.changeColor(currObj.tags[1].textStyles, color)
						}]
					};
					var sz = "0px",
						clr = "#00FF3F3E";

					if(ishow) {
						sz = "10px";
						clr = "#FF3F3E";
					}
					subNview.tags.push({
						tag: "font",
						id: "tabBar33",
						text: "\ue62c",
						position: {
							top: "5px",
							left: "55%",
							width: "16px",
							height: "16px"
						},
						textStyles: {
							fontSrc: "_www/fonts/iconfont.ttf",
							align: "center",
							size: sz,
							color: clr
						}
					});
					// 重绘当前nview
					wb.updateSubNViews([subNview]);
				}
			}
		},
		/**
		 * 获取用户信息
		 */
		getUserInfor: function() {
			var self = this;
			BMCW.Ajax.ajax({
				url: self.Route.GetUserInfor,
				showLoading: false,
				data: {
					userID: BMCW.getCurrentUserID()
				},
				success: function(rdata) {
					if(rdata.status == 0) {
						self.Param.Data = rdata.data;

						//缓存用户类型 级别 和手机号码
						BMCW.setLocalStorage("CurrentUserType", rdata.data.UserType);
						BMCW.setLocalStorage("UserLevel", rdata.data.UserLevel);
						BMCW.setLocalStorage("BMCWUserID", rdata.data.BMCWUserID);
						BMCW.setLocalStorage("CurrentUserMobile", rdata.data.Mobile);

						if(rdata.data.UserType == 2) { //类型=代办 and 状态=待审核
							//UserLevel: 0:未认证,1:已认证,2:已交保证金
							if(BMCW.isNullOrEmpty(rdata.data.UserLevel) || rdata.data.UserLevel == 0) {
								self.getAuthReult();
							} else if(rdata.data.UserLevel == 1) {
								console.log(123)
								//充值
								document.getElementById("divPayPrice").style.display = 'block';
								BMCW.addTabMask();
							}
						}
					} else {
						BMCW.toast(rdata.message);
					}
				}
			});
		},
		/**
		 * 获取认证结果
		 */
		getAuthReult: function() {
			var self = this;
			BMCW.Ajax.ajax({
				url: self.Route.GetUserAuth,
				showLoading: false,
				data: {
					UserID: BMCW.getCurrentUserID()
				},
				success: function(rdata) {
					if(rdata.status == 0) {
						if(rdata.data.UserAuthID == 0) {
							document.getElementById("divUsrAuth").style.display = 'block';
							BMCW.addTabMask();
						} else if(rdata.data.AuthStatus == 3) {
							var btnArray = ['取消', '认证'];

							BMCW.confirm("您提交的[实名认证]被拒绝，请重新提交。", "", btnArray, function(e) {
								if(e.index == 1) {
									BMCW.openWindow(BMCW.routeCfg.userauthfirststep);
									BMCW.removeTabMask();
								} else {
									BMCW.removeTabMask();
								}
							}, "div");
							BMCW.addTabMask();
						}

					} else {
						BMCW.toast(rdata.message);
					}
				}
			});
		},
		/**
		 * 检查更新
		 */
		updateLocation: function() {
			document.getElementById("spnLocName").innerHTML = BMCW.getLocalStorage('LocationName');
		}
	});
	//实例化类
	window.page = new BMCW.BasePage();
})(mui, BMCW);