(function($, BMCW) {
	"use strict";

	BMCW.augment(BMCW.BasePage, {
		/**
		 * 页面路由
		 */
		Route: {
			Login: "/Login/Login" //登录
		},
		/**
		 * 参数
		 */
		Param: {
			SourcePage: "", //来源页面
			CallBack: "" //回调方法
		},
		/**
		 * 初始化方法
		 * 页面参数初始化  页面方法初始化  等
		 * @param {Object} options
		 */
		init: function(options) {
			var self = this,
				wb = plus.webview.currentWebview();
			self.Param.SourcePage = wb.SourcePage;
			self.Param.CallBack = wb.CallBack;

			mui.init({
				swipeBack: true //启用右滑关闭功能
			});
		},
		/**
		 * 事件绑定
		 * @param {Object} options
		 */
		initEvent: function(options) {
			var self = this;
			//登陆
			document.getElementById("btn_login").addEventListener("tap", function() {
				self.login.call(self);
			}, false);

			//页面跳转
			$("#btn_container").on("tap", "a", function(e) {
				var hf = this.getAttribute("href").substring(1);
				BMCW.openWindow(BMCW.routeCfg[hf], {
					extras: {
						SourcePage: self.Param.SourcePage,
						CallBack: self.Param.CallBack
					}
				});
			});
		},
		/**
		 * 渲染页面
		 * 通过ajax对页面加载显示
		 * @param {Object} options
		 */
		initView: function(options) {

		},
		/**
		 * 登陆
		 */
		login: function() {
			var self = this;
			var cltInfo = plus.push.getClientInfo();

			var usrMobile = $("#ipt_mobile").val();
			var usrPwd = $("#ipt_pwd").val();

			if(BMCW.isNullOrEmpty(usrMobile)) {
				BMCW.toast("请输入手机号码");
				return false;
			}
			if(!BMCW.isMobile(usrMobile)) {
				BMCW.toast("请输入正确的手机号码");
				return false;
			}
			if(BMCW.isNullOrEmpty(usrPwd)) {
				BMCW.toast("请输入密码");
				return false;
			}
			BMCW.Ajax.ajax({
				url: self.Route.Login,
				type: "POST",
				loadingMsg: "登陆中...",
				data: {
					mobile: usrMobile, //电话
					password: BMCW.md5(usrPwd), //密码
					ostype: plus.os.name, //操作系统
					osversion: plus.os.version, //系统版本
					imei: plus.device.imei,
					uuid: plus.device.uuid,
					vendor: plus.device.vendor, //供应商
					model: plus.device.model, //型号
					version: BMCW.getLocalStorage("CurrentAppVersion"), //当前版本
					token: cltInfo.token, //ios推送标识
					clientid: cltInfo.clientid //android推送标识
				},
				success: function(rdata) {
					if(rdata.status == 0) {
						BMCW.setLocalStorage("CurrentUserID", rdata.data.UserID);
						BMCW.setLocalStorage("CurrentUserMobile", rdata.data.Mobile);
						BMCW.setLocalStorage("BMCWUserID", rdata.data.BMCWUserID);
						BMCW.setLocalStorage("CurrentUserType", rdata.data.CurrentUserType);
						BMCW.setLocalStorage("UserLevel", rdata.data.UserLevel);

						//调用回调函数,关闭当前页
						if(self.Param.SourcePage) {
							var callMethod = BMCW.format("{0}()", self.Param.CallBack);
							var wb = BMCW.getWebviewById(self.Param.SourcePage);
							wb.evalJS(callMethod);
						}

						BMCW.closeWebview(BMCW.routeCfg.login.id);
					} else {
						BMCW.toast(rdata.message);
					}
				}
			});
		}
	});

	//实例化类
	window.page = new BMCW.BasePage();

})(mui, BMCW);