(function($, BMCW) {
	"use strict";

	BMCW.augment(BMCW.BasePage, {
		/**
		 * 页面路由
		 */
		Route: {
			GetApplyEntrustmentList: "/ApplyEntrustment/GetApplyEntrustmentList", //获取列表
			CancelEntrustment: "/ApplyEntrustment/CancelEntrustment", //取消委托申请
			MakeSureEntrustment: "/ApplyEntrustment/MakeSureEntrustment", //确认申请
			CompleteEntrustment: "/ApplyEntrustment/CompleteEntrustment", //完成申请
			EvaluateEntrustment: "/ApplyEntrustment/EvaluateEntrustment", //评价
			ResetEntrusment: "/ApplyEntrustment/ResetEntrusment", //重新预约
			DeleteEntrustment: "/ApplyEntrustment/DeleteEntrustment", //刪除预约
			GetUserAgentInfo: "/UserAgent/GetUserAgentInfoByUserId", //获取申请人信息
			GetUserEvaluation: "/ApplyEntrustment/GetUserEvaluation", //获取评价信息			
			GetStarTags: "/UserAgent/GetStarTags" //获取星级和标签关系
		},
		/**
		 * 参数
		 */
		Param: {
			PageIndex: 1, //页码
			PageSize: 10, //页大小
			PageCount: 0, //总数量
			EntrustList: [], //代理人列表
			SourcePage: "", //来源页面
			CallBack: "", //回调方法
			ApplyId: 0, //申请id
			ExpertUserId: 0, //专业代办
			StarIndex: 0, //评价星级
			RegOfficeID: 0, //车管所id
			isEvaluate: false, //是否已经评价
			IsReCreate: 0, //是否重复下单
			StarTags: [], //星级标签
			Tags: [], //标签
			StarDesc: ['非常不满意，各方面都很差', '不满意，比较差', '一般，还需要改善', '比较满意，仍可改善', '非常满意，无可挑剔'] //评价内容
		},
		/**
		 * 初始化方法
		 * 页面参数初始化  页面方法初始化  等
		 * @param {Object} options
		 */
		init: function(options) {
			var self = this,
				wb = plus.webview.currentWebview();
			self.Param.SourcePage = wb.SourcePage;
			self.Param.CallBack = wb.CallBack;
			mui.init({
				swipeBack: true //启用右滑关闭功能				
			});

			//下拉刷新
			BMCW.setCirclePullToRefresh(function() {
				self.Param.PageIndex = 1;
				self.getApplyEntrustmentList();
			});

			//滑动底部自动分页查询
			document.addEventListener("plusscrollbottom", function() {
				if(self.Param.PageIndex < self.Param.PageCount) {
					self.Param.PageIndex += 1;
					self.getApplyEntrustmentList();
				}
			}, false);

			FastClick.attach(document.body);
		},
		/**
		 * 事件绑定
		 * @param {Object} options
		 */
		initEvent: function(options) {
			var self = this;
			//绑定右滑删除

			$('#muiContent').on('tap', '.mui-btn', function(event) {
				var elem = this;
				self.deleteEntrustment.call(self, elem.id.substring(3));
			});

			//评分
			mui('.icons').on('tap', 'i', function() {
				if(self.Param.isEvaluate) {
					return;
				}

				var index = parseInt(this.getAttribute("data-index"));
				if(index == self.Param.StarIndex) {
					return;
				}
				var parent = this.parentNode;
				var children = parent.children;
				var description = document.getElementById("starDesc");
				if(this.classList.contains("mui-icon-star")) {
					for(var i = 0; i < index; i++) {
						children[i].classList.remove('mui-icon-star');
						children[i].classList.add('mui-icon-star-filled');
					}
				} else {
					for(var i = index; i < 5; i++) {
						children[i].classList.add('mui-icon-star');
						children[i].classList.remove('mui-icon-star-filled');
					}
				}
				self.Param.Tags = [];
				self.Param.StarIndex = index;
				description.innerHTML = self.Param.StarDesc[index - 1];
				self.changeTags(index);
			});

			//绑定关闭事件
			document.getElementById("close1").addEventListener('click', function() {
				self.animateOut("box1", 'bjcgMask', 'fadeInDownBig', 'fadeOut', .4, .2, "");
			});
			document.getElementById("close2").addEventListener('click', function() {
				self.animateOut("box2", 'bjcgMask', 'fadeInDownBig', 'fadeOut', .4, .2, "");
			});
			document.getElementById("close3").addEventListener('click', function() {
				self.animateOut("box3", 'bjcgMask', 'fadeInDownBig', 'fadeOut', .4, .2, "");
			});
			document.getElementById("close4").addEventListener('click', function() {
				self.animateOut("box4", 'bjcgMask', 'fadeInDownBig', 'fadeOut', .4, .2, "");
			});
			//点击遮罩层关闭底部弹窗
			document.getElementById("bjcgMask").addEventListener('click', function() {
				self.closeMask();
			});
		},
		/**
		 * 渲染页面
		 * 通过ajax对页面加载显示
		 * @param {Object} options
		 */
		initView: function(options) {
			var self = this;
			//预约成功会跳转到此页面
			BMCW.closeWebview(BMCW.routeCfg.registersuccess.id, "none");
			BMCW.closeWebview(BMCW.routeCfg.registerlist.id, "none");

			//查询数据
			self.Param.PageIndex = 1;
			self.getApplyEntrustmentList();
			self.GetStarTags();
		},
		/**
		 * 获取全部列表
		 */
		getApplyEntrustmentList: function() {
			var self = this,
				applyUserId = 0,
				expertUserId = 0;
			var usertype = BMCW.getLocalStorage("CurrentUserType");
			if(usertype == 2) { //用户类型为代办
				expertUserId = BMCW.getLocalStorage("CurrentUserID");
			} else {
				applyUserId = BMCW.getLocalStorage("CurrentUserID")
			}
			BMCW.Ajax.ajax({
				url: self.Route.GetApplyEntrustmentList,
				data: {
					applyUserId: applyUserId,
					expertUserId: expertUserId,
					pageIndex: self.Param.PageIndex,
					pageSize: self.Param.PageSize
				},
				success: function(rdata) {
					if(rdata.status == 0) {
						//如果返回成功,Message赋值总记录数
						self.updateEntrustList(rdata.data);
						self.renderView(rdata.data, rdata.message);
					} else {
						BMCW.toast(rdata.message);
					}
				}
			});
		},
		/**
		 * 渲染页面
		 * @param {Object} data
		 */
		renderView: function(data, pageCount) {
			var self = this,
				content = document.getElementById("muiContent");

			//如果首页,则清空内容
			if(self.Param.PageIndex == 1) {
				content.innerHTML = "";
				if(data.length < 1) {
					document.getElementById("div_nodata").style.display = "";
					document.getElementById("divContainer").style.display = "none";
				} else {
					document.getElementById("div_nodata").style.display = "none";
					document.getElementById("divContainer").style.display = "";
				}
			}

			if(data.length > 0) {
				self.Param.PageCount = BMCW.getPageCount(parseInt(pageCount), self.Param.PageSize);

				var tpl = "";
				for(var i = 0; i < data.length; i++) {
					content.innerHTML += self.getTpl(data[i]);
				}

				content.innerHTML += tpl;
			}
		},
		/**
		 * 获取模版
		 */
		getTpl: function(item) {
			var self = this;
			var statusName = '',
				methodName = '';
			var weekday = ["周日", "周一", "周二", "周三", "周四", "周五", "周六"];
			switch(item.ApplyStatus) {
				case 1:
					statusName = '待接单';
					methodName = "page.showStatus1(" + item.ApplyId + "," + item.ExpertUserId + ");";
					break;
				case 2:
					statusName = '办理中';
					methodName = "page.showStatus2(" + item.ApplyId + "," + item.ExpertUserId + ");";
					break;
				case 3:
					statusName = '已关闭';
					methodName = "page.showStatus3(" + item.ApplyId + "," + item.ExpertUserId + "," + item.RegOfficeID + "," + item.CancelType + ");";
					break;
				case 4:
					statusName = '已完成';
					methodName = "page.showStatus4(" + item.ApplyId + "," + item.ExpertUserId + "," + item.IsReCreate + ");";
					break;
			}
			//组合时间格式
			var hh = ''
			var bdate = BMCW.convertToDate(item.RegStartDate);
			var edate = BMCW.convertToDate(item.RegEndDate);
			var wk = weekday[bdate.getDay()];
			if(bdate.getHours() > 12) {
				hh = ' 下午 ';
			} else {
				hh = ' 上午 ';
			}
			var dt = BMCW.formatDate(bdate, "HH:mm") + '-' + BMCW.formatDate(edate, "HH:mm");

			var tpl = '<li onclick="' + methodName + '" class="mui-table-view my-entrust-item mui-table-view-cell">';
			tpl += '	<div class="mui-slider-right mui-disabled">';
			tpl += '		<a class="mui-btn mui-btn-red" id="btn' + item.ApplyId + '">删除</a>';
			tpl += '	</div>';
			tpl += '	<div class="mui-slider-handle bjcg-cell-swipe">';
			tpl += '		<div class="bjcg-cell-swipe-item bjcg-bottom-inner-content-item">';
			tpl += '			<i class="icon iconfont icon-shijian-tianchong i1"></i>';
			tpl += '			<span>' + wk + '</span>';
			tpl += '			<span>' + hh + '</span>';
			tpl += '			<span>' + dt + '</span>';
			tpl += '		</div>';
			tpl += '		<div class="bjcg-cell-swipe-item bjcg-bottom-inner-content-item ">';
			tpl += '			<i class="icon iconfont icon-dian i2"></i>';
			tpl += '			<span>' + item.BizTypeName + '</span>';
			tpl += '		</div>';
			tpl += '		<div class="bjcg-cell-swipe-item bjcg-bottom-inner-content-item ">';
			tpl += '			<i class="icon iconfont icon-dian i3"></i>';
			tpl += '			<span>' + item.OfficeName + '</span>';
			tpl += '		</div>';
			tpl += '		<div class="bjcg-btn-area">';
			tpl += '			<span>' + statusName + '</span>';
			tpl += '			<i class="icon iconfont icon-jiantouyou"></i>';
			tpl += '		</div>';
			if(statusName == '已完成') {
				if(item.IsEvaluate == 0) {
					tpl += '<div class="bjcg-pingjia-area"><span>评价本次服务</span></div>';
				}
			}
			tpl += '	</div>';
			tpl += '</li>';
			return tpl;
		},
		/**
		 * 待处理
		 * @param {Object} applyId
		 * @param {Object} expertUserId
		 */
		showStatus1: function(applyId, expertUserId) {
			var self = this;
			self.Param.ApplyId = applyId;
			self.Param.ExpertUserId = expertUserId;
			self.animateIn("box1", 'bjcgMask', 'fadeInUpBig', 'fadeIn', .4, .2, "");
			self.getUserAgentInfo(expertUserId, 1);
			self.getEntrusmentInfo(applyId, 1);
		},
		/**
		 * 处理中
		 * @param {Object} applyId
		 * @param {Object} expertUserId
		 */
		showStatus2: function(applyId, expertUserId) {
			var self = this;
			self.Param.ApplyId = applyId;
			self.Param.ExpertUserId = expertUserId;
			self.animateIn("box2", 'bjcgMask', 'fadeInUpBig', 'fadeIn', .4, .2, "");
			self.getUserAgentInfo(expertUserId, 2);
			self.getEntrusmentInfo(applyId, 2);
		},
		/**
		 * 取消
		 * @param {Object} applyId
		 * @param {Object} expertUserId
		 */
		showStatus3: function(applyId, expertUserId, officeId, CancelType) {
			var self = this;
			self.Param.ApplyId = applyId;
			self.Param.ExpertUserId = expertUserId;
			self.Param.RegOfficeID = officeId;
			self.animateIn("box3", 'bjcgMask', 'fadeInUpBig', 'fadeIn', .4, .2, "");
			if(CancelType == 1) {
				document.getElementById("pCancelDesc").innerHTML = '车务订单已取消。';
			} else if(CancelType == 2) {
				document.getElementById("pCancelDesc").innerHTML = '对方已取消，请选择其他代办。';
			} else {
				document.getElementById("pCancelDesc").innerHTML = '超时无人接单，请选择其他代办。';
			}
			self.getEntrusmentInfo(applyId, 3);

		},
		/**
		 * 完成
		 * @param {Object} applyId
		 * @param {Object} expertUserId
		 */
		showStatus4: function(applyId, expertUserId, isReCreate) {
			var self = this;
			self.Param.ApplyId = applyId;
			self.Param.ExpertUserId = expertUserId;
			self.Param.IsReCreate = isReCreate;
			//隐藏标签
			document.getElementById("starTagUlOne").innerHTML = "";
			document.getElementById("divStarArea").style.display = "none";

			self.Param.Tags = [];
			self.clearStar();
			self.getUserEvaluation();
			self.animateIn("box4", 'bjcgMask', 'fadeInUpBig', 'fadeIn', .4, .2, "");
		},
		/**
		 * 关闭
		 * @param {Object} regId
		 */
		cancelEntrustment: function(idx) {
			var self = this;
			var btnArray = ['取消', '确认'];
			BMCW.confirm('确认取消订单?', '<img src="../../../images/bjcg-icon-tip.jpg" alt=""/>', btnArray, function(e) {
				if(e.index == 1) {
					BMCW.Ajax.ajax({
						url: self.Route.CancelEntrustment,
						type: "POST",
						data: {
							ApplyId: self.Param.ApplyId,
							CancelType: 1 //人工取消
						},
						success: function(rdata) {
							if(rdata.status == 0) {
								self.closeMask();
								self.initView();
								document.getElementById('box' + idx).style.display = 'none';
							} else {
								BMCW.toast(rdata.message);
							}
						}
					});
				}
			}, 'div');
		},
		/**
		 * 确认
		 */
		makeSureEntrustment: function() {

		},
		/**
		 * 完成
		 */
		completeEntrustment: function() {

		},
		/* 		
		 * 动画进入
		 * innerId为想要添加动画的盒子id            string
		 * maskId为遮罩盒子id                    string
		 * actionName为动画的类名                                                 string
		 * innerTime为内层盒子动画时间 （秒）                          number
		 * maskTime为遮罩盒子动画时间 （秒）                              number
		 * speed为动画速度                                                                     string
		 * */
		animateIn: function(innerId, maskId, innerActionName, maskActionName, innerTime, maskTime, speed) {
			var self = this;
			var elementId = document.getElementById(innerId);
			var maskId = document.getElementById(maskId);
			//操作系统
			var osName = plus.os.name.toLocaleLowerCase();
			if(osName == "ios") {
				innerTime = '.3';
				maskTime = '.1';
			}
			elementId.style.display = 'block';
			maskId.style.display = 'block';
			maskId.style.animation = maskActionName + " " + maskTime + "s" + " " + speed;
			elementId.style.animation = innerActionName + " " + innerTime + "s" + " " + speed;
		},
		/* 	
		 * 动画离开
		 * innerId为想要添加动画的盒子id            string
		 * maskId为遮罩盒子id                    string
		 * actionName为动画的类名                                                    string
		 * innerTime为内层盒子动画时间 （秒）                          number
		 * maskTime为遮罩盒子动画时间 （秒）                              number
		 * speed为动画速度                                                                    string
		 * */
		animateOut: function(innerId, maskId, innerActionName, maskActionName, innerTime, maskTime, speed) {
			var self = this;
			var elementId = document.getElementById(innerId);
			var maskId = document.getElementById(maskId)
			elementId.style.animation = innerActionName + " " + innerTime + "s" + " " + speed;
			maskId.style.animation = maskActionName + " " + maskTime + "s" + " " + speed;
			maskId.style.display = 'none';
			elementId.style.display = 'none';
		},
		/**
		 * 重新选择代办
		 */
		reCreateEntrustment: function() {
			var self = this;
			//代理人列表
			BMCW.openWindow(BMCW.routeCfg.useragententrustlist, {
				extras: {
					EntrustID: 0,
					OfficeId: self.Param.RegOfficeID,
					SourcePage: BMCW.routeCfg.pnlentrustmentlist.id,
					CallBack: "page.addRegisterInfo"
				}
			});
		},
		addRegisterInfo: function(obj) {
			var self = this;
			if(self.Param.IsReCreate == 1) {
				BMCW.toast('单据已经重新预约过,不能再次预约。')
				return false;
			}

			BMCW.Ajax.ajax({
				url: self.Route.ResetEntrusment,
				type: "POST",
				data: {
					ApplyId: self.Param.ApplyId,
					ExpertUserId: obj.userId //人工取消
				},
				success: function(rdata) {
					if(rdata.status == 0) {
						self.closeMask();
						self.initView();
					} else {
						BMCW.toast(rdata.message);
					}
				}
			});
		},
		/**
		 * 评价
		 */
		evaluateEntrustment: function() {
			var self = this;
			if(self.Param.StarIndex <= 0) {
				BMCW.toast('请评价星级');
				return;
			}

			BMCW.Ajax.ajax({
				url: self.Route.EvaluateEntrustment,
				type: "POST",
				data: {
					ApplyId: self.Param.ApplyId,
					ExpertUserId: self.Param.ExpertUserId, //专业代办
					EvaluateUserId: BMCW.getLocalStorage("CurrentUserID"),
					EvaluateDesc: self.Param.StarDesc[self.Param.StarIndex - 1],
					CustomContent: document.getElementById("areaDesc").value || "",
					EvaluateStar: self.Param.StarIndex,
					TagIds: self.Param.Tags.join(",")
				},
				success: function(rdata) {
					if(rdata.status == 0) {
						self.closeMask();
						self.initView();
					} else {
						BMCW.toast(rdata.message);
					}
				}
			});
		},
		/**
		 * 删除
		 */
		deleteEntrustment: function(appId) {
			var self = this;
			var btnArray = ['取消', '确认'];
			BMCW.confirm('删除订单后将无法恢复，您也无法再对他进行投诉。', '<img src="../../../images/bjcg-icon-tip.jpg" alt=""/>', btnArray, function(e) {
				if(e.index == 1) {
					BMCW.Ajax.ajax({
						url: self.Route.DeleteEntrustment,
						type: "POST",
						data: {
							ApplyId: appId,
							CancelType: 1 //人工取消
						},
						success: function(rdata) {
							if(rdata.status == 0) {
								self.initView();
							} else {
								BMCW.toast(rdata.message);
							}
						}
					});
				}
			}, 'div');

		},
		/**
		 * 获取用户信息
		 */
		getUserAgentInfo: function(userId, idx) {
			var self = this;
			BMCW.Ajax.ajax({
				url: self.Route.GetUserAgentInfo,
				data: {
					userId: userId
				},
				success: function(rdata) {
					if(rdata.status == 0) {
						var item = rdata.data;
						var userFaith = item.EvaluationLevel * 20;
						if(BMCW.isNullOrEmpty(item.UserHead)) {
						    document.getElementById("img" + idx).style.background ="url('../../../images/bjcg-touxiang-no-login.png') center center no-repeat";
							document.getElementById("img" + idx).style.backgroundSize='cover';
						} else {
						    document.getElementById("img" + idx).style.background ='url('+item.UserHead+') center center no-repeat';
							document.getElementById("img" + idx).style.backgroundSize='cover';
						}
						var usrName = '';
						if(!BMCW.isNullOrEmpty(item.UserTrueName)) {
							usrName = item.UserTrueName.substring(0, 1);
						}
						if(item.UserGender == 2) {
							usrName += '女士';
						} else {
							usrName += '先生';
						}
						document.getElementById("name" + idx).innerHTML = usrName;
						document.getElementById("evalate" + idx).innerHTML = item.EvaluationLevel;
						document.getElementById("ordernum" + idx).innerHTML = item.OrderNumer;
						document.getElementById("userfaith" + idx).innerHTML = userFaith;
						document.getElementById("aphone" + idx).href = "tel:" + item.Mobile;
					} else {
						BMCW.toast(rdata.message);
					}
				}
			});
		},
		getUserEvaluation: function() {
			var self = this;
			BMCW.Ajax.ajax({
				url: self.Route.GetUserEvaluation,
				showLoading: false,
				data: {
					applyId: self.Param.ApplyId
				},
				success: function(rdata) {
					if(rdata.status == 0) {
						if(!BMCW.isNullOrEmpty(rdata.data)) {
							self.showStar(rdata.data.UserLevel);
							self.showTags(rdata.data.UserLevel, rdata.data.TagIds)
							self.Param.isEvaluate = true;
						} else {
							self.Param.isEvaluate = false;
							document.getElementById("btnContainer").style.display = "block";
						}
					} else {
						self.Param.isEvaluate = false;
						document.getElementById("btnContainer").style.display = "block";
						BMCW.toast(rdata.message);
					}
				}
			});
		},
		/**
		 * 显示星级
		 * @param {Object} index
		 */
		showStar: function(index) {
			var self = this;
			var starBox = document.getElementById('iconContainer');
			var children = starBox.children;
			var description = document.getElementById('starDesc');
			//先清空
			for(var i = 0; i < index; i++) {
				children[i].classList.add('mui-icon-star');
				children[i].classList.remove('mui-icon-star-filled');
			}
			//后填充
			for(var i = 0; i < index; i++) {
				children[i].classList.remove('mui-icon-star');
				children[i].classList.add('mui-icon-star-filled');
			}
			description.innerHTML = self.Param.StarDesc[index - 1];
			document.getElementById("btnContainer").style.display = "none";
		},
		/**
		 * 清空星级选择
		 */
		clearStar: function() {
			var self = this;
			var starBox = document.getElementById('iconContainer');
			var children = starBox.children;
			//先清空
			for(var i = 0; i < children.length; i++) {
				children[i].classList.add('mui-icon-star');
				children[i].classList.remove('mui-icon-star-filled');
			}
		},
		/**
		 * 展示委托申请信息
		 * @param {Object} item
		 */
		getEntrusmentInfo: function(Id, idx) {
			var self = this,
				conList = self.Param.EntrustList;
			for(var i = 0; i < conList.length; i++) {
				if(conList[i].ApplyId == Id) {
					var item = conList[i];
					var weekday = ["周日", "周一", "周二", "周三", "周四", "周五", "周六"];
					//组合时间格式
					var hh = ''
					var bdate = BMCW.convertToDate(item.RegStartDate);
					var edate = BMCW.convertToDate(item.RegEndDate);
					var wk = weekday[bdate.getDay()];
					if(bdate.getHours() > 12) {
						hh = ' 下午 ';
					} else {
						hh = ' 上午 ';
					}
					var dt = BMCW.formatDate(bdate, "HH:mm") + '-' + BMCW.formatDate(edate, "HH:mm");
					document.getElementById("wk" + idx).innerHTML = wk;
					document.getElementById("hh" + idx).innerHTML = hh;
					document.getElementById("dt" + idx).innerHTML = dt;
					document.getElementById("biztypename" + idx).innerHTML = item.BizTypeName;
					document.getElementById("officename" + idx).innerHTML = item.OfficeName;
					break;
				}
			}
		},
		/**
		 * 缓存列表
		 * @param {Object} data
		 */
		updateEntrustList: function(data) {
			var self = this;
			if(self.Param.PageIndex == 1) {
				self.Param.EntrustList = [];
			}
			for(var i = 0; i < data.length; i++) {
				var idx = self.existItem(self.Param.EntrustList, data[i].ApplyId);
				if(idx > 0) {
					self.Param.EntrustList[idx] = data[i];
				} else {
					self.Param.EntrustList.push(data[i]);
				}
			}
		},
		/**
		 * 判断是否存在
		 * @param {Object} items
		 * @param {Object} Id
		 */
		existItem: function(items, Id) {
			var result = 0;
			for(var i = 0; i < items.length; i++) {
				if(items[i].ApplyId == Id) {
					result = i;
					break;
				}
			}
			return result;
		},
		/**
		 * 获取星级和标签关系
		 */
		GetStarTags: function() {
			var self = this;
			BMCW.Ajax.ajax({
				showLoading: false,
				url: self.Route.GetStarTags,
				success: function(rdata) {
					console.log(JSON.stringify(rdata))
					if(rdata.status == 0) {
						self.Param.StarTags = rdata.data;
					} else {
						BMCW.toast(rdata.message);
					}
				}
			});
		},
		/*
		 * 修改标签
		 */
		changeTags: function(idx) {
			var self = this,
				tags = self.Param.StarTags;
			var tpl = '';
			for(var i = 0; i < tags.length; i++) {
				if(idx == tags[i].EvaluationStar) {
					tpl += '<li onclick="page.clickTag(' + tags[i].EvaluationTagID + ',this);" class="star-tag-box-text">' + tags[i].TagDesc + '</li>';
				}
			}
			console.log(tpl)
			document.getElementById("starTagUlOne").innerHTML = tpl;
			document.getElementById("divStarArea").style.display = "block";
		},
		/**
		 * 单击标签
		 * @param {Object} idx
		 * @param {Object} elem
		 */
		clickTag: function(idx, elem) {
			var self = this;
			if(elem.classList.contains("active")) {
				elem.classList.remove("active");
				var index = self.Param.Tags.indexOf(idx);
				if(index > -1) {
					self.Param.Tags.splice(index, 1);
				}
			} else {
				elem.classList.add("active");
				self.Param.Tags.push(idx);
			}
		},
		/**
		 * 显示评价
		 * @param {Object} idx
		 * @param {Object} tagId
		 */
		showTags: function(idx, tagIds) {
			var self = this,
				tags = self.Param.StarTags;
			var tpl = '';
			if(!BMCW.isNullOrEmpty(tagIds)) {
				tagIds = tagIds.split(",");
				for(var j = 0; j < tagIds.length; j++) {
					for(var i = 0; i < tags.length; i++) {
						if(idx == tags[i].EvaluationStar && tagIds[j] == tags[i].EvaluationTagID) {
							tpl += '<li class="star-tag-box-text">' + tags[i].TagDesc + '</li>';
						}
					}
				}
			}

			document.getElementById("starTagUlOne").innerHTML = tpl;
		},
		closeMask: function() {
			var self = this;
			self.animateOut("box1", 'bjcgMask', 'fadeInDownBig', 'fadeOut', .4, .2, "");
			self.animateOut("box2", 'bjcgMask', 'fadeInDownBig', 'fadeOut', .4, .2, "");
			self.animateOut("box3", 'bjcgMask', 'fadeInDownBig', 'fadeOut', .4, .2, "");
			self.animateOut("box4", 'bjcgMask', 'fadeInDownBig', 'fadeOut', .4, .2, "");
		}
	});

	//实例化类
	window.page = new BMCW.BasePage();

})(mui, BMCW);