(function($, BMCW) {
	"use strict";

	BMCW.augment(BMCW.BasePage, {
		/**
		 * 页面路由
		 */
		Route: {
			GetMessageTypePage: "/Message/GetMessageTypePage", //获取全部列表
			GetMessageTotalType: "/Message/GetMessageTotalType", //按类型查询未读消息
			DeleteMessage: "/Message/DeleteMessage"
		},
		/**
		 * 参数
		 */
		Param: {
			PageIndex: 1, //页码
			PageSize: 10, //页大小
			PageCount: 0, //总数量
			MessageType: 1, //类型		
			isInit: true,
			FirstShow: true
		},
		/**
		 * 初始化方法
		 * 页面参数初始化  页面方法初始化  等
		 * @param {Object} options
		 */
		init: function(options) {
			var self = this,
				wb = plus.webview.currentWebview();

			//设置滚动条隐藏 不可缩放
			plus.webview.currentWebview().setStyle({
				scrollIndicator: "none",
				scalable: false
			});

			mui.init({
				keyEventBind: {
					backbutton: false //关闭back按键监听
				}
			});

			//下拉刷新
			BMCW.setCirclePullToRefresh(function() {
				if(BMCW.getLocalStorage("CurrentUserID") > 0) {
					self.Param.PageIndex = 1;
					self.getMessageList(true);
					self.getMessageTotalType();
				}
			});

			//滑动底部自动分页查询
			document.addEventListener("plusscrollbottom", function() {
				if(self.Param.PageIndex < self.Param.PageCount) {
					self.Param.PageIndex += 1;
					self.getMessageList(true);
				}
			}, false);
		},
		/**
		 * 事件绑定
		 * @param {Object} options
		 */
		initEvent: function(options) {
			var self = this;
			var wb = plus.webview.currentWebview();

			wb.addEventListener('show', function(e) {
				//延迟加载数据
				if(self.Param.FirstShow) {
					self.initShowView();
					self.Param.FirstShow = false;
				}
				if(BMCW.getLocalStorage("CurrentUserID") < 1) {
					document.getElementById("spn_messagetype1").style.display = "none";
					document.getElementById("spn_messagetype2").style.display = "none";
					document.getElementById("muiContent").innerHTML = "";
					document.getElementById("div_nodata").style.display = "";
				} else {
					self.Param.PageIndex = 1;
					self.getMessageList.call(self, false);
					self.getTotalList.call(self);
				}
			}, false);

			//table跳转
			mui("#ul_messagetype").on("tap", "li", function() {
				if(this.classList.contains("active")) {
					return false;
				} else {
					var chd = document.getElementById("ul_messagetype").children;
					for(var i = 0; i < chd.length; i++) {
						if(chd[i].classList.contains("active")) {
							chd[i].classList.remove("active");
							break;
						}
					}
					this.classList.add("active");
					self.Param.PageIndex = 1;
					self.Param.MessageType = this.id.substring(14);
					self.getMessageList.call(self, true);
					self.getTotalList.call(self);
				}
			});
		},
		/**
		 * 渲染页面
		 * 通过ajax对页面加载显示
		 * @param {Object} options
		 */
		initShowView: function(options) {
			var self = this;
			document.getElementById("li_messagetype" + self.Param.MessageType).classList.add("active");
			if(BMCW.getLocalStorage("CurrentUserID") > 0) {
				self.getMessageList(false);
				self.getTotalList();
			}
		},
		initView: function(options) {
			var self = this;
			if(BMCW.getLocalStorage("CurrentUserID") > 0) {
				self.getTotalList();
			}
		},
		getTotalList: function() {
			var self = this;
			self.getMessageTotalType();
		},
		/**
		 * 获取全部列表
		 * @param {Boolean} showLoading
		 */
		getMessageList: function(showLoading) {
			var self = this;
			BMCW.Ajax.ajax({
				url: self.Route.GetMessageTypePage,
				showLoading: showLoading,
				data: {
					userID: BMCW.getLocalStorage("CurrentUserID"),
					messageType: self.Param.MessageType,
					pageIndex: self.Param.PageIndex,
					pageSize: self.Param.PageSize
				},
				success: function(rdata) {
					if(rdata.status == 0) {
						//如果返回成功,Message赋值总记录数	
						self.renderView(rdata.data, rdata.message);
					} else {
						BMCW.toast(rdata.message);
					}
				}
			});
		},
		/**
		 * 根据类型汇总
		 */
		getMessageTotalType: function() {
			var self = this;
			BMCW.Ajax.ajax({
				url: self.Route.GetMessageTotalType,
				showLoading: false,
				data: {
					userID: BMCW.getLocalStorage("CurrentUserID")
				},
				success: function(rdata) {
					if(rdata.status == 0) {
						//如果返回成功,Message赋值总记录数	
						self.renderMessage(rdata.data);
					} else {
						BMCW.toast(rdata.message);
					}
				}
			});
		},
		/**
		 * 消息汇总
		 * @param {Object} data
		 */
		renderMessage: function(data) {
			var showType1 = false,
				showType2 = false;
			var wb = plus.webview.getLaunchWebview();
			if(data.length) {
				for(var i = 0; i < data.length; i++) {
					switch(data[i].MessageType) {
						case 1: //已预约
							document.getElementById("spn_messagetype1").innerHTML = data[i].CT;
							document.getElementById("spn_messagetype1").style.display = "";
							showType1 = true;
							break;
						case 2:
							document.getElementById("spn_messagetype2").innerHTML = data[i].CT;
							document.getElementById("spn_messagetype2").style.display = "";
							showType2 = true;
							break;
					}
				}
				wb.evalJS("page.updateSubNview(true)");
			} else {
				wb.evalJS("page.updateSubNview(false)");
			}
			if(showType1 == false) {
				document.getElementById("spn_messagetype1").style.display = "none";
			}
			if(showType2 == false) {
				document.getElementById("spn_messagetype2").style.display = "none";
			}
		},
		/**
		 * 渲染页面
		 * @param {Object} data
		 */
		renderView: function(data, pageCount) {
			var self = this,
				content = document.getElementById("muiContent");

			//如果首页,则清空内容
			if(self.Param.PageIndex == 1) {
				content.innerHTML = "";
				if(data.length < 1) {
					document.getElementById("div_nodata").style.display = "";
				} else {
					document.getElementById("div_nodata").style.display = "none";
				}
			}

			if(data.length > 0) {
				self.Param.PageCount = BMCW.getPageCount(parseInt(pageCount), self.Param.PageSize);

				for(var i = 0; i < data.length; i++) {
					content.innerHTML += self.getTpl(data[i]);
				}
			}
		},
		/**
		 * 获取模版
		 */
		getTpl: function(item) {
			var self = this;

			var tpl = '<div class="bjcg-yuyue-item">';
			if(item.IsRead == 1) {
				tpl += '<i id="i_spit' + item.MessageID + '" class="bjcg-red-dian"></i>';
			}
			tpl += '<h4 onclick="page.messageDetail(' + item.MessageID + ',' + item.MessageType + ');" class="bjcg-yuyue-item-h4">' + item.MessageTitle + '</h4>';
			tpl += '<p onclick="page.messageDetail(' + item.MessageID + ',' + item.MessageType + ');" class="bjcg-yuyue-item-p mui-ellipsis-2">【' + item.SendDate.substring(5) + '】' + item.MessageDesc + '</p>';
			tpl += '<a onclick="page.deleteMessage(' + item.MessagePoolID + ',' + item.MessageType + ');"  class="bjcg-yuyue-item-a" href="###"><i class="icon iconfont icon-shanchu"></i></a>';
			tpl += '</div>';
			return tpl;
		},
		/**
		 * 跳转详情
		 * @param {Object} regId
		 */
		messageDetail: function(regId, regType) {
			var self = this;
			var elem = document.getElementById("i_spit" + regId);
			if(elem) {
				elem.style.display = "none";
			}
			BMCW.routeCfg.messsagedetail.titleNView.titleText = self.getTypeText(regType);
			BMCW.openWindow(BMCW.routeCfg.messsagedetail, {
				extras: {
					MessageID: regId
				}
			});
		},
		/**
		 * 删除消息
		 * @param {Object} msgId
		 */
		deleteMessage: function(msgId) {
			var self = this;
			BMCW.confirm("确认删除消息?", '<img src="../../../images/bjcg-icon-tip.jpg" alt=""/>', "", function(e) {
				if(e.index == 1) {
					BMCW.removeTabMask();
					BMCW.Ajax.ajax({
						url: self.Route.DeleteMessage,
						type: "POST",
						data: {
							Id: msgId
						},
						success: function(rdata) {
							if(rdata.status == 0) {
								BMCW.toast("删除成功");
								self.Param.PageIndex = 1;
								self.getMessageList(false);
								self.getTotalList();
							} else {
								BMCW.toast(rdata.message);
							}
						}
					});
				} else {
					BMCW.removeTabMask();
				}
			});
			BMCW.addTabMask();
		},
		/**
		 * 获取消息枚举
		 * @param {Object} t
		 */
		getTypeText: function(t) {
			var txt = "其他";
			if(t == 1) {
				txt = "预约消息";
			} else if(t == 2) {
				txt = "通知消息";
			}
			return txt;
		}
	});

	//实例化类
	window.page = new BMCW.BasePage();

})(mui, BMCW);