(function($, BMCW) {
	"use strict";

	BMCW.augment(BMCW.BasePage, {
		/**
		 * 页面路由
		 */
		Route: {
			createRecharge: "/account/CreateRecharge", //创建充值订单
			payRecharge: "/account/PayRecharge", //充值接口	
			GetConsultantList: "/Personal/GetConsultantList" //获取保证金列表
		},
		/**
		 * 参数
		 */
		Param: {
			pays: {}, //支付通道
			payPrice: 2000, //支付金额		
			checkFlag: true, //重置协议是否勾选
			SourcePage: "", //来源页面
			CallBack: "" //回调方法
		},
		/**
		 * 初始化方法
		 * 页面参数初始化  页面方法初始化  等
		 * @param {Object} options
		 */
		init: function(options) {
			var self = this,
				wb = plus.webview.currentWebview();
			self.Param.SourcePage = wb.SourcePage;
			self.Param.CallBack = wb.CallBack;
			mui.init({
				swipeBack: true //启用右滑关闭功能
			});
		},
		/**
		 * 事件绑定
		 * @param {Object} options
		 */
		initEvent: function(options) {
			var self = this;
			//阅读协议复选框
			var rowXieYi = document.querySelector(".bjcg-fwtk-new-box");
			var iconBox = document.getElementsByClassName('icon-bjcg-yes');
			if(rowXieYi) {
				rowXieYi.addEventListener("tap", function() {
					self.Param.checkFlag = !self.Param.checkFlag;
					if(self.Param.checkFlag) {
						iconBox[0].classList.add('active');
					} else {
						iconBox[0].classList.remove('active');
					}
				}, false);
			}
			//充值的常见问题
			document.getElementById("link_rechargeComProblem").addEventListener('tap', function() {
				BMCW.openWindow(BMCW.routeCfg.rechargeComProblem);
			}, false);

			//支付条款的跳转
			document.getElementById("a_rechargeClause").addEventListener('tap', function(e) {
				BMCW.openWindow(BMCW.routeCfg.rechargeClause);
				e.stopPropagation();
			}, false);

			//微信支付
			document.getElementById("li_wxpay").addEventListener("tap", function() {
				var ichk = document.getElementById("i_wxpay");
				if(ichk.classList.contains("checked")) {
					return false;
				}
				ichk.classList.add("checked");
				document.getElementById("i_alipay").classList.remove("checked");
			}, false);

			//阿里支付
			document.getElementById("li_alipay").addEventListener("tap", function() {
				var ichk = document.getElementById("i_alipay");
				if(ichk.classList.contains("checked")) {
					return false;
				}
				ichk.classList.add("checked");
				document.getElementById("i_wxpay").classList.remove("checked");
			}, false);

			//确认支付
			document.getElementById("btn_sure").addEventListener("tap", function() {
				self.pay.call(self);
			}, false);
		},
		/**
		 * 渲染页面
		 * 通过ajax对页面加载显示
		 * @param {Object} options
		 */
		initView: function(options) {
			var self = this;
			plus.payment.getChannels(function(channels) {
				var content = document.getElementById('dcontent');
				for(var i in channels) {
					var channel = channels[i];
					if(channel.id == 'qhpay' || channel.id == 'qihoo') { // 过滤掉不支持的支付通道：暂不支持360相关支付
						continue;
					}
					switch(channel.id) {
						case "qhpay":
						case "qihoo":
							break;
						case "alipay":
							document.getElementById("li_alipay").style.display = "";
							break;
						case "wxpay":
							document.getElementById("li_wxpay").style.display = "";
							break;
					}
					self.Param.pays[channel.id] = channel;
				}
			}, function(e) {
				outLine('获取支付通道失败：' + e.message);
			});

			self.addActionLog("accountRechargeInit");
		},
		/**
		 * 立即充值
		 */
		pay: function() {
			var self = this;
			var id = "alipay";
			var payType = 2;
			if(document.getElementById("i_wxpay").classList.contains("checked")) {
				id = "wxpay";
				payType = 1;
			}
			if(!self.Param.checkFlag) {
				BMCW.toast("请同意充值条款和协议");
				return false;
			}
			BMCW.Ajax.ajax({
				useBmcw: true,
				type: "post",
				url: self.Route.createRecharge,
				data: {
					UserID: BMCW.getLocalStorage("BMCWUserID") || 0,
					Amount: self.Param.payPrice,
					PayType: payType
				},
				success: function(rdata) {
					if(rdata.status == 0) {
						var rechargeId = rdata.data;
						self.payActual.call(self, rechargeId, id, payType);
					}
				}
			});
		},
		/**
		 *  实际充值方法
		 * @param {Object} rechargeId
		 * @param {Object} payChannelId
		 * @param {Object} payType
		 */
		payActual: function(rechargeId, payChannelId, payType) {
			var self = this;
			BMCW.Ajax.ajax({
				useBmcw: true,
				type: "post",
				url: self.Route.payRecharge,
				data: {
					rechargeId: rechargeId,
					payType: payType,
				},
				success: function(rdata) {
					if(rdata.status == 0) {
						plus.payment.request(self.Param.pays[payChannelId], rdata.data.Result, function(result) {
							self.addActionLog("accountRechargeSuccess");
							var wb1 = plus.webview.getWebviewById(BMCW.routeCfg.myAccount.id);
							if(wb1 != null) {
								wb1.reload(true);
								BMCW.closeWebview(BMCW.routeCfg.accountRecharge.id);
							} else {
								BMCW.openWindow(BMCW.routeCfg.myAccount);
							}

						}, function(e) {
							BMCW.openWindow(BMCW.routeCfg.payerror, {
								extras: {
									code: e.code,
									message: e.message,
								}
							});
						});
					} else {
						self.addActionLog("accountRechargeFail");
						BMCW.toast(rdata.message);
					}
				}
			});
		},
		addActionLog: function(msg) {
			var apperrorUrl =  "/Common/AddActLog";
			var options = {
				url: apperrorUrl,
				data: {
					tk: "pay",
					msg: msg
				},
				type: "POST",
				showLoading: false,
				success: function(result) {
				console.log(result)
				},
				error: function(date) {console.log(date)}
			};
			BMCW.Ajax.ajax(options);
		}

	});
	//实例化类
	window.page = new BMCW.BasePage();

})(mui, BMCW);