(function($, BMCW) {
	"use strict";

	BMCW.augment(BMCW.BasePage, {
		/**
		 * 页面路由
		 */
		Route: {
			getSummary: "/account/GetSummary", //获取账户概览
			getTradeList: "/account/LogList", //获取交易列表	
			applyRefund: "/account/ApplyRefund", //申请退还保证金	
		},
		/**
		 * 参数
		 */
		Param: {
			PageIndex: 1, //页码
			PageSize: 5, //页大小
			PageCount: 0, //总数量					
			SourcePage: "", //来源页面
			CallBack: "" //回调方法
		},
		/**
		 * 初始化方法
		 * 页面参数初始化  页面方法初始化  等
		 * @param {Object} options
		 */
		init: function(options) {
			var self = this,
				wb = plus.webview.currentWebview();
			self.Param.SourcePage = wb.SourcePage;
			self.Param.CallBack = wb.CallBack;
		},
		/**
		 * 事件绑定
		 * @param {Object} options
		 */
		initEvent: function(options) {
			var self = this;
			document.getElementById("btnRecharge").addEventListener("tap", function() {
				BMCW.openWindow(BMCW.routeCfg.accountRecharge, {
					extras: {
						SourcePage: BMCW.routeCfg.accountRecharge.id,
						CallBack: "page.initView"
					}
				});
			}, false);

			document.getElementById("btnMore").addEventListener('tap', function() {
				BMCW.openWindow(BMCW.routeCfg.myAccountList);
			}, false);

			//保证金常见问题
			document.getElementById("link_accountComProblem").addEventListener('tap', function() {
				BMCW.openWindow(BMCW.routeCfg.accountComProblem);
			}, false);

			$('.mui-content-padded').on('tap', '#btnApplyRefund', function() {
				if(document.getElementById("btnApplyRefund").classList.contains("bjcg-disabled")) {
					return false;
				}

				var btnArray = ['取消', '退款'];
				BMCW.confirm('退还保证金后，将无法接受系统派单，并失去认证车务代办福利，退款申请后5-7个工作日，退还到原付款账户，是否申请退还？', '<img src="../../../images/bjcg-icon-tip.jpg" alt=""/>', btnArray, function(e) {
					if(e.index == 1) {
						self.applyRefund();
					}
				}, '信息确认');
			});

		},
		/**
		 * 渲染页面
		 * 通过ajax对页面加载显示
		 * @param {Object} options
		 */
		initView: function(options) {
			var self = this;

			self.getUserAccountSummary();
			self.getPageData();
			//关闭保证金说明页面
			BMCW.closeWebview(BMCW.routeCfg.cashDepositServer.id, "none");
			BMCW.closeWebview(BMCW.routeCfg.userauthresult.id, "none");
			BMCW.closeWebview(BMCW.routeCfg.accountRecharge.id, "none");
		},
		/**
		 * 获取账户概览
		 */
		getUserAccountSummary: function() {
			var self = this;
			var userID = BMCW.getLocalStorage("BMCWUserID") || 0;
			BMCW.Ajax.ajax({
				useBmcw: true,
				showLoading: false,
				url: self.Route.getSummary,
				data: {
					userID: userID
				},
				success: function(rdata) {
					if(rdata.status == 0) {
						var response = rdata.data;
						document.getElementById("labAccountTotal").innerText = response.TotalAccount;
					} else {
						BMCW.toast(rdata.message);
					}
				}
			});
		},

		/**
		 * 申请退还保证金
		 */
		applyRefund: function() {
			var self = this;
			var userID = BMCW.getLocalStorage("BMCWUserID") || 0;
			BMCW.Ajax.ajax({
				type: "post",
				useBmcw: true,
				url: self.Route.applyRefund,
				data: {
					userID: userID
				},
				success: function(rdata) {
					if(rdata.status == 0) {
						var response = rdata.data;
						BMCW.toast(rdata.message)
					} else {
						BMCW.toast(rdata.message, {
							duration: "long"
						});
					}
				}
			});
		},
		/**
		 * 获取分页数据
		 */
		getPageData: function() {
			var self = this;

			var pageCondition = {
				UserId: BMCW.getLocalStorage("BMCWUserID") || 0, //用户ID
				page: self.Param.PageIndex, //页码
				rows: self.Param.PageSize, //页大小
				PageCount: 0, //总页数
			};

			BMCW.Ajax.ajax({
				useBmcw: true,
				url: self.Route.getTradeList,
				data: pageCondition,
				success: function(rdata) {
					if(rdata.status == 0) {
						var response = rdata.data;
						var total = response.total;
						var pageData = response.items;
						self.renderListView(pageData, total);
					} else {
						BMCW.toast(rdata.message);
					}
				}
			});
		},
		renderListView: function(data, totalCount) {
			var self = this;
			var szHtmlAll = "";
			var ulListView = document.getElementById("ulListView");
			if(self.Param.PageIndex == 1) {
				ulListView.innerHTML = "";
				if(data.length < 1) {
					document.getElementById("div_nodata").style.display = "";
					document.getElementById("btnApplyRefund").classList.add("bjcg-disabled");
					document.getElementById("btnMore").style.display = "none";
				} else {
					document.getElementById("div_nodata").style.display = "none";
					document.getElementById("btnApplyRefund").classList.remove("bjcg-disabled");
					document.getElementById("btnMore").style.display = "";
				}
			}
			if(data.length > 0) {
				self.Param.PageCount = BMCW.getPageCount(parseInt(totalCount), self.Param.PageSize);
				for(var i = 0; i < data.length; i++) {
					var item = data[i];
					szHtmlAll += self.getTpl(data[i]);
				}
				ulListView.innerHTML += szHtmlAll;
			}
		},
		getTpl: function(item) {
			var tpl = '<li class="new-my-account-content-list-item list-item-flex">';
			tpl += '<div class="new-my-account-content-list-item-left">';
			tpl += '<p class="item-left-title">' + item.TypeName + '</p>';
			tpl += '<span class="item-left-date">' + item.DateTimeText + '</span>';
			tpl += '</div>';
			tpl += '<div class="new-my-account-content-list-item-right">';
			tpl += '<span class="item-right-title">' + item.MoneyText + '</span>';
			tpl += '</div>';
			tpl += '</li>';
			return tpl;
		}

	});
	//实例化类
	window.page = new BMCW.BasePage();

})(mui, BMCW);