(function($, BMCW) {
	"use strict";

	BMCW.augment(BMCW.BasePage, {
		/**
		 * 页面路由
		 */
		Route: {
			getTradeList: "/account/LogList" //获取交易列表				
		},
		/**
		 * 参数
		 */
		Param: {
			PageIndex: 1, //页码
			PageSize: 10, //页大小
			PageCount: 0, //总数量		
			SourcePage: "", //来源页面
			CallBack: "" //回调方法
		},
		/**
		 * 初始化方法
		 * 页面参数初始化  页面方法初始化  等
		 * @param {Object} options
		 */
		init: function(options) {
			var self = this,
				wb = plus.webview.currentWebview();
			self.Param.SourcePage = wb.SourcePage;
			self.Param.CallBack = wb.CallBack;

			//设置滚动条隐藏 不可缩放
			plus.webview.currentWebview().setStyle({
				scrollIndicator: "none",
				scalable: false
			});
		},
		/**
		 * 事件绑定
		 * @param {Object} options
		 */
		initEvent: function(options) {
			var self = this;

			//下拉刷新
			BMCW.setCirclePullToRefresh(function() {
				if(BMCW.getLocalStorage("CurrentUserID") > 0) {
					self.Param.PageIndex = 1;
					self.getPageData();
				}
			});

			//滑动底部自动分页查询
			document.addEventListener("plusscrollbottom", function() {
				if(self.Param.PageIndex < self.Param.PageCount) {
					self.Param.PageIndex += 1;
					self.getPageData();
				}
			}, false);
		},
		/**
		 * 渲染页面
		 * 通过ajax对页面加载显示
		 * @param {Object} options
		 */
		initView: function(options) {
			var self = this;
			if(BMCW.getLocalStorage("CurrentUserID") > 0) {
				self.getPageData();
			}
		},

		/**
		 * 获取分页数据
		 */
		getPageData: function() {
			var self = this;

			var pageCondition = {
				UserId: BMCW.getLocalStorage("BMCWUserID") || 0, //用户ID
				page: self.Param.PageIndex, //页码
				rows: self.Param.PageSize, //页大小
				PageCount: 0, //总页数
			};

			BMCW.Ajax.ajax({
				useBmcw: true,
				url: self.Route.getTradeList,
				data: pageCondition,
				success: function(rdata) {
					if(rdata.status == 0) {
						var response = rdata.data;
						var total = response.total;
						var pageData = response.items;
						self.renderListView(pageData, total);
					} else {
						BMCW.toast(rdata.message);
					}
				}
			});
		},

		renderListView: function(data, totalCount) {
			var self = this;
			var szHtmlAll = "";
			var ulListView = document.getElementById("ulListView");
			if(self.Param.PageIndex == 1) {
				ulListView.innerHTML = "";
				if(data.length < 1) {
					document.getElementById("div_nodata").style.display = "";
				} else {
					document.getElementById("div_nodata").style.display = "none";
				}
			}
			if(data.length > 0) {
				self.Param.PageCount = BMCW.getPageCount(parseInt(totalCount), self.Param.PageSize);
				for(var i = 0; i < data.length; i++) {
					var item = data[i];
					szHtmlAll += self.getTpl(data[i]);
				}
				ulListView.innerHTML += szHtmlAll;
			}
		},
		getTpl: function(item) {

			var tpl = '	<li class="transaction-details-item">';
			tpl += '	<div class="transaction-details-item-left">';
			tpl += '    <p>' + item.TypeName + '</p>';
			tpl += '	<span>' + item.DateTimeText + '</span>';
			tpl += '</div>';
			tpl += '<div class="transaction-details-item-right">';
			tpl += '	<span class="transaction-details-item-right-text">' + item.MoneyText + '</span>';
			tpl += '</div>';
			tpl += '</li>';
			return tpl;
		}
	});
	//实例化类
	window.page = new BMCW.BasePage();

})(mui, BMCW);