(function($, BMCW) {
	"use strict";

	BMCW.augment(BMCW.BasePage, {
		/**
		 * 页面路由
		 */
		Route: {
			GetUserInfor: "/Personal/GetUserInfor", //获取用户信息
			UpdateUserHead: "/Personal/UpdateUserHead" //上传头像
		},
		/**
		 * 参数
		 */
		Param: {
			SourcePage: "", //来源页面
			CallBack: "", //回调方法
			Data: {} //用户信息
		},
		/**
		 * 初始化方法
		 * 页面参数初始化  页面方法初始化  等
		 * @param {Object} options
		 */
		init: function(options) {
			var self = this,
				wb = plus.webview.currentWebview();
			self.Param.Data = wb.Data || {};
			self.Param.SourcePage = wb.SourcePage;
			self.Param.CallBack = wb.CallBack;
		},
		/**
		 * 事件绑定
		 * @param {Object} options
		 */
		initEvent: function(options) {
			var self = this;
			//修改用户名
			document.getElementById("li_username").addEventListener("tap", function() {
				BMCW.openWindow(BMCW.routeCfg.usernameedit, {
					extras: {
						UserName: self.Param.Data.UserName,
						SourcePage: BMCW.routeCfg.personaldetail.id,
						CallBack: "page.updateUserName"
					}
				});
			}, false);

			//修改密码
			document.getElementById("li_password").addEventListener("tap", function() {
				BMCW.openWindow(BMCW.routeCfg.passwordedit);
			}, false);

			//修改头像
			document.getElementById("li_userhead").addEventListener("tap", function() {
				self.showActionsheet();
			}, false);

			//退出
			document.getElementById("btn_exit").addEventListener("tap", function() {
				BMCW.setLocalStorage('CurrentUserID', 0);

				//调用回调函数,关闭当前页
				if(self.Param.SourcePage) {
					var callMethod = "page.exit();";
					var wb = BMCW.getWebviewById(self.Param.SourcePage);
					wb.evalJS(callMethod);
				}
				
				//去掉消息红点
				var wbc = plus.webview.getLaunchWebview();
				wbc.evalJS("page.updateSubNview(false)");

				BMCW.closeWebview(BMCW.routeCfg.personaldetail.id);

			}, false);

			//页面关闭前刷新我的页面
			mui.init({
				beforeback: function() {
					if(self.Param.SourcePage) {
						//调用回到函数,并关闭当前页
						var callMethod = BMCW.format("{0}({1})", self.Param.CallBack, JSON.stringify(self.Param.Data));
						var wb = BMCW.getWebviewById(self.Param.SourcePage);
						wb.evalJS(callMethod);
					}
				}
			});
		},
		/**
		 * 渲染页面
		 * 通过ajax对页面加载显示
		 * @param {Object} options
		 */
		initView: function(options) {
			var self = this,
				data = self.Param.Data;
			if(!BMCW.isNullOrEmpty(data.UserHead)) {
//				document.getElementById("img_userhead").src = data.UserHead;
				document.getElementById("img_userhead").style.background='url('+data.UserHead+') center center no-repeat';
				document.getElementById("img_userhead").style.backgroundSize='cover';
			}
			if(!BMCW.isNullOrEmpty(data.UserName)) {

				document.getElementById("spn_username").innerHTML = data.UserName;
			}
		},
		/**
		 * 显示选择框
		 */
		showActionsheet: function() {
			var self = this;
			var btnArray = [{
				title: "拍照"
			}, {
				title: "从相册选择"
			}];
			plus.nativeUI.actionSheet({
				title: "上传头像",
				cancel: "取消",
				buttons: btnArray
			}, function(e) {
				var index = e.index;
				switch(index) {
					case 0:
						break;
					case 1:
						self.imgCamera();
						break;
					case 2:
						self.galleryImgs();
						break;
				}
			});
		},
		/**
		 * 照相
		 */
		imgCamera: function() {
			var self = this;
			var cmr = plus.camera.getCamera(1);
			var imgName = new Date().getTime();
			plus.io.requestFileSystem(plus.io.PUBLIC_DOCUMENTS, function(fs) {
				cmr.captureImage(function(path) {
						plus.gallery.save(path, function(e) {
							console.log("图片保存到相册成功.");
						}, function(e) {
							console.log("图片保存到相册失败.");
						})
						self.getPrivatePath([path]);
					},
					function(error) {
						console.log("调用照相失败: " + error.message);
					}, {
						filename: fs.root.fullPath
					});
			}, function(e) {
				console.log("Request file system failed: " + e.message);
			});

		},
		/**
		 * 相册选取
		 */
		galleryImgs: function() {
			var self = this;
			plus.gallery.pick(function(e) {
				var fileArr = [];
				fileArr.push(e);
				self.getPrivatePath(fileArr);

			}, function(e) {
				console.log("取消选择图片");
			}, {
				filter: "image",
				multiple: false
			});
		},
		/**
		 * 获取私有路径
		 * @param {Object} files
		 */
		getPrivatePath: function(files) {
			var self = this;
			plus.io.requestFileSystem(plus.io.PRIVATE_DOC,
				function(fs) {
					fs.root.getDirectory(fs.root.fullPath, {
							create: true //如果不存在,则创建
						},
						function(dir) {
							var tArray = []; //图片像素太大,在批量上传之前把相片先压缩,然后保存的程序私有路径，然后再统一删除
							for(var i in files) {
								var sPath = files[i];
								var tPath = fs.root.toLocalURL() + self.getFileName(sPath); //ios只支持绝对路径
								self.compressPhoto(sPath, tPath, tArray, files.length);
							}
						},
						function(e) {
							console.log("创建/获取目录失败:" + e.message)
						});
				},
				function(e) {
					console.log("获取文件私有路径失败:" + e.message);
				});
		},
		/**
		 * 图片压缩
		 * @param {Object} sPath
		 * @param {Object} tPath
		 * @param {Object} tArray
		 * @param {Object} targetLength
		 */
		compressPhoto: function(sPath, tPath, tArray, targetLength) {
			var self = this;
			//必须声明新变量,否则js内存泄漏，filePath永远是最后一次传入值
			var fp = sPath,
				dfp = tPath;
			plus.zip.compressImage({
					src: fp,
					dst: dfp,
					quality: 20,
					overwrite: true
				},
				function() {
					tArray.push(dfp);
					if(tArray.length == targetLength) {
						//将相册选择的照片集，转换成string保存到localStorage中					
						self.fileUplaod(tArray);
					}
					console.log("文件压缩成功.");
				},
				function(error) {
					console.log("文件压缩失败:" + error.code + "," + error.message);
				});
		},
		/**
		 * 文件上传
		 * @param {Object} brandId
		 * @param {Object} serialId
		 * @param {Object} photoRemark
		 */
		fileUplaod: function(photos) {
			var self = this;
			var upurl = BMCW.baseUrl + self.Route.UpdateUserHead;
			var task = plus.uploader.createUpload(
				upurl, {
					method: "POST"
				},
				function(upload, status) {
					plus.nativeUI.closeWaiting();
					if(status == 200) {
						//返回的结果会有双引号
						var reg = new RegExp('"', "g");
						self.Param.Data.UserHead = upload.responseText.replace(reg, "");
						console.log(self.Param.Data.UserHead)
						document.getElementById("img_userhead").src = self.Param.Data.UserHead;
						self.deletePhoto();
					} else {
						console.log("文件上传失败.");
					}
				});

			if(photos.length) {
				for(var i = 0; i < photos.length; i++) {
					task.addFile(photos[i], {
						key: "key" + BMCW.getLocalStorage("CurrentUserID")
					})
				}
				task.addData('UserID', BMCW.getLocalStorage("CurrentUserID"));
				task.start();
				plus.nativeUI.showWaiting("照片正在上传中...");
			}

		},
		/**
		 * 删除私有目录中的文件
		 */
		deletePhoto: function() {
			plus.io.requestFileSystem(plus.io.PRIVATE_DOC,
				function(fs) {
					fs.root.removeRecursively(
						function() {
							console.log("删除目录成功:" + fs.root.fullPath);
						},
						function(e) {
							console.log("删除目录失败:" + e.message);
						});
				},
				function(e) {
					console.log("获取文件私有路径失败:" + e.message);
				});
		},
		/**
		 * 获取文件名
		 * @param {Object} filepath
		 */
		getFileName: function(filepath) {
			var pos = filepath.lastIndexOf("/");
			if(pos == -1) {
				pos = filepath.lastIndexOf("\\")
			}
			var filename = filepath.substring(pos + 1)
			return filename;
		},
		/**
		 * 更新用户名
		 * @param {Object} username
		 */
		updateUserName: function(username) {
			var self = this;
			self.Param.Data.UserName = username;
			document.getElementById("spn_username").innerHTML = username;
		}
	});

	//实例化类
	window.page = new BMCW.BasePage();

})(mui, BMCW);