(function($, BMCW) {
	"use strict";

	BMCW.augment(BMCW.BasePage, {
		/**
		 * 页面路由
		 */
		Route: {
			AddUserAuth: "/Personal/UserAuthApply",
			GetUserAuth: "/Personal/GetUserAuth"
		},
		/**
		 * 参数
		 */
		Param: {
			ImageArr: {}, //图片对象
			SourcePage: "", //来源页面
			CallBack: "" //回调方法
		},
		/**
		 * 初始化方法
		 * 页面参数初始化  页面方法初始化  等
		 * @param {Object} options
		 */
		init: function(options) {
			var self = this,
				wb = plus.webview.currentWebview();
			self.Param.SourcePage = wb.SourcePage;
			self.Param.CallBack = wb.CallBack;

			//关闭注册页面(用户注册会跳转此页面)
			BMCW.closeWebview(BMCW.routeCfg.register.id, "none");
			BMCW.closeWebview(BMCW.routeCfg.userauthresult.id, "none");

			mui.init({
				swipeBack: true //启用右滑关闭功能
			});
		},
		/**
		 * 事件绑定
		 * @param {Object} options
		 */
		initEvent: function(options) {
			var self = this;

			document.getElementById("img_IdentityImage").addEventListener('tap', function() {
				self.showActionsheet("IdentityImage");
			}, false);
			document.getElementById("i_IdentityImage").addEventListener('tap', function() {
				self.showActionsheet("IdentityImage");
			}, false);
			document.getElementById("img_IdentityBackImage").addEventListener('tap', function() {
				self.showActionsheet("IdentityBackImage");
			}, false);
			document.getElementById("i_IdentityBackImage").addEventListener('tap', function() {
				self.showActionsheet("IdentityBackImage");
			}, false);
			document.getElementById("img_IdentityHandImage").addEventListener('tap', function() {
				self.showActionsheet("IdentityHandImage");
			}, false);
			document.getElementById("i_IdentityHandImage").addEventListener('tap', function() {
				self.showActionsheet("IdentityHandImage");
			}, false);

			document.getElementById("btn_sure").addEventListener("tap", function() {
				self.beforeSubmit.call(self);
			}, false);
		},
		/**
		 * 渲染页面
		 * 通过ajax对页面加载显示
		 * @param {Object} options
		 */
		initView: function(options) {
			var self = this;
			self.getUserAuth();
		},
		/**
		 * 渲染页面
		 * @param {Object} data
		 */
		getUserAuth: function() {
			var self = this;
			var userID = BMCW.getLocalStorage("CurrentUserID") || 0;
			BMCW.Ajax.ajax({
				url: self.Route.GetUserAuth,
				data: {
					UserID: userID
				},
				success: function(rdata) {
					if(rdata.status == 0) {
						self.Param.Data = rdata.data;
						self.renderView(rdata.data);
					} else {
						BMCW.toast(rdata.message);
					}
				}
			});
		},
		/**
		 * 获取模版
		 */
		renderView: function(item) {
			var self = this;
			if(item.UserAuthID > 0) {
				//显示再次上传
				document.getElementById("i_IdentityBackImage").style.display = "";
				document.getElementById("i_IdentityHandImage").style.display = "";
				document.getElementById("i_IdentityImage").style.display = "";

				//显示图片
				document.getElementById("img_IdentityBackImage").src = item.IdentityBackImage;
				document.getElementById("img_IdentityHandImage").src = item.IdentityHandImage;
				document.getElementById("img_IdentityImage").src = item.IdentityImage;
			}
		},
		/**
		 * 提交验证
		 */
		beforeSubmit: function() {
			var self = this;
			if(self.Param.Data && self.Param.Data.UserAuthID > 0) {
				var hasImage = false;
				for(var m in self.Param.ImageArr) {
					hasImage = true;
					break;
				}
				if(hasImage == false) {
					BMCW.toast("请重新上传身份证照片");
					return false;
				}
			} else {
				if(BMCW.isNullOrEmpty(self.Param.ImageArr.IdentityImage)) {
					BMCW.toast("请上传身份证正面照");
					return false;
				}
				//本市显示指标
				if(BMCW.isNullOrEmpty(self.Param.ImageArr.IdentityBackImage)) {
					BMCW.toast("请上传身份证背面照");
					return false;
				}

				if(BMCW.isNullOrEmpty(self.Param.ImageArr.IdentityHandImage)) {
					BMCW.toast("请上传手持身份证面照");
					return false;
				}
			}
			self.AddUserAuth();
		},
		/**
		 * 显示选择框
		 */
		showActionsheet: function(attrname) {
			var self = this;
			var btnArray = [{
				title: "拍照"
			}, {
				title: "从相册选择"
			}];
			plus.nativeUI.actionSheet({
				title: "上传证件",
				cancel: "取消",
				buttons: btnArray
			}, function(e) {
				var index = e.index;
				switch(index) {
					case 0:
						break;
					case 1:
						self.imgCamera(attrname);
						break;
					case 2:
						self.galleryImgs(attrname);
						break;
				}
			});
		},
		/**
		 * 照相
		 */
		imgCamera: function(attrname) {
			var self = this;
			var cmr = plus.camera.getCamera(1);
			var imgName = new Date().getTime();
			plus.io.requestFileSystem(plus.io.PUBLIC_DOCUMENTS, function(fs) {
				cmr.captureImage(function(path) {
						plus.gallery.save(path, function(e) {
							console.log("图片保存到相册成功.");
						}, function(e) {
							console.log("图片保存到相册失败.");
						})
						self.getPrivatePath([path], attrname);
					},
					function(error) {
						console.log("调用照相失败: " + error.message);
					}, {
						filename: fs.root.fullPath
					});
			}, function(e) {
				console.log("Request file system failed: " + e.message);
			});

		},
		/**
		 * 相册选取
		 */
		galleryImgs: function(attrname) {
			var self = this;
			plus.gallery.pick(function(e) {
				var fileArr = [];
				fileArr.push(e);
				self.getPrivatePath(fileArr, attrname);

			}, function(e) {
				console.log("取消选择图片");
			}, {
				filter: "image",
				multiple: false
			});
		},
		/**
		 * 获取私有路径
		 * @param {Object} files
		 */
		getPrivatePath: function(files, attrname) {
			var self = this;
			plus.io.requestFileSystem(plus.io.PRIVATE_DOC,
				function(fs) {
					fs.root.getDirectory(fs.root.fullPath, {
							create: true //如果不存在,则创建
						},
						function(dir) {
							for(var i in files) {
								var sPath = files[i];
								var tPath = fs.root.toLocalURL() + self.getFileName(sPath); //ios只支持绝对路径
								self.compressPhoto(sPath, tPath, files.length, attrname);
							}
						},
						function(e) {
							console.log("创建/获取目录失败:" + e.message)
						});
				},
				function(e) {
					console.log("获取文件私有路径失败:" + e.message);
				});
		},
		/**
		 * 图片压缩
		 * @param {Object} sPath
		 * @param {Object} tPath		
		 * @param {Object} targetLength
		 * @param {Object} attrname
		 */
		compressPhoto: function(sPath, tPath, targetLength, attrname) {
			var self = this;
			//必须声明新变量,否则js内存泄漏，filePath永远是最后一次传入值
			var fp = sPath,
				dfp = tPath;
			plus.zip.compressImage({
					src: fp,
					dst: dfp,
					quality: 20,
					overwrite: true
				},
				function() {
					self.Param.ImageArr[attrname] = dfp;
					document.getElementById("img_" + attrname).src = dfp;
					console.log("文件压缩成功.");
				},
				function(error) {
					console.log("文件压缩失败:" + error.code + "," + error.message);
				});
		},
		getFileName: function(filepath) { //获取文件名
			var pos = filepath.lastIndexOf("/");
			if(pos == -1) {
				pos = filepath.lastIndexOf("\\")
			}
			var filename = filepath.substring(pos + 1)
			return filename;
		},
		/**
		 * 添加卖方信息
		 */
		AddUserAuth: function() {
			var self = this;
			var userID = BMCW.getLocalStorage("CurrentUserID") || 0;
			var upurl = BMCW.baseUrl + self.Route.AddUserAuth;

			var task = plus.uploader.createUpload(
				upurl, {
					method: "POST"
				},
				function(upload, status) {
					plus.nativeUI.closeWaiting();				
					if(status == 200) {
						var reg = new RegExp('"', "g");
						var userAuthId = upload.responseText.replace(reg, "");
						//更新审核状态
						BMCW.setLocalStorage("UserLevel", 0);

						//打开结果页面
						BMCW.openWindow(BMCW.routeCfg.userauthresult, {
							extras: {
								AuthStatus: 1,
								SourcePage:BMCW.routeCfg.userauth.id
							}
						});
					} else {
						console.log("文件上传失败.");
					}
				});

			for(var k in self.Param.ImageArr) {
				task.addFile(self.Param.ImageArr[k], {
					key: k
				})
			}

			task.addData('UserID', userID);
			task.start();
			plus.nativeUI.showWaiting("保存中...");
		},

		/**
		 * 显示示例
		 * @param {Object} imgId
		 */
		showImage: function(imgId) {
			var self = this;
			document.getElementById(imgId).style.display = "block";
		},
		/**
		 * 关闭示例
		 * @param {Object} imgId
		 */
		slClose: function(imgId) {
			document.getElementById(imgId).style.display = "none";
		}
	});

	//实例化类
	window.page = new BMCW.BasePage();

})(mui, BMCW);