﻿(function($, BMCW) {
	"use strict";

	BMCW.augment(BMCW.BasePage, {
		/**
		 * 页面路由
		 */
		Route: {
			GetCarOfficeList: "/UserAgent/GetCarOfficeList",
			GetUserInfor: "/Personal/GetUserInfor",
			UpdateUserAuthUserTrueNameIdentityCode: "/Personal/UpdateUserAuthUserTrueNameIdentityCode",
			GetUserOfficeRelaListByUserId: "/UserAgent/GetUserOfficeRelaListByUserId"
		},
		/**
		 * 参数
		 */
		Param: {
			SourcePage: "", //来源页面
			CallBack: "", //回调方法
			OfficeIds: [],
		},
		/**
		 * 初始化方法
		 * 页面参数初始化  页面方法初始化  等
		 * @param {Object} options
		 */
		init: function(options) {
			var self = this,
				wb = plus.webview.currentWebview();
			self.Param.SourcePage = wb.SourcePage;
			self.Param.CallBack = wb.CallBack;

			mui.init({
				swipeBack: true //启用右滑关闭功能
			});
		},
		/**
		 * 事件绑定
		 * @param {Object} options
		 */
		initEvent: function(options) {
			var self = this;
			document.getElementById("btn_sure").addEventListener("tap", function() {
				self.beforeSubmit.call(self);
			}, false);
		},
		/**
		 * 渲染页面
		 * 通过ajax对页面加载显示
		 * @param {Object} options
		 */
		initView: function(options) {
			var self = this;
			self.getCarOfficeList();
			self.GetUserInfor();
		},
		/**
		 * 渲染页面
		 * @param {Object} data
		 */
		GetUserInfor: function() {
			var self = this;
			var userID = BMCW.getLocalStorage("CurrentUserID") || 0;
			BMCW.Ajax.ajax({
				url: self.Route.GetUserInfor,
				data: {
					UserID: userID
				},
				success: function(rdata) {
					if(rdata.status == 0) {
						//self.Param.Data = rdata.data;
						document.getElementById("UserTrueName").value = rdata.data.UserTrueName;
						document.getElementById("IdentityCode").value = rdata.data.IdentityCode;
					} else {
						BMCW.toast(rdata.message);
					}
				}
			});
		},
		/**
		 * 渲染页面
		 * @param {Object} data
		 */
		getCarOfficeList: function() {
			var self = this;
			var userID = BMCW.getLocalStorage("CurrentUserID") || 0;
			BMCW.Ajax.ajax({
				url: self.Route.GetCarOfficeList,
				success: function(rdata) {
					if(rdata.status == 0) {
						self.renderView(rdata.data);

						self.getRelationCoffice(userID);
					} else {
						BMCW.toast(rdata.message);
					}
				}
			});
		},
		renderView: function(data) {
			var self = this;
			var htmlStr = "";
			var userID = BMCW.getLocalStorage("CurrentUserID") || 0;
			for(var i = 0; i < data.length; i++) {
				var li = "";
				for(var j = 0; j < data[i].OfficeList.length; j++) {
					li += "<li class=\"bjcg-list-box-item mui-ellipsis-2\" id=\"" + data[i].OfficeList[j].OfficeID + "\">";
					li += "<i class=\"icon iconfont icon-bjcg-yes\"></i>";
					li += "<span>" + data[i].OfficeList[j].Name + "</span></li>";
				}
				htmlStr += '<ul class="mui-clearfix bjcg-list-box-ul">' +
					li +
					'</ul>'
			}
			document.getElementById("OfficeList").innerHTML = htmlStr;

		},
		//查询当前用户关联车管所
		getRelationCoffice: function(userID) {
			var self = this;

			BMCW.Ajax.ajax({
				url: self.Route.GetUserOfficeRelaListByUserId,
				data: {
					UserID: userID
				},
				success: function(rdata) {
					if(rdata.status == 0) {
						self.bindUserOfficeRela(rdata.data);
						self.choiceEvent();
					} else {
						BMCW.toast(rdata.message);
					}
				}
			});
		},
		/**
		 * 绑定选中事件
		 */
		choiceEvent: function() {
			var self = this;
			var items = document.getElementsByClassName('bjcg-list-box-item');

			for(var i = 0; i < items.length; i++) {
				items[i].onclick = function() {
					var isContains = false
					var officeId = this.id;
					for(var i = 0; i < self.Param.OfficeIds.length; i++) {
						if(officeId == self.Param.OfficeIds[i]) {
							this.classList.remove('active');
							self.Param.OfficeIds.splice(i, 1);
							isContains = true;
							break;
						}
					}
					if(!isContains) {
						if(self.Param.OfficeIds.length >= 5) {
							wx.showToast({
								title: '最多选择5个服务区域',
								icon: 'none'
							});

						} else {
							this.classList.add('active');
							self.Param.OfficeIds.push(officeId);
						}
					}
				}
			}
		},
		/**
		 * 选中用户管理车管
		 * @param {Object} data
		 */
		bindUserOfficeRela: function(data) {
			var self = this;

			if(data.length == 0) return;
			var items = document.getElementsByClassName('bjcg-list-box-item');
			for(var i = 0; i < items.length; i++) {
				for(var j = 0; j < data.length; j++) {
					if(items[i].id == data[j].OfficeId) {
						items[i].classList.add('active');
						self.Param.OfficeIds.push(data[j].OfficeId);
					}
				}
			}
		},
		/**
		 * 提交验证
		 */
		beforeSubmit: function() {
			var self = this;
			var name = document.getElementById("UserTrueName").value;
			var code = document.getElementById("IdentityCode").value;

			if(BMCW.isNullOrEmpty(name)) {
				BMCW.toast("请填写真实姓名");
				return false;
			}
			if(!BMCW.isIdentityCode(code)) {
				BMCW.toast("请输入正确的身份证号");
				return false;
			}
			if(self.Param.OfficeIds.length < 1) {
				BMCW.toast("请选择服务区域");
				return false;
			}
			self.UpdateUserInfo(name, code, self.Param.OfficeIds.join(','));
		},
		/**
		 * 更新用户信息
		 */
		UpdateUserInfo: function(name, code, officeidlist) {
			var self = this;
			BMCW.Ajax.ajax({
				url: self.Route.UpdateUserAuthUserTrueNameIdentityCode,
				type: "POST",
				data: {
					userid: BMCW.getLocalStorage("CurrentUserID"),
					usertruename: name,
					identitycode: code,
					officeidlist: officeidlist
				},
				success: function(rdata) {
					if(rdata.status == 0) {
						BMCW.openWindow(BMCW.routeCfg.userauth);
					} else {
						BMCW.toast(rdata.message);
					}
				}
			});
		}
	});

	//实例化类
	window.page = new BMCW.BasePage();

})(mui, BMCW);