(function ($, BMCW) {
    "use strict";

    BMCW.augment(BMCW.BasePage, {
        /**
		 * 页面路由
		 */
        Route: {
            GetCarOfficeInfoList: "/Common/GetCarOfficeInfoList" //根据城市获取车管所列表
        },
        /**
		 * 参数
		 */
        Param: {
            OfficeID: 0, //已选车管所
            LocationID: 0, //城市ID
            BizTypeID: 0, //二级业务ID
            CarSourceList: [], //车管所列表
            SourcePage: "", //来源页面
            CallBack: ""//回调方法
        },
        /**
		 * 初始化方法
		 * 页面参数初始化  页面方法初始化  等
		 * @param {Object} options
		 */
        init: function (options) {
            var self = this,
				wb = plus.webview.currentWebview();
            self.Param.LocationID = wb.LocationID || 0;
            self.Param.BizTypeID = wb.BizTypeID || 0;
            self.Param.OfficeID = wb.OfficeID || 0;
            self.Param.SourcePage = wb.SourcePage;
            self.Param.CallBack = wb.CallBack;
            mui.init({
                swipeBack: true //启用右滑关闭功能
            });
        },
        /**
		 * 事件绑定
		 * @param {Object} options
		 */
        initEvent: function (options) {
            var self = this;
            mui("#muiContent").on("tap", "li", function () {
                var dataId = this.getAttribute("data-id");
                var coList = self.Param.CarSourceList;
                var jsonData = {};
                for (var i = 0; i < coList.length; i++) {
                    if (coList[i].OfficeID == dataId) {
                        jsonData = coList[i];
                        break;
                    }
                }

                //调用回调函数,关闭当前页
                var callMethod = BMCW.format("{0}({1})", self.Param.CallBack, JSON.stringify(jsonData));
                var wb = BMCW.getWebviewById(self.Param.SourcePage);
                wb.evalJS(callMethod);

                BMCW.closeWebview(BMCW.routeCfg.carofficesearch.id);
            });
        },
        /**
		 * 渲染页面
		 * 通过ajax对页面加载显示
		 * @param {Object} options
		 */
        initView: function (options) {
            var self = this;
            var noData = document.getElementById("noData");//暂无数据的盒子
            BMCW.Ajax.ajax({
                url: self.Route.GetCarOfficeInfoList,
                data: {
                    locationID: self.Param.LocationID,
                    bizTypeID: self.Param.BizTypeID
                },
                success: function (rdata) {
                    if (rdata.status == 0) {
                        self.Param.CarSourceList = rdata.data;
                        if (self.Param.CarSourceList.length == 0) {
                            noData.style.display = "block";
                        } else {
                            noData.style.display = "none";
                        }
                        self.renderView(rdata.data);
                    } else {
                        noData.style.display = "block";
                        BMCW.toast(rdata.message);
                    }
                }
            });

        },
        /**
		 * 渲染页面
		 * @param {Object} data
		 */
        renderView: function (data) {
            var self = this,
				content = document.getElementById("muiContent"),
				unContent = document.getElementById("muiUnContent"),
				divUnContent = document.getElementById("div_uncontent"),
				divContent = document.getElementById("div_count");
            for (var i = 0; i < data.length; i++) {
                if (data[i].IsPass <= 0 || data[i].BizTypeID <= 0) {
                    divUnContent.style.display = "";
                    unContent.innerHTML += self.getTpl(data[i]);
                } else {
                    content.innerHTML += self.getTpl(data[i]);
                    divContent.style.display = "";
                }
            }
        },
        /**
		 * 获取模版
		 */
        getTpl: function (item) {
            var self = this,
				seled = "";
            if (item.OfficeID == self.Param.OfficeID) {
                seled = "active";
            }

            var rmk = "";
            if (item.IsPass <= 0) {
                rmk = "【即将开通线上预约】";
                seled = "jinyong";
            } else if (item.BizTypeID <= 0) {
                rmk = "【不支持办理此业务】";
                seled = "jinyong";
            }
            var tpl = '<li data-id="{0}" class="bjcg-banlididian-item ' + seled + '">';
            tpl += '<h4 class="bjcg-banlididian-item-h4"><i class="icon iconfont icon-bjcg-yes bjcg-banlididian-item-i1"></i>{1}{2}</h4>';
            tpl += '<p class="bjcg-banlididian-item-p"><i class="icon iconfont icon-didian bjcg-banlididian-item-i2"></i>{3}</p>';
            tpl += '<p class="bjcg-banlididian-item-p"><i class="icon iconfont icon-shijian bjcg-banlididian-item-i2"></i>{4}</p>';
            tpl += '</li>';
            return BMCW.format(tpl, item.OfficeID, item.Name, rmk, item.Address, item.WorkDate);
        }
    });

    //实例化类
    window.page = new BMCW.BasePage();

})(mui, BMCW);