(function($, BMCW) {
	"use strict";

	BMCW.augment(BMCW.BasePage, {
		/**
		 * 页面路由
		 */
		Route: {
			GeContactInfo: "/Contact/GetContactInfo", //查询单个车主
			AddContactInfo: "/Contact/AddContactInfo", //添加车主
			UpdateContactInfo: "/Contact/UpdateContactInfo" //更新车主
		},
		/**
		 * 参数
		 */
		Param: {
			UserID: 0, //用户ID
			Data: {
				ApplyUserType: 1
			}, //保存车主信息
			ContactID: 0, //车主ID  如果大于0则为更新
			SourcePage: "", //来源页面
			CallBack: "" //回调方法
		},
		/**
		 * 初始化方法
		 * 页面参数初始化  页面方法初始化  等
		 * @param {Object} options
		 */
		init: function(options) {
			var self = this,
				wb = plus.webview.currentWebview();
			self.Param.SourcePage = wb.SourcePage;
			self.Param.CallBack = wb.CallBack;
			self.Param.ContactID = wb.ContactID || 0;

			mui.init({
				swipeBack: true //启用右滑关闭功能
			});
		},
		/**
		 * 事件绑定
		 * @param {Object} options
		 */
		initEvent: function(options) {
			var self = this;

			//个人
			document.getElementById("dl_ApplyUserType1").addEventListener("tap", function() {
				var chk = document.getElementById("i_ApplyUserType1");
				if(chk.classList.contains("checked")) {
					return false;
				}
				chk.classList.add("checked");
				document.getElementById("i_ApplyUserType2").classList.remove("checked");
				document.getElementById("div_ApplyUser1").style.display = "block";
				document.getElementById("div_ApplyUser2").style.display = "none";
				self.Param.Data.ApplyUserType = 1;
			}, false);

			//公司
			document.getElementById("dl_ApplyUserType2").addEventListener("tap", function() {
				var chk = document.getElementById("i_ApplyUserType2");
				if(chk.classList.contains("checked")) {
					return false;
				}
				chk.classList.add("checked");
				document.getElementById("i_ApplyUserType1").classList.remove("checked");
				document.getElementById("div_ApplyUser2").style.display = "block";
				document.getElementById("div_ApplyUser1").style.display = "none";
				self.Param.Data.ApplyUserType = 2;
			}, false);

			//男
			document.getElementById("dl_Gender1").addEventListener("tap", function() {
				var chk = document.getElementById("i_Gender1");
				if(chk.classList.contains("checked")) {
					return false;
				}
				chk.classList.add("checked");
				document.getElementById("i_Gender2").classList.remove("checked");
			}, false);

			//女
			document.getElementById("dl_Gender2").addEventListener("tap", function() {
				var chk = document.getElementById("i_Gender2");
				if(chk.classList.contains("checked")) {
					return false;
				}
				chk.classList.add("checked");
				document.getElementById("i_Gender1").classList.remove("checked");
			}, false);

			//身份证
			document.getElementById("ipt_CIdentityCode").addEventListener("blur", function() {
				if(!BMCW.isNullOrEmpty(this.value)) {
					this.value = this.value.toUpperCase();
				}
			}, false);

			//信用代码
			document.getElementById("ipt_IdentityCode").addEventListener("blur", function() {
				if(!BMCW.isNullOrEmpty(this.value)) {
					this.value = this.value.toUpperCase();
				}
			}, false);

			document.getElementById("btn_add").addEventListener("tap", function() {
				self.beforeSubmit.call(self);
			}, false);
		},
		/**
		 * 渲染页面
		 * 通过ajax对页面加载显示
		 * @param {Object} options
		 */
		initView: function(options) {
			var self = this;
			if(self.Param.ContactID > 0) {
				self.getContact();
			}
		},
		/**
		 * 渲染页面
		 * @param {Object} data
		 */
		getContact: function() {
			var self = this;
			BMCW.Ajax.ajax({
				url: self.Route.GeContactInfo,
				data: {
					contactID: self.Param.ContactID
				},
				success: function(rdata) {
					if(rdata.status == 0) {
						self.Param.Data = rdata.data;
						self.renderView(rdata.data);
					} else {
						BMCW.toast(rdata.message);
					}
				}
			});
		},
		/**
		 * 获取模版
		 */
		renderView: function(item) {
			//办理人类型，1：个人，2：公司
			if(item.ApplyUserType == 1) {
				document.getElementById("i_ApplyUserType1").classList.add("checked");
				document.getElementById("i_ApplyUserType2").classList.remove("checked");
				document.getElementById("ipt_ApplyUserName").value = item.ApplyUserName;
				document.getElementById("ipt_IdentityCode").value = item.IdentityCode;
				document.getElementById("ipt_ApplyMobile").value = item.ApplyMobile;
				document.getElementById("div_ApplyUser1").style.display = "block";
				document.getElementById("div_ApplyUser2").style.display = "none";
				//性别1男2女
				if(item.Gender == 1) {
					document.getElementById("i_Gender1").classList.add("checked");
					document.getElementById("i_Gender2").classList.remove("checked");
				} else {
					document.getElementById("i_Gender2").classList.add("checked");
					document.getElementById("i_Gender1").classList.remove("checked");
				}
			} else {
				document.getElementById("i_ApplyUserType2").classList.add("checked");
				document.getElementById("i_ApplyUserType1").classList.remove("checked");
				document.getElementById("ipt_CApplyUserName").value = item.ApplyUserName;
				document.getElementById("ipt_CIdentityCode").value = item.IdentityCode;
				document.getElementById("ipt_CApplyMobile").value = item.ApplyMobile;
				document.getElementById("div_ApplyUser2").style.display = "block";
				document.getElementById("div_ApplyUser1").style.display = "none";
			}
		},
		/**
		 * 提交验证
		 */
		beforeSubmit: function() {
			var self = this;
			if(self.Param.Data.ApplyUserType == 1) { //个人

				self.Param.Data.ApplyUserName = mui("#ipt_ApplyUserName").val();
				if(document.getElementById("i_Gender1").classList.contains("checked")) {
					self.Param.Data.Gender = 1;
				} else {
					self.Param.Data.Gender = 2;
				}
				self.Param.Data.IdentityCode = mui("#ipt_IdentityCode").val();
				self.Param.Data.ApplyMobile = mui("#ipt_ApplyMobile").val();

				if(BMCW.isNullOrEmpty(self.Param.Data.ApplyUserName)) {
					BMCW.toast("请输入姓名");
					return false;
				}
				if(BMCW.isNullOrEmpty(self.Param.Data.IdentityCode)) {
					BMCW.toast("请输入身份证号");
					return false;
				}
				if(!BMCW.isIdentityCode(self.Param.Data.IdentityCode)) {
					BMCW.toast("请输入正确的身份证号");
					return false;
				}
				if(BMCW.isNullOrEmpty(self.Param.Data.ApplyMobile)) {
					BMCW.toast("请输入手机号码");
					return false;
				}
				if(!BMCW.isMobile(self.Param.Data.ApplyMobile)) {
					BMCW.toast("请输入正确的手机号码");
					return false;
				}
			} else { //公司

				self.Param.Data.ApplyUserName = mui("#ipt_CApplyUserName").val();
				self.Param.Data.IdentityCode = mui("#ipt_CIdentityCode").val();
				self.Param.Data.ApplyMobile = mui("#ipt_CApplyMobile").val();

				if(BMCW.isNullOrEmpty(self.Param.Data.ApplyUserName)) {
					BMCW.toast("请输入公司全称");
					return false;
				}
				if(BMCW.isNullOrEmpty(self.Param.Data.IdentityCode)) {
					BMCW.toast("请输入信用代码");
					return false;
				}
				var reg = /[0-9A-Za-z]{18}/
				if(!reg.test(self.Param.Data.IdentityCode)) {
					BMCW.toast("请输入正确的信用代码");
					return false;
				}
				if(BMCW.isNullOrEmpty(self.Param.Data.ApplyMobile)) {
					BMCW.toast("请输入手机号码");
					return false;
				}
				if(!BMCW.isMobile(self.Param.Data.ApplyMobile)) {
					BMCW.toast("请输入正确的手机号码");
					return false;
				}
			}

			self.Param.Data.UserID = BMCW.getLocalStorage("CurrentUserID");
			if(self.Param.ContactID > 0) {
				self.updateContact();
			} else {
				self.addContact();
			}
		},
		/**
		 * 添加车主
		 * @param {Object} data
		 */
		addContact: function() {
			var self = this;
			BMCW.Ajax.ajax({
				url: self.Route.AddContactInfo,
				type: "POST",
				data: self.Param.Data,
				success: function(rdata) {
					if(rdata.status == 0) {
						self.Param.Data.Id = rdata.data;

						//调用回到函数,并关闭当前页
						if(self.Param.SourcePage) {
							var callMethod = BMCW.format("{0}({1})", self.Param.CallBack, JSON.stringify(self.Param.Data));
							var wb = BMCW.getWebviewById(self.Param.SourcePage);
							wb.evalJS(callMethod);
						}

						BMCW.closeWebview(BMCW.routeCfg.contactaddedit.id);
					} else {
						BMCW.toast(rdata.message);
					}
				}
			});
		},
		/**
		 * 更新车主
		 * @param {Object} data
		 */
		updateContact: function() {
			var self = this;
			BMCW.Ajax.ajax({
				url: self.Route.UpdateContactInfo,
				type: "POST",
				data: self.Param.Data,
				success: function(rdata) {
					if(rdata.status == 0) {

						if(self.Param.SourcePage) {
							//调用回到函数,并关闭当前页
							var callMethod = BMCW.format("{0}({1})", self.Param.CallBack, JSON.stringify(self.Param.Data));
							var wb = BMCW.getWebviewById(self.Param.SourcePage);
							wb.evalJS(callMethod);
						}

						BMCW.closeWebview(BMCW.routeCfg.contactaddedit.id);
					} else {
						BMCW.toast(rdata.message);
					}
				}
			});
		}
	});

	//实例化类
	window.page = new BMCW.BasePage();

})(mui, BMCW);