(function($, BMCW) {
	"use strict";

	BMCW.augment(BMCW.BasePage, {
		/**
		 * 页面路由
		 */
		Route: {
			GetContactInfoList: "/Contact/GetContactInfoList", //查询列表
			DeleteContactInfo: "/Contact/DeleteContactInfo",
			UpdateContactInfo: "/Contact/UpdateContactInfo",
			AddContactInfo: "/Contact/AddContactInfo",
			GetContactInfo: "/Contact/GetContactInfo"
		},
		/**
		 * 参数
		 */
		Param: {
			UserID: 0, //用户ID
			PageIndex: 1, //页码
			PageSize: 10, //页大小
			PageCount: 0, //总数量
			ContactID: 0, //已选中的车主
			ContactList: [], //车主列表
			SourcePage: "", //来源页面
			CallBack: "" //回调方法
		},
		/**
		 * 初始化方法
		 * 页面参数初始化  页面方法初始化  等
		 * @param {Object} options
		 */
		init: function(options) {
			var self = this,
				wb = plus.webview.currentWebview();
			self.Param.ContactID = wb.ContactID || 0;
			self.Param.SourcePage = wb.SourcePage;
			self.Param.CallBack = wb.CallBack;

			//下拉刷新
			BMCW.setCirclePullToRefresh(function() {
				self.pageSearch();
			});

			mui.init({
				swipeBack: true //启用右滑关闭功能
			});
		},
		/**
		 * 事件绑定
		 * @param {Object} options
		 */
		initEvent: function(options) {
			var self = this;

			//选中事件
			document.getElementById("btn_add").addEventListener("tap", function() {
				self.editContact.call(self, 0);
			}, false);
		},
		/**
		 * 渲染页面
		 * 通过ajax对页面加载显示
		 * @param {Object} options
		 */
		initView: function(options) {
			var self = this;
			self.pageSearch();
		},
		/**
		 * 分页查询
		 */
		pageSearch: function() {
			var self = this;
			BMCW.Ajax.ajax({
				url: self.Route.GetContactInfoList,
				data: {
					userID: BMCW.getLocalStorage("CurrentUserID"),
					pageIndex: self.Param.PageIndex,
					pageSize: self.Param.PageSize
				},
				success: function(rdata) {
					if(rdata.status == 0) {
						//如果返回成功,Message赋值总记录数	
						self.updateContactList(rdata.data);
						self.renderView(rdata.data, rdata.message);
					} else {
						BMCW.toast(rdata.message);
					}
				}
			});
		},
		/**
		 * 渲染页面
		 * @param {Object} data
		 * @param {type} pageCount
		 */
		renderView: function(data, pageCount) {
			var self = this,
				pageIndex = self.Param.PageIndex,
				content = document.getElementById("muiContent");

			//如果首页,则清空内容
			if(pageIndex == 1) {
				content.innerHTML = "";
			}

			if(data.length > 0) {
				self.Param.PageCount = BMCW.getPageCount(parseInt(pageCount), self.Param.PageSize);

				var tpl = "";
				for(var i = 0; i < data.length; i++) {
					content.innerHTML += self.getTpl(data[i]);
				}

				content.innerHTML += tpl;
			}
		},
		/**
		 * 获取模版
		 */
		getTpl: function(item) {
			var self = this,
				seled = '';
			if(item.Id == self.Param.ContactID) {
				seled = 'active';
			}
			var rmk = '<em class="bjcg-person-main-user bjcg-gongsi">公司</em>';
			if(item.ApplyUserType == 1) {
				rmk = '<em class="bjcg-person-main-user bjcg-geren">个人</em>';
			}

			var tpl = '<li class="bjcg-person-main-li ' + seled + '">';
			tpl += '	 <i class="icon iconfont icon-bjcg-yes bjcg-person-main-i"></i>';
			tpl += '     <div onclick="page.selectContact(' + item.Id + ');"  class="bjcg-person-main-title">';
			tpl += '	     <span class="bjcg-person-main-username">' + rmk + item.ApplyUserName + '</span>';
			tpl += '     </div>';
			tpl += '     <div  onclick="page.selectContact(' + item.Id + ');"  class="bjcg-person-main-middle">';
			if(item.ApplyUserType == 1) {
				tpl += '    <p class="bjcg-person-main-middle-p">手机号码：<span>' + item.ApplyMobile + '</span></p>';
				tpl += '	<p class="bjcg-person-main-middle-p">身份证号：<span>' + item.IdentityCode + '</span></p>';
			} else {
				tpl += '	<p class="bjcg-person-main-middle-p">信用代码：<span>' + item.IdentityCode + '</span></p>';
			}
			tpl += '    </div>';
			tpl += '    <div class="bjcg-person-main-bottom mui-clearfix">';
			tpl += '	   <a class="bjcg-person-main-bottom-a" onclick="page.editContact(' + item.Id + ');" href="###"><i class="icon iconfont icon-ai-edit bjcg-person-main-bottom-i"></i></a>';
			tpl += '	   <a class="bjcg-person-main-bottom-a" onclick="page.deleteContact(' + item.Id + ');" href="###"><i class="icon iconfont icon-shanchu bjcg-person-main-bottom-i"></i></a>';
			tpl += '    </div>';
			tpl += '</li>';
			return tpl;
		},
		/**
		 * 编辑车主
		 * @param {Object} contactId
		 */
		editContact: function(contactId) {
			var self = this;
			BMCW.openWindow(BMCW.routeCfg.contactaddedit, {
				extras: {
					ContactID: contactId,
					SourcePage: BMCW.routeCfg.contactlist.id,
					CallBack: "page.searchFirst"
				}
			});
		},
		searchFirst: function() {
			var self = this;
			self.Param.PageIndex = 1;
			self.pageSearch();
		},
		/**
		 * 删除联系人
		 * @param {Object} contactId
		 */
		deleteContact: function(contactId) {
			var self = this;
			BMCW.confirm("确认删除车主?", '<img src="../../../images/bjcg-icon-tip.jpg" alt=""/>', '', function(e) {
				if(e.index == 1) {
					BMCW.Ajax.ajax({
						url: self.Route.DeleteContactInfo,
						type: "POST",
						data: {
							Id: contactId
						},
						success: function(rdata) {
							if(rdata.status == 0) {
								self.Param.PageIndex = 1;
								self.pageSearch();
							} else {
								BMCW.toast(rdata.message);
							}
						}
					});
				}
			});
		},
		/**
		 * 选择联系人
		 * @param {Object} contactId
		 */
		selectContact: function(contactId) {
			var self = this,
				conList = self.Param.ContactList;
			var jsonData = {};
			for(var i = 0; i < conList.length; i++) {
				if(conList[i].Id == contactId) {
					jsonData = conList[i];
					break;
				}
			}

			if(self.Param.SourcePage) {
				//调用回到函数,并关闭当前页
				var callMethod = BMCW.format("{0}({1})", self.Param.CallBack, JSON.stringify(jsonData));
				var wb = BMCW.getWebviewById(self.Param.SourcePage);
				wb.evalJS(callMethod);
				BMCW.closeWebview(BMCW.routeCfg.contactlist.id);
			}
		},
		updateContactList: function(data) {
			var self = this,
				conList = self.Param.ContactList;
			for(var i = 0; i < data.length; i++) {
				var idx = self.existItem(conList, data[i].Id);
				if(idx > 0) {
					conList[idx] = data[i];
				} else {
					conList.push(data[i]);
				}
			}
		},
		existItem: function(items, Id) {
			var result = 0;
			for(var i = 0; i < items.length; i++) {
				if(items[i].Id == Id) {
					result = i;
					break;
				}
			}
			return result;
		}
	});

	//实例化类
	window.page = new BMCW.BasePage();

})(mui, BMCW);