(function($, BMCW) {
	"use strict";

	BMCW.augment(BMCW.BasePage, {
		/**
		 * 页面路由
		 */
		Route: {
			GeEntrustInfo: "/Entrust/GetEntrustInfo", //查询单个代理人
			AddEntrustInfo: "/Entrust/AddEntrustInfo", //添加代理人
			UpdateEntrustInfo: "/Entrust/UpdateEntrustInfo" //更新代理人
		},
		/**
		 * 参数
		 */
		Param: {
			UserID: 0, //用户ID
			Data: {}, //保存代理人信息
			EntrustID: 0, //代理人ID  如果大于0则为更新
			SourcePage: "", //来源页面
			CallBack: "" //回调方法
		},
		/**
		 * 初始化方法
		 * 页面参数初始化  页面方法初始化  等
		 * @param {Object} options
		 */
		init: function(options) {
			var self = this,
				wb = plus.webview.currentWebview();
			self.Param.SourcePage = wb.SourcePage;
			self.Param.CallBack = wb.CallBack;
			self.Param.EntrustID = wb.EntrustID || 0;

			mui.init({
				swipeBack: true //启用右滑关闭功能
			});
		},
		/**
		 * 事件绑定
		 * @param {Object} options
		 */
		initEvent: function(options) {
			var self = this;
			document.getElementById("btn_add").addEventListener("tap", function() {
				self.beforeSubmit.call(self);
			}, false);

			document.getElementById("ipt_IdentityCode").addEventListener("blur", function() {
				if(!BMCW.isNullOrEmpty(this.value)) {
					this.value = this.value.toUpperCase();
				}
			}, false);
		},
		/**
		 * 渲染页面
		 * 通过ajax对页面加载显示
		 * @param {Object} options
		 */
		initView: function(options) {
			var self = this;
			if(self.Param.EntrustID > 0) {
				self.getEntrust();
			}

		},
		/**
		 * 渲染页面
		 * @param {Object} data
		 */
		getEntrust: function() {
			var self = this;
			BMCW.Ajax.ajax({
				url: self.Route.GeEntrustInfo,
				data: {
					entrustID: self.Param.EntrustID
				},
				success: function(rdata) {
					if(rdata.status == 0) {
						self.Param.Data = rdata.data;
						self.renderView(rdata.data);
					} else {
						BMCW.toast(rdata.message);
					}
				}
			});
		},
		/**
		 * 获取模版
		 */
		renderView: function(item) {
			document.getElementById("ipt_EntrustUserName").value = item.EntrustUserName;
			document.getElementById("ipt_EntrustMobile").value = item.EntrustMobile;
			document.getElementById("ipt_IdentityCode").value = item.IdentityCode;
		},
		/**
		 * 提交验证
		 */
		beforeSubmit: function() {
			var self = this;

			self.Param.Data.EntrustUserName = mui("#ipt_EntrustUserName").val();
			self.Param.Data.EntrustMobile = mui("#ipt_EntrustMobile").val();
			self.Param.Data.IdentityCode = mui("#ipt_IdentityCode").val();

			if(BMCW.isNullOrEmpty(self.Param.Data.EntrustUserName)) {
				BMCW.toast("请输入姓名");
				return false;
			}
			if(BMCW.isNullOrEmpty(self.Param.Data.EntrustMobile)) {
				BMCW.toast("请输入手机号码");
				return false;
			}
			if(!BMCW.isMobile(self.Param.Data.EntrustMobile)) {
				BMCW.toast("请输入正确的手机号码");
				return false;
			}
			if(BMCW.isNullOrEmpty(self.Param.Data.IdentityCode)) {
				BMCW.toast("请输入身份证号");
				return false;
			}
			if(!BMCW.isIdentityCode(self.Param.Data.IdentityCode)) {
				BMCW.toast("请输入正确的身份证号");
				return false;
			}

			self.Param.Data.UserID = BMCW.getLocalStorage("CurrentUserID");
			if(self.Param.EntrustID > 0) {
				self.updateEntrust();
			} else {
				self.addEntrust();
			}
		},
		/**
		 * 添加代理人
		 * @param {Object} data
		 */
		addEntrust: function() {
			var self = this;
			BMCW.Ajax.ajax({
				url: self.Route.AddEntrustInfo,
				type: "POST",
				data: self.Param.Data,
				success: function(rdata) {
					if(rdata.status == 0) {
						self.Param.Data.EntrustID = rdata.data;

						if(self.Param.SourcePage) {
							//调用回到函数,并关闭当前页
							var callMethod = BMCW.format("{0}({1})", self.Param.CallBack, JSON.stringify(self.Param.Data));
							var wb = BMCW.getWebviewById(self.Param.SourcePage);
							wb.evalJS(callMethod);
						}

						BMCW.closeWebview(BMCW.routeCfg.entrustaddedit.id);
					} else {
						BMCW.toast(rdata.message);
					}
				}
			});
		},
		/**
		 * 更新代理人
		 * @param {Object} data
		 */
		updateEntrust: function() {
			var self = this;
			BMCW.Ajax.ajax({
				url: self.Route.UpdateEntrustInfo,
				type: "POST",
				data: self.Param.Data,
				success: function(rdata) {
					if(rdata.status == 0) {
						//调用回到函数,并关闭当前页
						var callMethod = BMCW.format("{0}({1})", self.Param.CallBack, JSON.stringify(self.Param.Data));
						var wb = BMCW.getWebviewById(self.Param.SourcePage);
						wb.evalJS(callMethod);
						BMCW.closeWebview(BMCW.routeCfg.entrustaddedit.id);
					} else {
						BMCW.toast(rdata.message);
					}
				}
			});
		}
	});

	//实例化类
	window.page = new BMCW.BasePage();

})(mui, BMCW);