(function($, BMCW) {
	"use strict";

	BMCW.augment(BMCW.BasePage, {
		/**
		 * 页面路由
		 */
		Route: {
			GetContactInfoList: "/Contact/GetContactInfoList", //查询车主列表
			GetEntrustInfoList: "/Entrust/GetEntrustInfoList", //查询代理人列表
			GetNoticeByCarOfficeAndBizType: "/Common/GetNoticeByCarOfficeAndBizType", //获取注意事项
			GetBizTypeList: "/Common/GetBizTypeList", //根据一级业务查询二级业务
			AddUserAgentEntrust: "/Entrust/AddUserAgentEntrustInfo" //添加专业委托人
		},
		/**
		 * 参数
		 */
		Param: {
			Data: {
				BizTypeID: 0, //预约业务类型ID
				RegOfficeID: 0, //预约车管所ID
				ContactID: 0, //车主
				EntrustID: 0, //代理人
				RegWayType: 1 //本人办理
			},
			ExtData: {}, //存放扩展信息
			UEntrustData: {}, //存放诚信代办
			EntrustData: {}, //存放代理人
			PageIndex: 1, //页码
			PageSize: 10, //页大小
			MasterID: 1, //主类型
			MasterName: '', //主类型名称
			TitleDesc: '', //业务类型
			BizTypeName: '', //业务类型
			BizTypeID: '', //业务类型id
			LocationID: 0, //当前登陆人城市
			FirstContact: true, //首次选择车主
			FirstEntrust: true, //首次选择代理人
			IsUserAgent: false //是否专业代办
		},
		/**
		 * 初始化方法
		 * 页面参数初始化  页面方法初始化  等
		 * @param {Object} options
		 */
		init: function(options) {
			var self = this,
				wb = plus.webview.currentWebview();
			self.Param.MasterID = wb.MasterID;
			self.Param.MasterName = wb.MasterName;
			self.Param.TitleDesc = wb.TitleDesc;
			self.Param.BizTypeName = wb.BizTypeName;
			self.Param.LocationID = BMCW.getLocalStorage("LocationID");

			mui.init({
				swipeBack: true //启用右滑关闭功能
			});

			//更新title
			document.getElementById("h1_title").innerHTML = self.Param.TitleDesc;

			//二级业务跳转
			if(wb.BizTypeID) {
				self.Param.Data.BizTypeID = wb.BizTypeID;
				//显示已选
				document.getElementById("span_selectedbiztype").innerHTML = wb.BizTypeName;
				document.getElementById("span_selectedbiztype").style.display = "";
				//隐藏请选择
				document.getElementById("span_selectbiztype").style.display = "none";
			}

			//如果代办用户，且认证，则默认代理人为当前登陆人，不允许修改
			var usertype = BMCW.getLocalStorage("CurrentUserType");
			if(usertype == 2) { //用户类型为代办,则判断是否认证			
				self.addUserEntrust({
					userId: BMCW.getLocalStorage("CurrentUserID")
				});

				self.Param.IsUserAgent = true;
				//代办不显示选择诚信代办
				document.getElementById("btnContainer").className = 'bjcg-yewu-main-bottom-person a-clo-2';
				document.getElementById("a_useragent").style.display = 'none';
				document.getElementById("li_useragent").style.display = 'none';
			} else {
				//个人显示选择诚信代办
				document.getElementById("btnContainer").className = 'bjcg-yewu-main-bottom-person a-clo-3';
				document.getElementById("a_useragent").style.display = '';
			}
		},
		/**
		 * 事件绑定
		 * @param {Object} options
		 */
		initEvent: function(options) {
			var self = this;

			//选择办理业务
			document.getElementById("a_selectbiztype").addEventListener("tap", function() {
				self.selectBizType.call(self);
			}, false);

			//选择车管所
			document.getElementById("a_selectcaroffice").addEventListener("tap", function() {
				if(self.Param.Data.BizTypeID && self.Param.Data.BizTypeID > 0) {
					self.selectCarOffice.call(self);
				} else {
					BMCW.toast("请选择办理业务");
					return false;
				}
			}, false);

			//选择车主 tab页
			document.getElementById("a_contact").addEventListener("tap", function() {
				var cls = this.classList;
				if(cls.contains("active")) {
					return false;
				}
				document.getElementById("li_entrust").style.display = "none";
				document.getElementById("div_entrustver").style.display = "none";
				document.getElementById("li_useragent").style.display = "none";
				this.classList.add("active");
				document.getElementById("a_entrust").classList.remove("active");
				document.getElementById("a_useragent").classList.remove("active");
				self.Param.Data.RegWayType = 1;
			}, false);

			//选择他人办理 tab页
			document.getElementById("a_entrust").addEventListener("tap", function() {
				var cls = this.classList;
				if(cls.contains("active")) {
					return false;
				}
				document.getElementById("li_entrust").style.display = "";
				document.getElementById("div_entrustver").style.display = "";
				document.getElementById("li_useragent").style.display = "none";
				this.classList.add("active");
				document.getElementById("a_contact").classList.remove("active");
				document.getElementById("a_useragent").classList.remove("active");

				//tab切换，自动赋值
				if(BMCW.isNullOrEmpty(self.Param.EntrustData.EntrustID)) {
					self.Param.Data.EntrustID = 0;
				} else {
					self.setEntrustData(self.Param.EntrustData);
				}
				self.Param.Data.RegWayType = 2;
			}, false);

			//选择诚信车务代办 tab页
			document.getElementById("a_useragent").addEventListener("tap", function() {
				var cls = this.classList;
				if(cls.contains("active")) {
					return false;
				}
				document.getElementById("li_entrust").style.display = "none";
				document.getElementById("div_entrustver").style.display = "";
				document.getElementById("li_useragent").style.display = "";
				this.classList.add("active");
				document.getElementById("a_contact").classList.remove("active");
				document.getElementById("a_entrust").classList.remove("active");

				//tab切换，自动赋值
				if(BMCW.isNullOrEmpty(self.Param.UEntrustData.EntrustID)) {
					self.Param.Data.EntrustID = 0;
				} else {
					self.setEntrustData(self.Param.UEntrustData);
				}
				self.Param.Data.RegWayType = 3;
			}, false);

			//选择车主
			document.getElementById("a_selectcontact").addEventListener("tap", function() {
				self.selectContact.call(self);
			}, false);

			//选择代理人
			document.getElementById("a_selectentrust").addEventListener("tap", function() {
				//如果当前登陆人为代理人,则不能选择
				if(self.Param.IsUserAgent) {
					BMCW.toast("你的角色为车务代办,不能修改");
					return false;
				}

				//个人用户登陆
				if(self.Param.Data.RegOfficeID <= 0) {
					BMCW.toast("请选择办理地点");
					return false;
				}
				self.Param.Data.RegWayType = 2;
				self.selectEntrust.call(self);
			}, false);

			//选择诚信代办
			document.getElementById("a_selectuseragent").addEventListener("tap", function() {
				//如果当前登陆人为代理人,则不能选择
				if(self.Param.IsUserAgent) {
					BMCW.toast("你的角色为车务代办,不能修改");
					return false;
				}

				//个人用户登陆
				if(self.Param.Data.RegOfficeID <= 0) {
					BMCW.toast("请选择办理地点");
					return false;
				}

				self.selectUserAgentEntrust.call(self);
			}, false);

			//下一步
			document.getElementById("btn_next").addEventListener("tap", function() {
				if(!BMCW.checkUserAuth()) {
					var btnArray = ['取消', '认证'];
					BMCW.confirm("您尚未认证，请到[我的]-[实名认证]进行认证。", '<img src="../../../images/bjcg-icon-tip.jpg" alt=""/>', btnArray, function(e) {
						if(e.index == 1) {
							BMCW.openWindow(BMCW.routeCfg.userauthfirststep);
						}
					});
					return false;
				}

				if(self.Param.Data.BizTypeID <= 0) {
					BMCW.toast("请选择办理业务");
					return false;
				}
				if(self.Param.Data.RegOfficeID <= 0) {
					BMCW.toast("请选择办理地点");
					return false;
				}
				if(self.Param.Data.ContactID <= 0) {
					BMCW.toast("请选择车主");
					return false;
				}
				//其他代理人
				if(self.Param.Data.RegWayType == 2) {
					if(self.Param.Data.EntrustID <= 0) {
						BMCW.toast("请选择代理人");
						return false;
					}
					if(self.Param.Data.EntrustIdentityCode == self.Param.Data.ApplyIdentityCode) {
						BMCW.toast('车主和代理人不能是同一个人，请重新录入');
						return false;
					}
				} else if(self.Param.Data.RegWayType == 3) { //诚信代办
					if(self.Param.Data.EntrustID <= 0) {
						BMCW.toast("请选择诚信车务代办");
						return false;
					}
				}

				BMCW.openWindow(BMCW.routeCfg.registersave, {
					extras: {
						Data: self.Param.Data,
						ExtData: self.Param.ExtData
					}
				});
			}, false);
		},
		/**
		 * 渲染页面
		 * 通过ajax对页面加载显示
		 * @param {Object} options
		 */
		initView: function(options) {
			var self = this;
			if(self.Param.Data.BizTypeID > 0) {
				return;
			}
			BMCW.Ajax.ajax({
				url: self.Route.GetBizTypeList,
				showLoading: false,
				data: {
					masterID: self.Param.MasterID
				},
				success: function(rdata) {
					if(rdata.status == 0) {
						if(rdata.data.length == 1) {
							self.reWriteBziType(rdata.data[0]);
						}
					} else {
						BMCW.toast(rdata.message);
					}
				}
			});
		},
		/**
		 * 选择业务类型
		 * @param {Object} BMCW
		 */
		selectBizType: function() {
			var self = this;
			BMCW.openWindow(BMCW.routeCfg.biztypesearch, {
				extras: {
					BizTypeID: self.Param.Data.BizTypeID,
					MasterID: self.Param.MasterID,
					SourcePage: BMCW.routeCfg.registeradd.id,
					CallBack: "page.reWriteBziType"
				}
			});
		},
		/**
		 * 回填返回值
		 * @param {Object} str
		 */
		reWriteBziType: function(obj) {
			var self = this;
			self.Param.Data.BizTypeID = obj.BizTypeID;
			//显示已选
			document.getElementById("span_selectedbiztype").innerHTML = obj.BizTypeName;
			document.getElementById("span_selectedbiztype").style.display = "";
			//隐藏请选择
			document.getElementById("span_selectbiztype").style.display = "none";

			self.getNoticeByCarOfficeAndBizType();
		},
		/**
		 * 选择车管所
		 */
		selectCarOffice: function() {
			var self = this;
			BMCW.openWindow(BMCW.routeCfg.carofficesearch, {
				extras: {
					BizTypeID: self.Param.Data.BizTypeID,
					OfficeID: self.Param.Data.RegOfficeID,
					LocationID: self.Param.LocationID,
					SourcePage: BMCW.routeCfg.registeradd.id,
					CallBack: "page.reWriteCarOffice"
				}
			});
		},
		/**
		 * 回填车管所返回值
		 * @param {Object} obj
		 */
		reWriteCarOffice: function(obj) {
			var self = this;
			self.Param.Data.RegOfficeID = obj.OfficeID;
			self.Param.ExtData = obj;
			//显示已选
			document.getElementById("span_selectedcaroffice").innerHTML = obj.Name;
			document.getElementById("span_selectedcaroffice").style.display = "";
			//隐藏请选择
			document.getElementById("span_selectcaroffice").style.display = "none";

			self.getNoticeByCarOfficeAndBizType();
		},
		/**
		 * 选择车主
		 */
		selectContact: function() {
			var self = this;
			//首次选择：查询判断是否存在车主,如果不存在则直接添加，否则跳转列表页
			if(self.Param.FirstContact) {
				self.Param.FirstContact = false;
				BMCW.Ajax.ajax({
					url: self.Route.GetContactInfoList,
					showLoading: false,
					data: {
						userID: BMCW.getLocalStorage("CurrentUserID"),
						pageIndex: self.Param.PageIndex,
						pageSize: self.Param.PageSize
					},
					success: function(rdata) {
						if(rdata.status == 0) {
							if(rdata.data.length > 0) {
								//车主列表
								BMCW.openWindow(BMCW.routeCfg.contactlist, {
									extras: {
										ContactID: self.Param.Data.ContactID,
										SourcePage: BMCW.routeCfg.registeradd.id,
										CallBack: "page.reWriteContact"
									}
								});
							} else {
								//添加车主
								BMCW.openWindow(BMCW.routeCfg.contactaddedit, {
									extras: {
										ContactID: 0,
										SourcePage: BMCW.routeCfg.registeradd.id,
										CallBack: "page.reWriteContact"
									}
								});
							}
						} else {
							BMCW.toast(rdata.message);
						}
					}
				});
			} else {
				//车主列表
				BMCW.openWindow(BMCW.routeCfg.contactlist, {
					extras: {
						ContactID: self.Param.Data.ContactID,
						SourcePage: BMCW.routeCfg.registeradd.id,
						CallBack: "page.reWriteContact"
					}
				});
			}
		},
		/**
		 * 回填车主
		 * @param {Object} obj
		 */
		reWriteContact: function(obj) {
			var self = this;
			self.Param.Data.ContactID = obj.Id;
			self.Param.Data.ApplyUserName = obj.ApplyUserName;
			self.Param.Data.ApplyIdentityType = obj.ApplyUserType;
			self.Param.Data.ApplyIdentityCode = obj.IdentityCode;

			document.getElementById("span_selectcontact").style.display = "none";
			document.getElementById("span_selectedCName").innerHTML = obj.ApplyUserName;
			if(obj.ApplyUserType == 1) {
				document.getElementById("span_selectedCType").innerHTML = "身份证";
			} else {
				document.getElementById("span_selectedCType").innerHTML = "信用代码";
			}
			document.getElementById("span_selectedCID").innerHTML = obj.IdentityCode;
			document.getElementById("span_selectedCName").style.display = "";
			document.getElementById("span_selectedCType").style.display = "";
			document.getElementById("span_selectedCID").style.display = "";
		},
		/**
		 * 选择代理人
		 */
		selectEntrust: function() {
			var self = this;
			//首次选择：查询判断是否存在代理人,如果不存在则直接添加，否则跳转列表页
			if(self.Param.FirstEntrust) {
				self.Param.FirstEntrust = false;
				BMCW.Ajax.ajax({
					url: self.Route.GetEntrustInfoList,
					showLoading: false,
					data: {
						userID: BMCW.getLocalStorage("CurrentUserID"),
						pageIndex: self.Param.PageIndex,
						pageSize: self.Param.PageSize
					},
					success: function(rdata) {
						if(rdata.status == 0) {
							if(rdata.data.length > 0) {
								//代理人列表
								BMCW.openWindow(BMCW.routeCfg.entrustlist, {
									extras: {
										EntrustID: self.Param.Data.EntrustID,
										SourcePage: BMCW.routeCfg.registeradd.id,
										CallBack: "page.reWriteEntrust"
									}
								});
							} else {
								//添加代理人
								BMCW.openWindow(BMCW.routeCfg.entrustaddedit, {
									extras: {
										EntrustID: 0,
										SourcePage: BMCW.routeCfg.registeradd.id,
										CallBack: "page.reWriteEntrust"
									}
								});
							}
						} else {
							BMCW.toast(rdata.message);
						}
					}
				});
			} else {
				//代理人列表
				BMCW.openWindow(BMCW.routeCfg.entrustlist, {
					extras: {
						EntrustID: self.Param.Data.EntrustID,
						SourcePage: BMCW.routeCfg.registeradd.id,
						CallBack: "page.reWriteEntrust"
					}
				});
			}
		},
		/**
		 * 回填代理人
		 * @param {Object} obj
		 */
		reWriteEntrust: function(obj) {
			var self = this;
			self.Param.EntrustData = obj;
			self.setEntrustData(obj);
			//self.Param.Data.RegWayType = 2;

			document.getElementById("span_selectentrust").style.display = "none";
			document.getElementById("span_selectedEName").innerHTML = obj.EntrustUserName;
			document.getElementById("span_selectedEType").innerHTML = "身份证";
			document.getElementById("span_selectedEID").innerHTML = obj.IdentityCode;
			document.getElementById("span_selectedEName").style.display = "";
			document.getElementById("span_selectedEType").style.display = "";
			document.getElementById("span_selectedEID").style.display = "";
		},
		/**
		 * 选择专业代办人
		 */
		selectUserAgentEntrust: function() {
			var self = this;
			//代理人列表
			BMCW.openWindow(BMCW.routeCfg.useragententrustlist, {
				extras: {
					UserID: self.Param.Data.UserAgentUserID,
					OfficeId: self.Param.Data.RegOfficeID,
					SourcePage: BMCW.routeCfg.registeradd.id,
					CallBack: "page.addUserAgentEntrust"
				}
			});
		},
		/**
		 * 回填诚信代办
		 * @param {Object} obj
		 */
		reWriteUserAgentEntrust: function(obj) {
			var self = this;
			self.Param.UEntrustData = obj;
			self.setEntrustData(obj);
			self.Param.Data.RegWayType = 3;

			document.getElementById("span_selecuserangent").style.display = "none";
			document.getElementById("span_selectedAName").innerHTML = obj.EntrustUserName;
			document.getElementById("span_selectedAType").innerHTML = "身份证";
			document.getElementById("span_selectedAID").innerHTML = BMCW.hideIdentityCode(obj.IdentityCode);
			document.getElementById("span_selectedAName").style.display = "";
			document.getElementById("span_selectedAType").style.display = "";
			document.getElementById("span_selectedAID").style.display = "";
		},
		/**
		 * 添加诚信代办
		 * @param {Object} obj
		 */
		addUserAgentEntrust: function(obj) {
			var self = this;
			BMCW.Ajax.ajax({
				url: self.Route.AddUserAgentEntrust,
				type: "POST",
				loadingMsg: false,
				data: {
					UserId: BMCW.getLocalStorage("CurrentUserID"),
					RelUserId: obj.userId
				},
				success: function(rdata) {
					if(rdata.status == 0) {
						self.reWriteUserAgentEntrust(rdata.data);
					} else {
						BMCW.toast(rdata.message);
					}
				}
			});
		},
		/**
		 * 如果是代办,添加自己为代理人
		 * @param {Object} obj
		 */
		addUserEntrust: function(obj) {
			var self = this;
			BMCW.Ajax.ajax({
				url: self.Route.AddUserAgentEntrust,
				type: "POST",
				loadingMsg: false,
				data: {
					UserId: BMCW.getLocalStorage("CurrentUserID"),
					RelUserId: obj.userId
				},
				success: function(rdata) {
					if(rdata.status == 0) {
						self.reWriteEntrust(rdata.data);
					} else {
						BMCW.toast(rdata.message);
					}
				}
			});
		},
		/**
		 * 获取注意事项
		 */
		getNoticeByCarOfficeAndBizType: function() {
			var self = this;
			if(self.Param.Data.RegOfficeID > 0 && self.Param.Data.BizTypeID > 0) {
				document.getElementById("div_noticeproce").style.display = "";
				document.getElementById("div_split").style.display = "";
				BMCW.Ajax.ajax({
					url: self.Route.GetNoticeByCarOfficeAndBizType,
					showLoading: false,
					data: {
						officeID: self.Param.Data.RegOfficeID,
						bizTypeID: self.Param.Data.BizTypeID
					},
					success: function(rdata) {
						if(rdata.status == 0) {
							document.getElementById("div_Procedure").innerHTML = rdata.data.Procedure || "";
							document.getElementById("div_NoticeItem").innerHTML = rdata.data.NoticeItem || "";
						}
					}
				});
			}
		},
		/**
		 * 赋值代理人
		 * @param {Object} obj
		 */
		setEntrustData: function(obj) {
			var self = this;
			self.Param.Data.EntrustID = obj.EntrustID || 0;
			self.Param.Data.EntrustUserName = obj.EntrustUserName;
			self.Param.Data.EntrustIdentityType = obj.IdentityType;
			self.Param.Data.EntrustIdentityCode = obj.IdentityCode;
			self.Param.Data.UserAgentUserID = obj.RelUserID || 0;
		}
	});

	//实例化类
	window.page = new BMCW.BasePage();

})(mui, BMCW);