(function($, BMCW) {
	"use strict";

	BMCW.augment(BMCW.BasePage, {
		/**
		 * 页面路由
		 */
		Route: {
			GetRegisterInfoList: "/Register/GetRegisterInfoList", //获取全部列表
			DeleteRegisterInfo: "/Register/DeleteRegisterInfo", //删除预约
			CancelRegisterInfo: "/Register/CancelRegisterInfo", //取消预约
			SetRegisterRead: "/Register/SetRegisterRead", //设置消息已读
			GetRegisterInfoStatusList: "/Register/GetRegisterInfoStatusList" //根状态获取列表
		},
		/**
		 * 参数
		 */
		Param: {
			PageIndex: 1, //页码
			PageSize: 10, //页大小
			PageCount: 0, //总数量
			RegStatus: 0, //类型
			SourcePage: "", //来源页面
			CallBack: "" //回调方法
		},
		/**
		 * 初始化方法
		 * 页面参数初始化  页面方法初始化  等
		 * @param {Object} options
		 */
		init: function(options) {
			var self = this,
				wb = plus.webview.currentWebview();
			self.Param.RegStatus = wb.RegStatus || 0;
			self.Param.SourcePage = wb.SourcePage;
			self.Param.CallBack = wb.CallBack;
			mui.init({
				swipeBack: true, //启用右滑关闭功能
				beforeback: function() {
					var wb = BMCW.getWebviewById(BMCW.routeCfg.personal.id);
					if(wb) {
						wb.evalJS("page.getRegisterTotalStatus()");
					}
					return true;
				}
			});

			//下拉刷新
			BMCW.setCirclePullToRefresh(function() {
				if(BMCW.getLocalStorage("CurrentUserID") > 0) {
					self.Param.PageIndex = 1;
					self.getCommonList();
				}
			});

			//滑动底部自动分页查询
			document.addEventListener("plusscrollbottom", function() {
				if(self.Param.PageIndex < self.Param.PageCount) {
					self.Param.PageIndex += 1;
					//document.getElementById("div_pullrefresh").style.display = "";
					self.getCommonList();
				}
			}, false);
		},
		/**
		 * 事件绑定
		 * @param {Object} options
		 */
		initEvent: function(options) {
			var self = this;
			mui("#ul_register").on("tap", "li", function() {
				if(this.classList.contains("active")) {
					return false;
				} else {
					var chd = document.getElementById("ul_register").children;
					for(var i = 0; i < chd.length; i++) {
						if(chd[i].classList.contains("active")) {
							chd[i].classList.remove("active");
							break;
						}
					}
					this.classList.add("active");
					self.Param.PageIndex = 1;
					self.Param.RegStatus = this.id.substring(12);
					self.getCommonList.call(self);
				}
			});
		},
		/**
		 * 渲染页面
		 * 通过ajax对页面加载显示
		 * @param {Object} options
		 */
		initView: function(options) {
			var self = this;
			document.getElementById("li_regstatus" + self.Param.RegStatus).classList.add("active");
			self.getCommonList();
		},
		getCommonList: function() {
			var self = this;
			if(self.Param.RegStatus == 0) {
				self.getRegisterInfoList();
			} else {
				self.getRegisterInfoStatusList();
			}
		},
		/**
		 * 获取全部列表
		 */
		getRegisterInfoList: function() {
			var self = this;
			BMCW.Ajax.ajax({
				url: self.Route.GetRegisterInfoList,
				data: {
					userID: BMCW.getLocalStorage("CurrentUserID"),
					pageIndex: self.Param.PageIndex,
					pageSize: self.Param.PageSize
				},
				success: function(rdata) {
					if(rdata.status == 0) {
						//如果返回成功,Message赋值总记录数	
						self.renderView(rdata.data, rdata.message);
					} else {
						BMCW.toast(rdata.message);
					}
				}
			});
		},
		/**
		 * 根据状态获取列表
		 */
		getRegisterInfoStatusList: function() {
			var self = this;
			BMCW.Ajax.ajax({
				url: self.Route.GetRegisterInfoStatusList,
				data: {
					userID: BMCW.getLocalStorage("CurrentUserID"),
					regStatus: self.Param.RegStatus,
					pageIndex: self.Param.PageIndex,
					pageSize: self.Param.PageSize
				},
				success: function(rdata) {
					if(rdata.status == 0) {
						//如果返回成功,Message赋值总记录数	
						self.renderView(rdata.data, rdata.message);
					} else {
						BMCW.toast(rdata.message);
					}
				}
			});
		},
		/**
		 * 渲染页面
		 * @param {Object} data
		 */
		renderView: function(data, pageCount) {
			var self = this,
				content = document.getElementById("muiContent");

			//如果首页,则清空内容
			if(self.Param.PageIndex == 1) {
				content.innerHTML = "";
				if(data.length < 1) {
					document.getElementById("div_nodata").style.display = "";
				} else {
					document.getElementById("div_nodata").style.display = "none";
				}
			}

			if(data.length > 0) {
				self.Param.PageCount = BMCW.getPageCount(parseInt(pageCount), self.Param.PageSize);

				var tpl = "";
				for(var i = 0; i < data.length; i++) {
					content.innerHTML += self.getTpl(data[i]);
				}

				content.innerHTML += tpl;
			}
		},
		/**
		 * 获取模版
		 */
		getTpl: function(item) {
			var self = this;
			//组合时间歌手
			var dt = item.RegStartDate.substring(0, 10);
			var hh = item.RegStartDate.substring(11, 13);
			if(parseInt(hh) > 12) {
				dt += ' 下午 ';
			} else {
				dt += ' 上午 ';
			}
			dt = dt + item.RegStartDate.substring(11) + '-' + item.RegEndDate.substring(11);

			var tpl = '<div class="bjcg-yuyue-item">';
			if(item.IsRead == 1) {
				tpl += '<i id="i_spit' + item.RegisterID + '" class="bjcg-red-dian"></i>';
			}
			tpl += '<h4 onclick="page.registerDetail(' + item.RegisterID + ');" class="bjcg-yuyue-item-h4">' + item.MasterBizTypeName + '-' + item.BizTypeName + '</h4>';
			tpl += '<p onclick="page.registerDetail(' + item.RegisterID + ');" class="bjcg-yuyue-item-p"><i class="icon iconfont icon-shouye1"></i>' + item.Name + '</p>';
			tpl += '<p onclick="page.registerDetail(' + item.RegisterID + ');" class="bjcg-yuyue-item-p"><i class="icon iconfont icon-didian"></i>' + item.Address + '</p>';
			tpl += '<p onclick="page.registerDetail(' + item.RegisterID + ');" class="bjcg-yuyue-item-p"><i class="icon iconfont icon-shijian"></i>' + dt + '</p>';
			tpl += '<p onclick="page.registerDetail(' + item.RegisterID + ');" class="bjcg-yuyue-item-p"><i class="icon iconfont icon-shenqingren"></i>车主  <span class="bjcg-yuyue-item-span">' + item.ApplyUserName + '</span><span class="bjcg-yuyue-item-span">' + item.ApplyMobile + '</span></p>';

			if(item.RegStatus == 1) {
				tpl += '<a onclick="page.registerCancel(' + item.RegisterID + ');" class="bjcg-yuyue-item-a" href="###">取消</a>';
			} else {
				tpl += '<a onclick="page.registerDelete(' + item.RegisterID + ');" class="bjcg-yuyue-item-a" href="###"><i class="icon iconfont icon-shanchu"></i></a>';
			}
			tpl += '</div>';
			return tpl;
		},
		registerCancel: function(regId) {
			var self = this;
			BMCW.confirm("确认取消?", '<img src="../../../images/bjcg-icon-tip.jpg" alt=""/>', "", function(e) {
				if(e.index == 1) {
					BMCW.Ajax.ajax({
						url: self.Route.CancelRegisterInfo,
						type: "POST",
						data: {
							Id: regId
						},
						success: function(rdata) {
							if(rdata.status == 0) {
								BMCW.toast("取消成功");
								self.Param.PageIndex = 1;
								self.getCommonList();
							} else {
								BMCW.toast(rdata.message);
							}
						}
					});
				}
			});
		},
		registerDelete: function(regId) {
			var self = this;
			BMCW.confirm("确认删除?", '<img src="../../../images/bjcg-icon-tip.jpg" alt=""/>', "", function(e) {
				if(e.index == 1) {
					BMCW.Ajax.ajax({
						url: self.Route.DeleteRegisterInfo,
						type: "POST",
						data: {
							Id: regId
						},
						success: function(rdata) {
							if(rdata.status == 0) {
								BMCW.toast("删除成功");
								self.Param.PageIndex = 1;
								self.getCommonList();
							} else {
								BMCW.toast(rdata.message);
							}
						}
					});
				}
			});
		},
		/**
		 * 跳转详情
		 * @param {Object} regId
		 */
		registerDetail: function(regId) {
			var self = this;
			self.setRegisterRead(regId);
			var elem = document.getElementById("i_spit" + regId);
			if(elem) {
				elem.style.display = "none";
			}
			BMCW.openWindow(BMCW.routeCfg.registersuccess, {
				extras: {
					RegisterID: regId
				}
			});

		},
		/**
		 * 发送消息
		 * @param {Object} regId
		 */
		setRegisterRead: function(regId) {
			var self = this;
			BMCW.Ajax.ajax({
				url: self.Route.SetRegisterRead,
				showLoading: false,
				type: "GET",
				data: {
					registerID: regId
				},
				success: function(rdata) {}
			});
		}
	});

	//实例化类
	window.page = new BMCW.BasePage();

})(mui, BMCW);