(function($, BMCW) {
	"use strict";

	BMCW.augment(BMCW.BasePage, {
		/**
		 * 页面路由
		 */
		Route: {
			GetRegisterTimeList: "/Common/GetRegisterTimeList", //获取预约时间列表
			AddRegisterInfo: "/Register/AddRegisterInfo" //添加预约
		},
		/**
		 * 参数
		 */
		Param: {
			UserID: 0, //用户ID
			Data: {}, //预约信息
			ExtData: {}, //扩展信息
			RegisterTimeList: [] //时间列表
		},
		/**
		 * 初始化方法
		 * 页面参数初始化  页面方法初始化  等
		 * @param {Object} options
		 */
		init: function(options) {
			var self = this,
				wb = plus.webview.currentWebview();
			self.Param.Data = wb.Data || {};
			self.Param.ExtData = wb.ExtData || {};

			mui.init({
				swipeBack: true //启用右滑关闭功能
			});
		},
		/**
		 * 事件绑定
		 * @param {Object} options
		 */
		initEvent: function(options) {
			var self = this;
			//注册
			$("#btn_add").click(function() {
				self.register.call(self);
			});

			//只能预约15天内
			var maxDate = new Date();
			maxDate.setDate(maxDate.getDate() + 14);

			//选择日期
			document.getElementById("ipt_RegDate").addEventListener("tap", function() {
				var regDate = this,
					arrDate = regDate.value.split('-');
				var dDate = new Date(arrDate[0], arrDate[1] - 1, arrDate[2]);
				plus.nativeUI.pickDate(function(e) {
					regDate.value = BMCW.formatDate(e.date, "yyyy-MM-dd");
					self.getRegisterTimeList.call(self);
				}, function(e) {}, {
					title: "预约时间",
					date: dDate,
					minDate: new Date(),
					maxDate: maxDate
				});
			}, false);
		},
		/**
		 * 渲染页面
		 * 通过ajax对页面加载显示
		 * @param {Object} options
		 */
		initView: function(options) {
			//如果当前时间在17:30以前，默认当天，否则默认第二天
			var self = this,
				dt = new Date(),
				days = dt.getDate();
			if(dt.getHours() > 17) {
				days++;
			} else if(dt.getHours() == 17) {
				if(dt.getMinutes() > 30) {
					days++;
				}
			}
			dt.setDate(days);
			//默认预约日期
			document.getElementById("ipt_RegDate").value = BMCW.formatDate(dt, "yyyy-MM-dd");
			document.getElementById("h_carofficename").innerHTML = self.Param.ExtData.Name;
			document.getElementById("p_carsourceaddress").innerHTML = self.Param.ExtData.Address;
			document.getElementById("p_carsourceworkdate").innerHTML = self.Param.ExtData.WorkDate;

			self.getRegisterTimeList();
		},
		getRegisterTimeList: function() {
			var self = this;
			self.Param.Data.TimeID = 0;
			//查询制定时间的预约时间列表
			BMCW.Ajax.ajax({
				url: self.Route.GetRegisterTimeList,
				data: {
					officeID: self.Param.Data.RegOfficeID,
					bizTypeID: self.Param.Data.BizTypeID,
					selectDate: document.getElementById("ipt_RegDate").value.replace(/-/g, '')
				},
				success: function(rdata) {
					if(rdata.status == 0) {
						self.Param.RegisterTimeList = rdata.data;
						self.renderView(rdata.data);
					} else {
						BMCW.toast(rdata.message);
					}
				}
			});
		},
		renderView: function(data) {
			var self = this,
				content = document.getElementById("muiContent");
			content.innerHTML = '';
			if(data.length > 0) {
				document.getElementById("div_nodata").style.display = "none";
				for(var i = 0; i < data.length; i++) {
					content.innerHTML += self.getTpl(data[i]);
				}
			} else {
				document.getElementById("div_nodata").style.display = "";
			}
		},
		/**
		 * 获取模版
		 */
		getTpl: function(item) {
			var self = this,
				rmk = "已约满",
				clk = "",
				selCls = "zhihui";
			//可预约数量大于0，并且当前时间
			if(item.AvilableCount > 0 && item.TimeStatus > 0) {
				rmk = "可预约";
				//如果结束时间大于当前时间
				if(BMCW.formatDate(item.EndDate, "yyyyMMddHHmm") > BMCW.formatDate(new Date(), "yyyyMMddHHmm")) {
					selCls = "";
					clk = 'onclick="page.selectItem(this);"';
				}
			}
			var dt = BMCW.formatDate(item.StartDate, "HH:mm") + '-' + BMCW.formatDate(item.EndDate, "HH:mm");

			var tpl = '<li data-id="' + item.TimeID + '" ' + clk + ' class="bjcg-yuyue-time-li ' + selCls + ' mui-col-sm-3  mui-col-xs-4">';
			tpl += '<a class="bjcg-yuyue-time-a" href="###">';
			tpl += '<span class="bjcg-yuyue-time-span">' + dt + '</span>';
			tpl += '<span class="bjcg-yuyue-time-span gray">' + rmk + '</span>';
			tpl += '</a>';
			tpl += '</li>';

			return tpl;
		},
		/**
		 * 
		 * @param {Object} timeID
		 */
		selectItem: function(dom) {
			var self = this;
			if(dom.classList.contains("blue")) {
				return false;
			} else {
				mui("#muiContent li").each(function() {
					this.classList.remove("blue");
				});
				dom.classList.add("blue");
				self.Param.Data.TimeID = dom.getAttribute("data-id");
			}
		},
		/**
		 * 注册
		 */
		register: function() {
			var self = this;
			self.Param.Data.RegisterUserID = BMCW.getLocalStorage("CurrentUserID");
			if(self.Param.Data.TimeID && self.Param.Data.TimeID > 0) {
				//赋值预约时间段
				for(var i = 0; i < self.Param.RegisterTimeList.length; i++) {
					if(self.Param.RegisterTimeList[i].TimeID == self.Param.Data.TimeID) {
						self.Param.Data.RegStartDate = self.Param.RegisterTimeList[i].StartDate;
						self.Param.Data.RegEndDate = self.Param.RegisterTimeList[i].EndDate;
						break;
					}
				}
			} else {
				BMCW.toast("请选择预约时间段");
				return false;
			}
			console.log(JSON.stringify(self.Param.Data))
			BMCW.Ajax.ajax({
				url: self.Route.AddRegisterInfo,
				type: "Post",
				loadloadingMsg: "预约中...",
				data: self.Param.Data,
				success: function(rdata) {
					if(rdata.status == 0) {
						BMCW.openWindow(BMCW.routeCfg.registersuccess, {
							extras: {
								RegisterID: rdata.message
							}
						});
					} else {
						BMCW.toast(rdata.message);
					}
				}
			});
		}
	});

	//实例化类
	window.page = new BMCW.BasePage();

})(mui, BMCW);