(function($, BMCW) {
	"use strict";

	BMCW.augment(BMCW.BasePage, {
		/**
		 * 页面路由
		 */
		Route: {
			GetRegisterInfo: "/Register/GetRegisterInfo", //根据一级业务查询二级业务
			BindExpertUser: "/Register/BindExpertUser", //重新绑定专业代办
			GetNoticeByCarOfficeAndBizType: "/Common/GetNoticeByCarOfficeAndBizType" //获取注意事项
		},
		/**
		 * 参数
		 */
		Param: {
			RegisterID: 0, //预约ID		
			RegOfficeID: 0, //预约车管所
			Data: {}
		},
		/**
		 * 初始化方法
		 * 页面参数初始化  页面方法初始化  等
		 * @param {Object} options
		 */
		init: function(options) {
			var self = this,
				wb = plus.webview.currentWebview();
			self.Param.RegisterID = wb.RegisterID;
		},
		/**
		 * 事件绑定
		 * @param {Object} options
		 */
		initEvent: function(options) {
			var self = this;

			//保存到相册
			document.getElementById("btn_saveqrcode").addEventListener("tap", function() {
				var loadUrl = document.getElementById("img_qrcode").getAttribute("src");
				plus.nativeUI.showWaiting("二维码保存中，请等待...");
				var dtask = plus.downloader.createDownload(loadUrl, {
					method: "GET",
					filename: "_doc/userhead.png"
				}, function(d, status) {
					// 下载完成
					if(status == 200) {
						plus.nativeUI.closeWaiting();
						var sd_path = plus.io.convertLocalFileSystemURL(d.filename);
						plus.gallery.save(sd_path, function() {
							BMCW.toast("保存成功");
							plus.downloader.clear();
						}, function() {
							BMCW.toast("请检测是否有获取相册的权限");
							plus.downloader.clear();
						});
					} else {
						BMCW.toast("保存失败");
						plus.downloader.clear();
						plus.nativeUI.closeWaiting();
					}
				});
				dtask.start();
			}, false);

			//添加专业代办
			document.getElementById("div_binduser").addEventListener("tap", function() {
				//代理人列表
				BMCW.openWindow(BMCW.routeCfg.useragententrustlist, {
					extras: {
						UserID: 0,
						OfficeId: self.Param.RegOfficeID,
						SourcePage: BMCW.routeCfg.registersuccess.id,
						CallBack: "page.bindExpertUser"
					}
				});
			}, false);

			//返回
			document.getElementById("btn_back").addEventListener("tap", function() {
				BMCW.closeWebview(BMCW.routeCfg.registeradd.id);
				BMCW.closeWebview(BMCW.routeCfg.registersave.id);
				BMCW.closeWebview();
			}, false);
		},
		/**
		 * 渲染页面
		 * 通过ajax对页面加载显示
		 * @param {Object} options
		 */
		initView: function(options) {
			var self = this;

			BMCW.closeWebview(BMCW.routeCfg.registeradd.id, "none");
			BMCW.closeWebview(BMCW.routeCfg.registersave.id, "none");

			BMCW.Ajax.ajax({
				url: self.Route.GetRegisterInfo,
				showLoading: false,
				data: {
					registerID: self.Param.RegisterID
				},
				success: function(rdata) {
					if(rdata.status == 0) {
						self.renderView(rdata.data);
						self.getNoticeByCarOfficeAndBizType(rdata.data);
					} else {
						BMCW.toast(rdata.message);
					}
				}
			});
		},
		/**
		 * 渲染页面
		 * @param {Object} data
		 */
		renderView: function(data) {
			var self = this;
			self.Param.RegOfficeID = data.RegOfficeID;
			 //预约时间
			var dt = data.RegStartDate.substring(0, 10);
			var hh = data.RegStartDate.substring(11, 13);
			if(parseInt(hh) > 12) {
				dt += ' 下午 ';
			} else {
				dt += ' 上午 ';
			}
			dt = dt + data.RegStartDate.substring(11) + '-' + data.RegEndDate.substring(11);
			document.getElementById("li_registerbiztype").innerHTML = '预约业务：' + data.MasterBizTypeName + ' <span>（' + data.BizTypeName + '）</span>';
			document.getElementById("li_registerdate").innerHTML = '预约时间：' + dt;
			document.getElementById("li_carsourceaddress").innerHTML = '办理地点：' + data.Name + '（' + data.Address + '）';
			var m = data.ApplyMobile || "";
			document.getElementById("li_contact").innerHTML = '车    主：' + data.ApplyUserName + ' ' + m;
			if(data.RegWayType > 1) {
				document.getElementById("li_entrust").innerHTML = '代理人：' + data.EntrustUserName + ' ' + data.EntrustMobile;
			}
			document.getElementById("img_qrcode").src = BMCW.baseUrl + data.QRCodeUrl;

			//如果预约为个人 and 状态为已预约，则显示绑定专业代办
			if(data.RegWayType == 1 && data.RegStatus == 1) {
				document.getElementById("div_binduser").style.display = "";
			} else {
				document.getElementById("div_binduser").style.display = "none";
			}
		},
		/**
		 * 获取注意事项
		 */
		getNoticeByCarOfficeAndBizType: function(data) {
			var self = this;
			if(data.RegOfficeID > 0 && data.BizTypeID > 0) {
				BMCW.Ajax.ajax({
					url: self.Route.GetNoticeByCarOfficeAndBizType,
					showLoading: false,
					data: {
						officeID: data.RegOfficeID,
						bizTypeID: data.BizTypeID
					},
					success: function(rdata) {
						if(rdata.status == 0) {
							document.getElementById("div_Procedure").innerHTML = rdata.data.Procedure || "";
							document.getElementById("div_NoticeItem").innerHTML = rdata.data.NoticeItem || "";
						}
					}
				});
			}
		},
		/**
		 * 重新选择代办
		 */
		reCreateEntrustment: function() {
			var self = this;
			//代理人列表
			BMCW.openWindow(BMCW.routeCfg.useragententrustlist, {
				extras: {
					EntrustID: 0,
					OfficeId: self.Param.RegOfficeID,
					SourcePage: BMCW.routeCfg.pnlentrustmentlist.id,
					CallBack: "page.addRegisterInfo"
				}
			});
		},
		/**
		 * 绑定专业代办
		 */
		bindExpertUser: function(obj) {
			var self = this;
			BMCW.Ajax.ajax({
				url: self.Route.BindExpertUser,
				type: "POST",
				data: {
					RegisterID: self.Param.RegisterID,
					UserAgentUserID: obj.userId
				},
				success: function(rdata) {
					if(rdata.status == 0) {
						BMCW.toast('下单成功.');
						
						BMCW.openWindow(BMCW.routeCfg.pnlentrustmentlist);
					} else {
						BMCW.toast(rdata.message);
					}
				}
			});
		}
	});

	//实例化类
	window.page = new BMCW.BasePage();

})(mui, BMCW);