(function($, BMCW) {
	"use strict";

	BMCW.augment(BMCW.BasePage, {
		/**
		 * 页面路由
		 */
		Route: {
			GetEntrustInfoList: "/UserAgent/GetUserAgentListByOfficeId", //根据检测厂获取代办列表
			AddUserAgentEntrust: "/Entrust/AddUserAgentEntrustInfo" //添加专业委托人
		},
		/**
		 * 参数
		 */
		Param: {
			PageIndex: 1, //页码
			PageSize: 11, //页大小
			PageCount: 0, //总数量
			OfficeId: 0, //车管所Id
			UserID: 0, //已选中的代理人
			EntrustList: [], //代理人列表
			SourcePage: "", //来源页面
			CallBack: "" //回调方法
		},
		/**
		 * 初始化方法
		 * 页面参数初始化  页面方法初始化  等
		 * @param {Object} options
		 */
		init: function(options) {
			var self = this,
				wb = plus.webview.currentWebview();
			self.Param.UserID = wb.UserID || 0;
			self.Param.OfficeId = wb.OfficeId || 0;
			self.Param.SourcePage = wb.SourcePage;
			self.Param.CallBack = wb.CallBack;

			//下拉刷新
			BMCW.setCirclePullToRefresh(function() {
				self.Param.PageIndex = 1;
				self.pageSearch();
			});

			//滑动底部自动分页查询
			document.addEventListener("plusscrollbottom", function() {
				if(self.Param.PageIndex < self.Param.PageCount) {
					self.Param.PageIndex += 1;
					self.pageSearch();
				}
			}, false);
			mui.init({
				swipeBack: true //启用右滑关闭功能
			});
		},
		/**
		 * 渲染页面
		 * 通过ajax对页面加载显示
		 * @param {Object} options
		 */
		initView: function(options) {
			var self = this;
			self.pageSearch();
		},
		/**
		 * 分页查询
		 */
		pageSearch: function() {
			var self = this;
			BMCW.Ajax.ajax({
				url: self.Route.GetEntrustInfoList,
				data: {
					OfficeId: self.Param.OfficeId,
					pageIndex: self.Param.PageIndex,
					pageSize: self.Param.PageSize
				},
				success: function(rdata) {
					if(rdata.status == 0) {
						//如果返回成功,Message赋值总记录数	
						self.updateEntrustList(rdata.data);
						self.renderView(rdata.data, rdata.message);
					} else {
						BMCW.toast(rdata.message);
					}
				}
			});
		},
		/**
		 * 渲染页面
		 * @param {Object} data
		 * @param {type} pageCount
		 */
		renderView: function(data, pageCount) {
			var self = this,
				pageIndex = self.Param.PageIndex,
				content = document.getElementById("muiContent");

			//如果首页,则清空内容
			if(pageIndex == 1) {
				content.innerHTML = "";
			}

			if(data.length > 0) {
				self.Param.PageCount = BMCW.getPageCount(parseInt(pageCount), self.Param.PageSize);

				var tpl = "";
				for(var i = 0; i < data.length; i++) {
					content.innerHTML += self.getTpl(data[i]);
				}

				content.innerHTML += tpl;
			}
		},
		/**
		 * 获取模版
		 */
		getTpl: function(item) {
			var self = this,
				seled = '';
			if(item.UserID == self.Param.UserID) {
				seled = 'active';
			}
			//名字进行加工  姓+性别
			var usrName = '';
			if(!BMCW.isNullOrEmpty(item.UserTrueName)) {
				usrName = item.UserTrueName.substring(0, 1);
			}
			if(item.UserGender == 2) {
				usrName += '女士';
			} else {
				usrName += '先生';
			}

			var userFaith = item.EvaluationLevel * 20;
			var tpl = '<div class="bjcg-cell-item ' + seled + '">';
			tpl += '      <a href="###" class="bjcg-cell">';
			tpl += '        <i onclick="page.selectEntrust(' + item.UserID + ');" class="icon iconfont icon-bjcg-yes bjcg-cell-choice-i"></i>';
			tpl += '		<div class="bjcg-cell-wrapper">';
			tpl += '			<div onclick="page.showEntrustDetail(' + item.UserID + ');" class="bjcg-cell-img bjcg-bg-img">';
			if(BMCW.isNullOrEmpty(item.UserHead)) {
				tpl += '		<div class="bjcg-touxiang" style="background:url("../../../images/bjcg-touxiang-no-login.png") center center no-repeat;background-size:cover;"></div>';
			} else {
				tpl += '<div class="bjcg-touxiang" style="background:url('+item.UserHead+') center center no-repeat;background-size:cover;"></div>';
			}
			tpl += ' 			</div>';
			tpl += ' 			<div onclick="page.selectEntrust(' + item.UserID + ');" class="bjcg-cell-content">';
			tpl += '				<div class="bjcg-cell-content-up">';
			tpl += '					<span class="bjcg-cell-text">' + usrName + '</span>';
			//tpl += '					<span class="bjcg-cell-tag">信任值<b>' + userFaith + '</b>分</span>';
			tpl += '					<div class="bjcg-cell-star">';
			tpl += '						<i class="icon iconfont icon-xingxing"></i>';
			tpl += '						<span class="bjcg-cell-value-text">' + item.EvaluationLevel + '</span>';
			tpl += '					</div>';
			tpl += '					<span class="bjcg-cell-value-totle"><b>' + item.OrderNumer + '</b>单</span>';
			tpl += '			</div>';
			tpl += '			<div onclick="page.selectEntrust(' + item.UserID + ');" class="bjcg-cell-content-down">';
			tpl += '				<ul class="mui-clearfix">';
			tpl += '					<li class="bjcg-cell-content-tag-item">';
			tpl += '						<i class="icon iconfont icon-chenggong"></i><span class="bjcg-cell-content-tag-text">诚信认证</span>';
			tpl += '					</li>';
			tpl += '					<li class="bjcg-cell-content-tag-item">';
			tpl += '						<i class="icon iconfont icon-chenggong"></i><span class="bjcg-cell-content-tag-text">实名认证</span>';
			tpl += '					</li>';
			tpl += '					<li class="bjcg-cell-content-tag-item">';
			tpl += '						 <i class="icon iconfont icon-chenggong"></i><span class="bjcg-cell-content-tag-text">保证金</span>';
			tpl += '					</li>';
			tpl += ' 				</ul>';
			tpl += '			</div>';
			tpl += ' 		</div>';
			tpl += ' 	</div>';
			tpl += ' </a>';
			tpl += ' </div>';
			return tpl;

		},
		/**
		 * 下来刷新
		 */
		firstSearch: function() {
			var self = this;
			self.Param.PageIndex = 1;
			self.pageSearch();
		},

		/**
		 * 选择联系人
		 * @param {Object} userId
		 */
		selectEntrust: function(userId) {

			var self = this,
				conList = self.Param.EntrustList;
			var jsonData = {
				userId: userId
			};
			//关闭当前页面
			if(self.Param.SourcePage) {
				//调用回到函数,并关闭当前页
				var callMethod = BMCW.format("{0}({1})", self.Param.CallBack, JSON.stringify(jsonData));
				var wb = BMCW.getWebviewById(self.Param.SourcePage);

				wb.evalJS(callMethod);

				BMCW.closeWebview(BMCW.routeCfg.useragententrustlist.id);
			}
		},
		updateEntrustList: function(data) {
			var self = this,
				conList = self.Param.EntrustList;
			for(var i = 0; i < data.length; i++) {
				var idx = self.existItem(conList, data[i].UserID);
				if(idx > 0) {
					conList[idx] = data[i];
				} else {
					conList.push(data[i]);
				}
			}
		},
		/**
		 * 显示明细
		 * @param {Object} userId
		 */
		showEntrustDetail: function(userId) {
			var self = this;
			BMCW.openWindow(BMCW.routeCfg.useragententrustinfo, {
				extras: {
					UserId: userId
				}
			});
		},
		existItem: function(items, Id) {
			var result = 0;
			for(var i = 0; i < items.length; i++) {
				if(items[i].UserID == Id) {
					result = i;
					break;
				}
			}
			return result;
		}
	});

	//实例化类
	window.page = new BMCW.BasePage();

})(mui, BMCW);