(function($, BMCW) {
	"use strict";

	BMCW.augment(BMCW.BasePage, {
		/**
		 * 页面路由
		 */
		Route: {
			GetArticleList: "/Article/GetCarBizArticleByCity"
		},
		/**
		 * 参数
		 */
		Param: {
			PageIndex: 1, //页码
			PageSize: 10, //页大小
			PageCount: 0, //总数量
			SourcePage: "", //来源页面
			CallBack: "" //回调方法
		},
		/**
		 * 初始化方法
		 * 页面参数初始化  页面方法初始化  等
		 * @param {Object} options
		 */
		init: function(options) {
			var self = this,
				wb = plus.webview.currentWebview();
			self.Param.SourcePage = wb.SourcePage;
			self.Param.CallBack = wb.CallBack;

			mui.init({
				swipeBack: true //启用右滑关闭功能
			});

			//下拉刷新
			BMCW.setCirclePullToRefresh(function() {
				self.Param.PageIndex = 1;
				self.initView();
			});

			//滑动底部自动分页查询
			document.addEventListener("plusscrollbottom", function() {
				if(self.Param.PageIndex < self.Param.PageCount) {
					self.Param.PageIndex += 1;
					//document.getElementById("div_pullrefresh").style.display = "";
					self.initView();
				}
			}, false);
		},
		/**
		 * 事件绑定
		 * @param {Object} options
		 */
		initEvent: function(options) {
			var self = this;
		},
		/**
		 * 渲染页面
		 * 通过ajax对页面加载显示
		 * @param {Object} options
		 */
		initView: function(options) {
			var self = this;
			self.pageSearch();
		},
		/**
		 * 分页擦鞋
		 */
		pageSearch: function() {
			var self = this;
			BMCW.Ajax.ajax({
				url: self.Route.GetArticleList,
				data: {
					pageIndex: self.Param.PageIndex,
					pageSize: self.Param.PageSize,
					CityId: BMCW.getLocalStorage("LocationID")
				},
				success: function(rdata) {
					if(rdata.status == 0) {
						//如果返回成功,Message赋值总记录数	
						self.renderView(rdata.data, rdata.message);
					} else {
						BMCW.toast(rdata.message);
					}
				}
			});
		},
		/**
		 * 渲染页面
		 * @param {Object} data
		 * @param {type} pageCount
		 */
		renderView: function(data, pageCount) {
			var self = this,
				pageIndex = self.Param.PageIndex,
				content = document.getElementById("muiContent");

			//如果首页,则清空内容
			//如果首页,则清空内容
			if(self.Param.PageIndex == 1) {
				content.innerHTML = "";
				if(data.length < 1) {
					document.getElementById("div_nodata").style.display = "";
				} else {
					document.getElementById("div_nodata").style.display = "none";
				}
			}

			if(data.length > 0) {
				self.Param.PageCount = BMCW.getPageCount(parseInt(pageCount), self.Param.PageSize);

				var tpl = "";
				for(var i = 0; i < data.length; i++) {
					content.innerHTML += self.getTpl(data[i]);
				}

				content.innerHTML += tpl;
			}
		},
		/**
		 * 获取模版
		 */
		getTpl: function(item) {
			var dt = BMCW.formatDate(item.CreatedDate, "yyyy-MM-dd");
			var tpl = '<li class="mui-table-view-cell mui-media bjcg-newslist-bg">';
			tpl += '<a onclick="page.articleDetial(' + item.ArticleId + ');">';
			tpl += '    <img class="mui-media-object bjcg-news-list-img  mui-pull-left" src="' + item.TitleImg + '">';
			tpl += '    <div class="mui-media-body">';
			tpl += '        <h4 class="bjcg-news-list-h4">' + item.Title + '</h4>';
			tpl += '       <p class="mui-ellipsis bjcg-news-list-p">' + dt + '</p>';
			tpl += '    </div>';
			tpl += '</a>';
			tpl += '</li>';
			return tpl;

		},

		firstSearch: function() {
			var self = this;
			self.Param.PageIndex = 1;
			self.pageSearch();
		},
		/**
		 * 
		 * @param {Object} ArticleId
		 */
		articleDetial: function(ArticleId) {
			var self = this;
			BMCW.openWindow(BMCW.routeCfg.articledetial, {
				extras: {
					articleid: ArticleId,
				}
			});
		}
	});

	//实例化类
	window.page = new BMCW.BasePage();

})(mui, BMCW);