(function($, BMCW) {
	"use strict";

	BMCW.augment(BMCW.BasePage, {
		/**
		 * 页面路由
		 */
		Route: {
			GetEnvironmentalPrice: "/Environmental/GetEnvironmentalPrice", //查询支付价格
			AddEnvironmental: "/Environmental/AddEnvironmental", //添加排放标准
			GetEnvironmentalList: "/Environmental/GetEnvironmentalList" //获取查询列表
		},
		/**
		 * 参数
		 */
		Param: {
			PageIndex: 1, //页码showList
			PageSize: 10, //页大小		
			Price: 0
		},
		/**
		 * 初始化方法
		 * 页面参数初始化  页面方法初始化  等
		 * @param {Object} options
		 */
		init: function(options) {
			var self = this,
				wb = plus.webview.currentWebview();

			mui.init({
				swipeBack: true //启用右滑关闭功能
			});

			var usrId = BMCW.getLocalStorage("CurrentUserID") || 0;
			if(usrId < 1) {
				BMCW.openWindow(BMCW.routeCfg.login);
			}
		},
		/**
		 * 事件绑定
		 * @param {Object} options
		 */
		initEvent: function(options) {
			var self = this;

			//选择办理业务
			document.getElementById("btn_sure").addEventListener("tap", function() {
				self.addEnviromnet.call(self);
			}, false);

			//帮助中心
			document.getElementById("a_vin").addEventListener("tap", function() {
				BMCW.openWindow(BMCW.routeCfg.helpcenter);
			}, false);

			//排放标准 tab页
			document.getElementById("li_search").addEventListener("tap", function() {
				var cls = this.classList;
				if(cls.contains("active")) {
					return false;
				}
				document.getElementById("div_list").style.display = "none";
				document.getElementById("div_search").style.display = "block";
				document.getElementById("div_nodata").style.display = "none";
				this.classList.add("active");
				document.getElementById("li_list").classList.remove("active");
			}, false);

			//查询记录tab页
			document.getElementById("li_list").addEventListener("tap", function() {
				var cls = this.classList;
				if(cls.contains("active")) {
					return false;
				}
				document.getElementById("div_search").style.display = "none";
				document.getElementById("div_list").style.display = "block";
				document.getElementById("div_nodata").style.display = "none";
				this.classList.add("active");
				document.getElementById("li_search").classList.remove("active");
				self.Param.PageIndex = 1;
				self.getCommonList(true);
			}, false);

			document.getElementById("ipt_VIN").addEventListener("blur", function() {
				if(!BMCW.isNullOrEmpty(this.value)) {
					this.value = this.value.toUpperCase();
				}
			}, false);

			//下拉刷新
			BMCW.setCirclePullToRefresh(function() {
				if(BMCW.getLocalStorage("CurrentUserID") > 0) {
					if(document.getElementById("li_list").classList.contains("active")) {
						self.Param.PageIndex = 1;
						self.getCommonList(true);
					}
				}
			});

			//滑动底部自动分页查询
			document.addEventListener("plusscrollbottom", function() {
				if(document.getElementById("li_list").classList.contains("active")) {
					if(self.Param.PageIndex < self.Param.PageCount) {
						self.Param.PageIndex += 1;
						self.getCommonList(true);
					}
				}
			}, false);
		},
		/**
		 * 渲染页面
		 * 通过ajax对页面加载显示
		 * @param {Object} options
		 */
		initView: function(options) {
			var self = this;
			//查询支付价格
			BMCW.Ajax.ajax({
				url: self.Route.GetEnvironmentalPrice,
				showLoading: false,
				success: function(rdata) {
					if(rdata.status == 0) {
						//document.getElementById("span_price").innerHTML = '￥' + rdata.data + '元';
						self.Param.Price = rdata.data;
					} else {
						BMCW.toast(rdata.message);
					}
				}
			});
		},
		getCommonList: function(showLoading) {
			var self = this;
			//查询列表
			BMCW.Ajax.ajax({
				url: self.Route.GetEnvironmentalList,
				showLoading: showLoading,
				data: {
					userID: BMCW.getLocalStorage("CurrentUserID"),
					pageIndex: self.Param.PageIndex,
					pageSize: self.Param.PageSize
				},
				success: function(rdata) {
					if(rdata.status == 0) {
						self.renderView(rdata.data, rdata.message);
					} else {
						BMCW.toast(rdata.message);
					}
				}
			});
		},
		/**
		 * 渲染页面
		 * @param {Object} showLoading
		 */
		renderView: function(data, pageCount) {
			var self = this,
				content = document.getElementById("div_list");

			//如果首页,则清空内容
			if(self.Param.PageIndex == 1) {
				content.innerHTML = "";
				if(data.length < 1) {
					document.getElementById("div_nodata").style.display = "";
				} else {
					document.getElementById("div_nodata").style.display = "none";
				}
			}

			if(data.length > 0) {
				self.Param.PageCount = BMCW.getPageCount(parseInt(pageCount), self.Param.PageSize);

				var tpl = "";
				for(var i = 0; i < data.length; i++) {
					tpl += self.getTpl(data[i]);
				}

				content.innerHTML += tpl;
			}
		},
		/**
		 * 渲染模版
		 * @param {Object} data
		 */
		getTpl: function(data) {
			var self = this;
			var refound = '';
			if(data.SearchResult == '查询失败') {
				refound = '<span>(已自动退款)</span>';
			}
			var tpl = '<div class="bjcg-yuyue-item">';
			tpl += '<p class="bjcg-yuyue-item-p">订单编号：<span>' + data.OrderCode + '</span></p>';
			tpl += '<p class="bjcg-yuyue-item-p">下单时间：<span>' + data.CreatedDate + '</span></p>';
			tpl += '<p class="bjcg-yuyue-item-p">车辆VIN码：<span>' + data.VIN + '</span></p>';
			tpl += '<p class="bjcg-yuyue-item-p">支付结果：<b class="bjcg-yuyue-item-b">' + data.PayStatus + '</b></p>';
			tpl += '<p class="bjcg-yuyue-item-p">查询结果：<b class="bjcg-yuyue-item-b">' + data.SearchResult + '</b>' + refound + '</p>';
			if(data.PayStatus == "支付中" || data.PayStatus == "支付失败") {
				tpl += '	<a  onclick="page.registerPay(' + data.EnvStandardID + ');" class="bjcg-pay-btn" href="###">立即支付</a>';
			}
			tpl += '</div>';
			return tpl;
		},
		addEnviromnet: function() {
			var self = this;
			var vinReg = /^[0-9A-Za-z]{17}$/;
			var vin = document.getElementById("ipt_VIN").value;
			if(BMCW.isNullOrEmpty(vin)) {
				BMCW.toast("请填写VIN码");
				return false;
			}
			if(!vinReg.test(vin)) {
				BMCW.toast("请填写正确的VIN码");
				return false;
			}

			BMCW.Ajax.ajax({
				url: self.Route.AddEnvironmental,
				type: "POST",
				data: {
					Price: self.Param.Price,
					VIN: vin,
					CreatedUserID: BMCW.getLocalStorage("CurrentUserID")
				},
				success: function(rdata) {
					if(rdata.status == 0) {
						BMCW.openWindow(BMCW.routeCfg.payment, {
							extras: {
								RegTransferID: rdata.data,
								payPrice: self.Param.Price,
								PayBusiness: 2, //支付业务类型 
								SourcePage: "Environment"
							}
						});
					} else {
						BMCW.toast(rdata.message);
					}
				}
			});
		},
		registerPay: function(regId) {
			var self = this;
			BMCW.openWindow(BMCW.routeCfg.payment, {
				extras: {
					RegTransferID: regId,
					payPrice: self.Param.Price,
					PayBusiness: 2, //支付业务类型 
					SourcePage: "Environment"
				}
			});
		},
		showList: function() {
			var self = this;
			document.getElementById("ipt_VIN").value = "";
			document.getElementById("div_search").style.display = "none";
			document.getElementById("div_list").style.display = "block";
			document.getElementById("li_list").classList.add("active");
			document.getElementById("li_search").classList.remove("active");
			self.Param.PageIndex = 1;
			self.getCommonList(false);
		}
	});

	//实例化类
	window.page = new BMCW.BasePage();

})(mui, BMCW);