(function($, BMCW) {
	"use strict";

	BMCW.augment(BMCW.BasePage, {
		/**
		 * 页面路由
		 */
		Route: {
			GetSurvey: "/Article/GetTrafficBrigade"
		},
		/**
		 * 参数
		 */
		Param: {
			SourcePage: "", //来源页面
			CallBack: "", //回调方法
			CurrentPro: 0, //当前省份
			CurrentCity: 0, //当前城市
			TmpPro: 0, //临时省份
			TmpCity: 0, //临时城市
			divClick: true //因为click事件存在穿透现象,所以需要一个变量锁
		},
		/**
		 * 初始化方法
		 * 页面参数初始化  页面方法初始化  等
		 * @param {Object} options
		 */
		init: function(options) {
			var self = this,
				wb = plus.webview.currentWebview();
			//初始化省份
			self.initProvice();
		},
		/**
		 * 事件绑定
		 * @param {Object} options
		 */
		initEvent: function(options) {
			var self = this,
				divMask = document.getElementById("div_mask");
			document.getElementById("li_downbutton").addEventListener('tap', function() {
				if(divMask.style.display == "none") {
					//设置当前省份和城市样式为选中状态
					document.getElementById("lipro" + self.Param.CurrentPro).classList.add('active');
					self.initCity(self.Param.CurrentPro);
					document.getElementById("licity" + self.Param.CurrentCity).classList.add('active');
					//显示遮罩
					document.getElementById("li_downbutton").classList.add('active');
					divMask.style.display = "block";
				} else {
					//关闭遮罩
					divMask.style.display = "none";
					document.getElementById("lipro" + self.Param.TmpPro).classList.remove('active');
					document.getElementById("li_downbutton").classList.remove('active');
				}
			}, false);

			divMask.addEventListener('click', function(evt) {
				//变量锁
				if(self.Param.divClick) {
					self.Param.divClick = false;
					return false;
				}
				//关闭遮罩
				divMask.style.display = "none";
				document.getElementById("lipro" + self.Param.TmpPro).classList.remove('active');
				document.getElementById("li_downbutton").classList.remove('active');
			}, false);

		},
		/**
		 * 渲染页面
		 * 通过ajax对页面加载显示
		 * @param {Object} options
		 */
        initView: function (options) {
            var self = this;
            //首个省份
            var firPro = cityJson[0];
            self.initCity(firPro.value);
            //首个城市
            var firCity = cityJson[0].childs[0];
            self.clickCity(firCity.value, firPro.value);
            //设置title内容
            document.getElementById("spn_title").innerHTML = firPro.text + "/" + firCity.text;
        },
        /**
		 * 初始化省份
		 */
        initProvice: function () {
            var self = this;
            var ulPro = document.getElementById("ul_provice");
            for (var i = 0; i < cityJson.length; i++) {
                ulPro.innerHTML += self.getProTpl(cityJson[i]);
            }
        },
        /**
		 * 获取省份模版
		 */
        getProTpl: function (item) {
            var tpl = '<li id="lipro' + item.value + '" onclick="page.clickPro(' + item.value + ');" class="pro-box-item">';
            tpl += '     <span class="pro-box-item-text">' + item.text + '</span>';
            tpl += '   </li>';
            return tpl;
        },
        /**
		 * 初始化城市
		 * @param {Object} proId
		 */
        initCity: function (proId) {
            var self = this,
				citylist = [];
            var ulPro = document.getElementById("ul_city");
            ulPro.innerHTML = '';
            for (var i = 0; i < cityJson.length; i++) {
                if (cityJson[i].value == proId) {
                    citylist = cityJson[i].childs;
                    break;
                }
            }
            for (var j = 0; j < citylist.length; j++) {
                ulPro.innerHTML += self.getCityTpl(citylist[j], proId);
            }
        },
        /**
		 * 获取城市模版
		 * @param {Object} item
		 */
        getCityTpl: function (item, proId) {
            var tpl = '<li id="licity' + item.value + '" onclick="page.clickCity(' + item.value + ',' + proId + ');" class="city-box-item">';
            tpl += '     <span class="city-box-item-text">' + item.text + '</span>';
            tpl += '   </li>';
            return tpl;
        },
		/**
		 * 获取检测场
		 */
		getSurvey: function(cityId) {
			var self = this;
			BMCW.Ajax.ajax({
				url: self.Route.GetSurvey,
				data: {
					cityId: cityId
				},
				success: function(rdata) {
					if(rdata.status == 0) {
						//如果返回成功,Message赋值总记录数	
						self.renderView(rdata.data, rdata.message);
					} else {
						BMCW.toast(rdata.message);
					}
				}
			});
		},
		/**
		 * 渲染页面
		 * @param {Object} data
		 * @param {type} pageCount
		 */
		renderView: function(data, pageCount) {
			var self = this,
				pageIndex = self.Param.PageIndex,
				content = document.getElementById("muiContent");

			if(data.length < 1) {
				document.getElementById("div_nodata").style.display = "";
			} else {
				document.getElementById("div_nodata").style.display = "none";
			}

			var tpl = "";
			if(data.length > 0) {
				for(var i = 0; i < data.length; i++) {
					tpl += self.getTpl(data[i]);
				}
			}
			content.innerHTML = tpl;
		},
		/**
		 * 获取模版
		 */
		getTpl: function(item) {
			var tpl = '<li class="filter-box-item">';
			tpl += '     <h4 class="filter-box-item-title">' + item.Name + '</h4>';
			tpl += '     <p class="filter-box-item-text"><i class="icon iconfont icon-didian"></i>' + item.Address + '</p>';
			var wdate = item.WorkDate || '暂无';
			tpl += '     <p class="filter-box-item-text"><i class="icon iconfont icon-shijian"></i>' + wdate + '</p>';
			tpl += '</li>';
			return tpl;
		},
		/**
		 * 单击省份
		 * @param {Object} proId
		 */
		clickPro: function(proId) {
			var self = this;
			//变量锁
			self.Param.divClick = true;
			if(self.Param.TmpPro != proId) {
				document.getElementById("lipro" + self.Param.TmpPro).classList.remove('active');
				self.Param.TmpPro = proId;
				document.getElementById("lipro" + self.Param.TmpPro).classList.add('active');
				self.initCity(proId);
			}
			return false;
		},
		/**
		 * 单击城市
		 * @param {Object} cityId
		 * @param {Object} proId
		 */
		clickCity: function(cityId, proId) {
			var self = this;
			//变量锁
			self.Param.divClick = true;
			if(self.Param.TmpCity == cityId) {
				return;
			}
			//设置当前选中省份和城市
            self.Param.CurrentCity = cityId;
            self.Param.CurrentPro = proId;
            self.Param.TmpPro = proId;
            self.Param.TmpCity = cityId;
            //关闭遮罩
            document.getElementById("div_mask").style.display = "none";
            document.getElementById("li_downbutton").classList.remove('active');

            //更新title内容
            for (var i = 0; i < cityJson.length; i++) {
                if (cityJson[i].value == proId) {
                    var citylist = cityJson[i].childs;
                    for (var j = 0; j < citylist.length; j++) {
                        if (citylist[j].value == cityId) {
                       
                            document.getElementById("spn_title").innerHTML = cityJson[i].text + "/" + citylist[j].text;
                            break;
                        }
                    }
                    break;
                }
            }

			self.getSurvey(cityId);

		}
	});

	//实例化类
	window.page = new BMCW.BasePage();

})(mui, BMCW);