(function($, BMCW) {
	"use strict";

	BMCW.augment(BMCW.BasePage, {
		/**
		 * 页面路由
		 */
		Route: {
			GetViolationResults: "/Violation/GetViolationResults"
		},
		/**
		 * 参数
		 */
		Param: {
			ViolationID: 0, //类型
			CarType: "",
			PlateNumber: "",
			EngineNo: "",
			SourcePage: "", //来源页面
			CallBack: "" //回调方法
		},
		/**
		 * 初始化方法
		 * 页面参数初始化  页面方法初始化  等
		 * @param {Object} options
		 */
		init: function(options) {
			var self = this,
				wb = plus.webview.currentWebview();
			self.Param.ViolationID = wb.ViolationID || 0;
			self.Param.PlateNumber = wb.PlateNumber || "";
			self.Param.EngineNo = wb.EngineNo || "";
			self.Param.CarType = wb.CarType || "02";

			mui.init({
				swipeBack: true //启用右滑关闭功能				
			});
		},
		/**
		 * 事件绑定
		 * @param {Object} options
		 */
		initEvent: function(options) {
			var self = this;

		},
		/**
		 * 渲染页面
		 * 通过ajax对页面加载显示
		 * @param {Object} options
		 */
		initView: function(options) {
			var self = this;

			BMCW.closeWebview(BMCW.routeCfg.violation.id, "none");
			document.getElementById("spn_CarType").innerHTML = self.Param.CarType == "01" ? "大型货车" : "小型汽车";
			document.getElementById("spn_PlateNumber").innerHTML = self.Param.PlateNumber;
			document.getElementById("spn_EngineNo").innerHTML = self.Param.EngineNo;
			self.GetViolationResults();
		},
		/**
		 * 根据状态获取列表
		 */
		GetViolationResults: function() {
			var self = this;
			BMCW.Ajax.ajax({
				url: self.Route.GetViolationResults,
				data: {
					violationId: self.Param.ViolationID
				},
				success: function(rdata) {
					if(rdata.status == 0) {
						//如果返回成功,Message赋值总记录数	
						self.renderView(rdata.data, rdata.message);
					} else {
						BMCW.toast(rdata.message);
					}
				}
			});
		},
		/**
		 * 渲染页面
		 * @param {Object} data
		 */
		renderView: function(data, pageCount) {
			var self = this,
				content = document.getElementById("muiContent");

			if(data.length > 0) {
				document.getElementById("b_ViolationCount").innerHTML = data.length;
				document.getElementById("p_HasViolation").style.display = "";

				var tpl = "";
				for(var i = 0; i < data.length; i++) {
					content.innerHTML += self.getTpl(data[i]);
				}

				content.innerHTML += tpl;
			} else {
				document.getElementById("p_noViolation").style.display = "";
			}
		},
		/**
		 * 获取模版
		 */
		getTpl: function(item) {
			var self = this;
			var bittype = '记' + item.Point + '分,罚款' + item.Fine + '元';

			var tpl = '<li>';
			tpl += '<p class="bjcg-wz-result-list-p">违章时间：<span>' + BMCW.formatDate(item.ViolationTime, "yyyy-MM-dd HH:mm") + '</span></p>';
			tpl += '<p class="bjcg-wz-result-list-p">违章处理：<span>' + bittype + '</span></p>';
			tpl += '<p class="bjcg-wz-result-list-p">违法地址：<span>' + item.Address + '</span></p>';
			tpl += '<p class="bjcg-wz-result-list-p">违法行为：<span>' + item.Reason + '</span></p>';

			tpl += '</li>';
			return tpl;
		}
	});

	//实例化类
	window.page = new BMCW.BasePage();

})(mui, BMCW);