(function($, BMCW) {
	"use strict";

	BMCW.augment(BMCW.BasePage, {
		/**
		 * 页面路由
		 */
		Route: {
			GetTransferUserByType: "/TransferUser/GetTransferUserByType", //根据过户申请ID和类型查询
			GetTransferUser: "/TransferUser/GetTransferUser", //根据主键查询
			AddTransferUser: "/TransferUser/AddTransferUser",
			UpdateTransferUser: "/TransferUser/UpdateTransferUser",
			UpdateTransferUserNoImage: "/TransferUser/UpdateTransferUserNoImage"
		},
		/**
		 * 参数
		 */
		Param: {
			TransferUserID: 0, //主键
			BizTypeID: 0,
			Data: {
				TransferType: 1, //申请人类型 1：买方 2：卖方
				TransferUserType: 1, //买(卖)方类型1：个人，2：公司
				IsLocal: 1 //买方户籍 1：本地 2：其他
			},
			ImageArr: {}, //图片对象
			SourcePage: "", //来源页面
			CallBack: "" //回调方法
		},
		/**
		 * 初始化方法
		 * 页面参数初始化  页面方法初始化  等
		 * @param {Object} options
		 */
		init: function(options) {
			var self = this,
				wb = plus.webview.currentWebview();
			self.Param.TransferUserID = wb.TransferUserID || 0;
			self.Param.SourcePage = wb.SourcePage;
			self.Param.CallBack = wb.CallBack;
			self.Param.BizTypeID = wb.BizTypeID || 0;

			mui.init({
				swipeBack: true //启用右滑关闭功能
			});
		},
		/**
		 * 事件绑定
		 * @param {Object} options
		 */
		initEvent: function(options) {
			var self = this;

			//卖方类型 1：个人 2：公司
			document.getElementById("dl_TransferUserType1").addEventListener("tap", function() {
				var chk = document.getElementById("i_TransferUserType1");
				if(chk.classList.contains("checked")) {
					return false;
				}
				chk.classList.add("checked");
				document.getElementById("i_TransferUserType2").classList.remove("checked");
				document.getElementById("dl_TransferUserName").innerHTML = '<b>*</b>姓名：';
				document.getElementById("ipt_TransferUserName").placeholder = '请输入姓名';
				document.getElementById("span_IdentityDesc").innerHTML = '买方身份证正面';

				if(document.getElementById("i_IsLocal1").classList.contains("checked")) {
					document.getElementById("div_ResidenceImage").style.display = "none";
				} else {
					document.getElementById("div_ResidenceImage").style.display = "";
				}
				document.getElementById("dl_IsLocal").style.display = "";
				self.Param.Data.TransferUserType = 1;

				self.setNoticeMsg(self.Param.BizTypeID, 1);
			}, false);

			document.getElementById("dl_TransferUserType2").addEventListener("tap", function() {
				var chk = document.getElementById("i_TransferUserType2");
				if(chk.classList.contains("checked")) {
					return false;
				}
				chk.classList.add("checked");
				document.getElementById("i_TransferUserType1").classList.remove("checked");
				document.getElementById("dl_TransferUserName").innerHTML = '<b>*</b>公司全称：';
				document.getElementById("ipt_TransferUserName").placeholder = '请输入公司全称';
				document.getElementById("span_IdentityDesc").innerHTML = '买方营业执照正面';
				document.getElementById("dl_IsLocal").style.display = "none";

				document.getElementById("div_ResidenceImage").style.display = "none";
				self.Param.Data.TransferUserType = 2;
				self.setNoticeMsg(self.Param.BizTypeID, 2);
			}, false);

			//是否户籍所在地 1：本地 2 ：外地
			document.getElementById("dl_IsLocal1").addEventListener("tap", function() {
				var chk = document.getElementById("i_IsLocal1");
				if(chk.classList.contains("checked")) {
					return false;
				}
				chk.classList.add("checked");
				document.getElementById("i_IsLocal2").classList.remove("checked");
				document.getElementById("div_ResidenceImage").style.display = "none";

				self.Param.Data.IsLocal = 1;
			}, false);

			document.getElementById("dl_IsLocal2").addEventListener("tap", function() {
				var chk = document.getElementById("i_IsLocal2");
				if(chk.classList.contains("checked")) {
					return false;
				}
				chk.classList.add("checked");
				document.getElementById("i_IsLocal1").classList.remove("checked");
				document.getElementById("div_ResidenceImage").style.display = "";
				self.Param.Data.IsLocal = 2;
			}, false);

			document.getElementById("img_IdentityImage").addEventListener('tap', function() {
				self.showActionsheet("IdentityImage");
			}, false);
			document.getElementById("img_QuotaImage").addEventListener('tap', function() {
				self.showActionsheet("QuotaImage");
			}, false);
			document.getElementById("img_ResidenceImage").addEventListener('tap', function() {
				self.showActionsheet("ResidenceImage");
			}, false);

			document.getElementById("btn_sure").addEventListener("tap", function() {
				self.beforeSubmit.call(self);
			}, false);
		},
		/**
		 * 渲染页面
		 * 通过ajax对页面加载显示
		 * @param {Object} options
		 */
		initView: function(options) {
			var self = this;
			if(self.Param.BizTypeID == 58) {
				document.getElementById("dd_IsLocal1").innerHTML = "户籍所在地";
				document.getElementById("dd_IsLocal2").innerHTML = "非户籍所在地";
			} else {
				document.getElementById("div_QuotaImage").style.display = "";
			}

			if(self.Param.TransferUserID > 0) {
				self.getTransferUser();
			} else {
				self.setNoticeMsg(self.Param.BizTypeID, 1);
			}
		},
		/**
		 * 渲染页面
		 * @param {Object} data
		 */
		getTransferUser: function() {
			var self = this;
			BMCW.Ajax.ajax({
				url: self.Route.GetTransferUser,
				data: {
					transferUserId: self.Param.TransferUserID
				},
				success: function(rdata) {
					if(rdata.status == 0) {
						self.Param.Data = rdata.data;
						self.renderView(rdata.data);
					} else {
						BMCW.toast(rdata.message);
					}
				}
			});
		},
		/**
		 * 获取模版
		 */
		renderView: function(item) {
			var self = this;
			//办理人类型，1：个人，2：公司
			if(item.TransferUserType == 1) {
				document.getElementById("i_TransferUserType1").classList.add("checked");
				document.getElementById("i_TransferUserType2").classList.remove("checked");
			} else {
				document.getElementById("i_TransferUserType2").classList.add("checked");
				document.getElementById("i_TransferUserType1").classList.remove("checked");
			}
			if(item.IsLocal == 1) {
				document.getElementById("i_IsLocal1").classList.add("checked");
				document.getElementById("i_IsLocal2").classList.remove("checked");
				document.getElementById("div_ResidenceImage").style.display = "none";
			} else {
				document.getElementById("i_IsLocal2").classList.add("checked");
				document.getElementById("i_IsLocal1").classList.remove("checked");
				document.getElementById("dl_IsLocal").style.display = "none";
				document.getElementById("div_ResidenceImage").style.display = "";
				document.getElementById("img_ResidenceImage").src = item.ResidenceImage;
			}
			//本市显示指标
			if(self.Param.BizTypeID == 59) {
				document.getElementById("img_QuotaImage").src = item.QuotaImage;
			}
			document.getElementById("ipt_TransferUserName").value = item.TransferUserName;
			document.getElementById("ipt_Mobile").value = item.Mobile;
			document.getElementById("ipt_DealPrice").value = item.DealPrice;
			document.getElementById("img_IdentityImage").src = item.IdentityImage;

			self.setNoticeMsg(self.Param.BizTypeID, item.TransferUserType);
		},
		/**
		 * 提交验证
		 */
		beforeSubmit: function() {
			var self = this;
			self.Param.Data.TransferUserName = mui("#ipt_TransferUserName").val();
			self.Param.Data.Mobile = mui("#ipt_Mobile").val();
			self.Param.Data.DealPrice = mui("#ipt_DealPrice").val();

			if(BMCW.isNullOrEmpty(self.Param.Data.TransferUserName)) {
				if(self.Param.Data.TransferUserType == 1) {
					BMCW.toast("请输入姓名");
				} else {
					BMCW.toast("请输入公司全称");
				}
				return false;
			}
			if(BMCW.isNullOrEmpty(self.Param.Data.Mobile)) {
				BMCW.toast("请输入手机号码");
				return false;
			}
			if(!BMCW.isMobile(self.Param.Data.Mobile)) {
				BMCW.toast("请输入正确的手机号码");
				return false;
			}
			if(BMCW.isNullOrEmpty(self.Param.Data.DealPrice)) {
				BMCW.toast("请输入交易金额");
				return false;
			}
			if(!BMCW.isPrice(self.Param.Data.DealPrice)) {
				BMCW.toast("请输入正确的交易金额");
				return false;
			}

			//如果用户ID为空，则为添加
			if(BMCW.isNullOrEmpty(self.Param.Data.TransferUserID)) {
				if(BMCW.isNullOrEmpty(self.Param.ImageArr.IdentityImage)) {
					if(self.Param.Data.TransferUserType == 1) {
						BMCW.toast("请上传买方身份证正面");
					} else {
						BMCW.toast("请上传买方营业执照正面");
					}
					return false;
				}
				//本市显示指标
				if(self.Param.BizTypeID == 59) {
					if(BMCW.isNullOrEmpty(self.Param.ImageArr.QuotaImage)) {
						BMCW.toast("请上传买方配置指标/更新指标");
						return false;
					}
				}
				if(self.Param.Data.IsLocal == 2) {
					if(BMCW.isNullOrEmpty(self.Param.ImageArr.ResidenceImage)) {
						BMCW.toast("买方居住卡/证正面");
						return false;
					}
				}
			}
			if(self.Param.TransferUserID > 0) {
				var hasImage = false;
				for(var k in self.Param.ImageArr) {
					hasImage = true;
					break;
				}
				//有无图片编辑,处理方法不一样
				if(hasImage) {
					self.addEditTransferUser(true);
				} else {
					self.UpdateTransferUserNoImage();
				}
			} else {
				self.addEditTransferUser(false);
			}
		},
		/**
		 * 显示选择框
		 */
		showActionsheet: function(attrname) {
			var self = this;
			var btnArray = [{
				title: "拍照"
			}, {
				title: "从相册选择"
			}];
			plus.nativeUI.actionSheet({
				title: "上传证件",
				cancel: "取消",
				buttons: btnArray
			}, function(e) {
				var index = e.index;
				switch(index) {
					case 0:
						break;
					case 1:
						self.imgCamera(attrname);
						break;
					case 2:
						self.galleryImgs(attrname);
						break;
				}
			});
		},
		/**
		 * 照相
		 */
		imgCamera: function(attrname) {
			var self = this;
			var cmr = plus.camera.getCamera(1);
			var imgName = new Date().getTime();
			plus.io.requestFileSystem(plus.io.PUBLIC_DOCUMENTS, function(fs) {
				cmr.captureImage(function(path) {
						plus.gallery.save(path, function(e) {
							console.log("图片保存到相册成功.");
						}, function(e) {
							console.log("图片保存到相册失败.");
						})
						self.getPrivatePath([path], attrname);
					},
					function(error) {
						console.log("调用照相失败: " + error.message);
					}, {
						filename: fs.root.fullPath
					});
			}, function(e) {
				console.log("Request file system failed: " + e.message);
			});

		},
		/**
		 * 相册选取
		 */
		galleryImgs: function(attrname) {
			var self = this;
			plus.gallery.pick(function(e) {
				var fileArr = [];
				fileArr.push(e);
				self.getPrivatePath(fileArr, attrname);

			}, function(e) {
				console.log("取消选择图片");
			}, {
				filter: "image",
				multiple: false
			});
		},
		/**
		 * 获取私有路径
		 * @param {Object} files
		 */
		getPrivatePath: function(files, attrname) {
			var self = this;
			plus.io.requestFileSystem(plus.io.PRIVATE_DOC,
				function(fs) {
					fs.root.getDirectory(fs.root.fullPath, {
							create: true //如果不存在,则创建
						},
						function(dir) {
							for(var i in files) {
								var sPath = files[i];
								var tPath = fs.root.toLocalURL() + self.getFileName(sPath); //ios只支持绝对路径
								self.compressPhoto(sPath, tPath, files.length, attrname);
							}
						},
						function(e) {
							console.log("创建/获取目录失败:" + e.message)
						});
				},
				function(e) {
					console.log("获取文件私有路径失败:" + e.message);
				});
		},
		/**
		 * 图片压缩
		 * @param {Object} sPath
		 * @param {Object} tPath		
		 * @param {Object} targetLength
		 * @param {Object} attrname
		 */
		compressPhoto: function(sPath, tPath, targetLength, attrname) {
			var self = this;
			//必须声明新变量,否则js内存泄漏，filePath永远是最后一次传入值
			var fp = sPath,
				dfp = tPath;
			plus.zip.compressImage({
					src: fp,
					dst: dfp,
					quality: 20,
					overwrite: true
				},
				function() {
					self.Param.ImageArr[attrname] = dfp;
					document.getElementById("img_" + attrname).src = dfp;
					console.log("文件压缩成功.");
				},
				function(error) {
					console.log("文件压缩失败:" + error.code + "," + error.message);
				});
		},
		getFileName: function(filepath) { //获取文件名
			var pos = filepath.lastIndexOf("/");
			if(pos == -1) {
				pos = filepath.lastIndexOf("\\")
			}
			var filename = filepath.substring(pos + 1)
			return filename;
		},
		/**
		 * 添加卖方信息
		 */
		addEditTransferUser: function(isEdit) {
			var self = this;
			var reg = new RegExp('"', "g");
			var upurl = BMCW.baseUrl + self.Route.AddTransferUser;
			if(isEdit) {
				upurl = BMCW.baseUrl + self.Route.UpdateTransferUser;
			}
			var task = plus.uploader.createUpload(
				upurl, {
					method: "POST"
				},
				function(upload, status) {
					plus.nativeUI.closeWaiting();
					if(status == 200) {
						var jsonData = {
							TransferUserID: upload.responseText.replace(reg, ""),
							TransferUserName: self.Param.Data.TransferUserName,
							DealPrice: self.Param.Data.DealPrice
						};

						//调用回调函数,关闭当前页
						if(self.Param.SourcePage) {
							var callMethod = BMCW.format("{0}({1})", self.Param.CallBack, JSON.stringify(jsonData));
							var wb = BMCW.getWebviewById(self.Param.SourcePage);
							wb.evalJS(callMethod);
						}

						BMCW.closeWebview(BMCW.routeCfg.buyer.id);
					} else {
						console.log("文件上传失败.");
					}
				});

			for(var k in self.Param.ImageArr) {
				task.addFile(self.Param.ImageArr[k], {
					key: k
				})
			}
			if(isEdit) {
				task.addData('TransferUserID', self.Param.Data.TransferUserID.toString()); //task只接收字符串格式内容
			}
			task.addData('TransferUserName', self.Param.Data.TransferUserName);
			task.addData('Mobile', self.Param.Data.Mobile);
			task.addData('TransferType', "1");
			task.addData('DealPrice', self.Param.Data.DealPrice.toString());
			task.addData('IsLocal', self.Param.Data.IsLocal.toString());
			task.addData('TransferUserType', self.Param.Data.TransferUserType.toString());
			task.start();
			plus.nativeUI.showWaiting("保存中...");
		},
		UpdateTransferUserNoImage: function() {
			var self = this;
			BMCW.Ajax.ajax({
				url: self.Route.UpdateTransferUserNoImage,
				type: "POST",
				data: self.Param.Data,
				success: function(rdata) {
					if(rdata.status == 0) {
						var reg = new RegExp('"', "g");
						var jsonData = {
							TransferUserID: rdata.data.replace(reg, ""),
							TransferUserName: self.Param.Data.TransferUserName,
							DealPrice: self.Param.Data.DealPrice
						};

						//调用回调函数,关闭当前页
						if(self.Param.SourcePage) {
							var callMethod = BMCW.format("{0}({1})", self.Param.CallBack, JSON.stringify(jsonData));
							var wb = BMCW.getWebviewById(self.Param.SourcePage);
							wb.evalJS(callMethod);
						}

						BMCW.closeWebview(BMCW.routeCfg.buyer.id);
					} else {
						BMCW.toast(rdata.message);
					}
				}
			});
		},
		/**
		 * 显示示例
		 * @param {Object} imgId
		 */
		showImage: function(imgId) {
			var self = this;
			if(imgId == "imgIdentityImage") {
				if(document.getElementById("i_TransferUserType1").classList.contains("checked")) {
					imgId = imgId + "1";
				} else {
					imgId = imgId + "2";
				}
			}
			document.getElementById(imgId).style.display = "block";
		},
		/**
		 * 关闭示例
		 * @param {Object} imgId
		 */
		slClose: function(imgId) {
			document.getElementById(imgId).style.display = "none";
		},
		/**
		 * 根据不通类型显示不通提示
		 * @param {Object} bittype
		 * @param {Object} usertype
		 */
		setNoticeMsg: function(bittype, usertype) {
			if(bittype == 58) { //外迁
				if(usertype == 1) { //个人
					document.getElementById("li_notice").innerHTML = "车辆外迁，如果车辆落户城市为买方户籍城市，只需上传有效期内身份证正面照片；如果落户城市不是买方户籍城市，需上传有效期内居住卡（含居住证、暂住证、派出所盖章居住证明）正面照片。";
				} else {
					document.getElementById("li_notice").innerHTML = "车辆外迁，需提供买方在落户城市公司营业执照正面照片。";
				}
			} else {
				if(usertype == 1) { //个人
					document.getElementById("li_notice").innerHTML = "本市过户，如果买方为北京户籍，只需上传有效期内身份证正面照片；如果是非北京户籍，需上传有效期内居住卡（含居住证、暂住证、工作居住证）正面照片。";
				} else {
					document.getElementById("li_notice").innerHTML = "本市过户，需提供买方在本市公司营业执照正面照片。";
				}
			}
		}
	});

	//实例化类
	window.page = new BMCW.BasePage();

})(mui, BMCW);