(function($, BMCW) {
	"use strict";

	BMCW.augment(BMCW.BasePage, {
		/**
		 * 页面路由
		 */
		Route: {
			GetTransferCar: "/TransferCar/GetTransferCar", //根据主键查询
			AddTransferCar: "/TransferCar/AddTransferCar",
			UpdateTransferCar: "/TransferCar/UpdateTransferCar"
		},
		/**
		 * 参数
		 */
		Param: {
			TransferCarID: 0, //主键			
			ImageArr: {}, //图片对象
			SourcePage: "", //来源页面
			CallBack: "" //回调方法
		},
		/**
		 * 初始化方法
		 * 页面参数初始化  页面方法初始化  等
		 * @param {Object} options
		 */
		init: function(options) {
			var self = this,
				wb = plus.webview.currentWebview();
			self.Param.TransferCarID = wb.TransferCarID || 0;
			self.Param.SourcePage = wb.SourcePage;
			self.Param.CallBack = wb.CallBack;

			mui.init({
				swipeBack: true //启用右滑关闭功能
			});
		},
		/**
		 * 事件绑定
		 * @param {Object} options
		 */
		initEvent: function(options) {
			var self = this;

			document.getElementById("img_CarImage").addEventListener('tap', function() {
				self.showActionsheet("CarImage");
			}, false);

			document.getElementById("btn_sure").addEventListener("tap", function() {
				self.beforeSubmit.call(self);
			}, false);
		},
		/**
		 * 渲染页面
		 * 通过ajax对页面加载显示
		 * @param {Object} options
		 */
		initView: function(options) {
			var self = this;
			if(self.Param.TransferCarID > 0) {
				self.getTransferCar();
			}
		},
		/**
		 * 渲染页面
		 * @param {Object} data
		 */
		getTransferCar: function() {
			var self = this;
			BMCW.Ajax.ajax({
				url: self.Route.GetTransferCar,
				data: {
					TransferCarId: self.Param.TransferCarID
				},
				success: function(rdata) {
					if(rdata.status == 0) {
						self.Param.Data = rdata.data;
						self.renderView(rdata.data);
					} else {
						BMCW.toast(rdata.message);
					}
				}
			});
		},
		/**
		 * 获取模版
		 */
		renderView: function(item) {
			var self = this;			
			document.getElementById("img_CarImage").src = item.CarImage;
		},
		/**
		 * 提交验证
		 */
		beforeSubmit: function() {
			var self = this;
			
			if(self.Param.TransferCarID > 0) {
				var hasImage = false;
				for(var k in self.Param.ImageArr) {
					hasImage = true;
					break;
				}
				//有无图片编辑,处理方法不一样
				if(hasImage) {
					self.addEditTransferCar(true);
				} else {
					BMCW.closeWebview(BMCW.routeCfg.car.id);
				}
			} else {
				var hasImage = false;
				for(var k in self.Param.ImageArr) {
					hasImage = true;
					break;
				}
				if(hasImage){
					self.addEditTransferCar(false);
				}else{
					BMCW.toast('请上传车辆照片');
					return false;
				}
				
			}
		},
		/**
		 * 显示选择框
		 */
		showActionsheet: function(attrname) {
			var self = this;
			var btnArray = [{
				title: "拍照"
			}, {
				title: "从相册选择"
			}];
			plus.nativeUI.actionSheet({
				title: "上传车辆信息",
				cancel: "取消",
				buttons: btnArray
			}, function(e) {
				var index = e.index;
				switch(index) {
					case 0:
						break;
					case 1:
						self.imgCamera(attrname);
						break;
					case 2:
						self.galleryImgs(attrname);
						break;
				}
			});
		},
		/**
		 * 照相
		 */
		imgCamera: function(attrname) {
			var self = this;
			var cmr = plus.camera.getCamera(1);
			var imgName = new Date().getTime();
			plus.io.requestFileSystem(plus.io.PUBLIC_DOCUMENTS, function(fs) {
				cmr.captureImage(function(path) {
						plus.gallery.save(path, function(e) {
							console.log("图片保存到相册成功.");
						}, function(e) {
							console.log("图片保存到相册失败.");
						})
						self.getPrivatePath([path], attrname);
					},
					function(error) {
						console.log("调用照相失败: " + error.message);
					}, {
						filename: fs.root.fullPath
					});
			}, function(e) {
				console.log("Request file system failed: " + e.message);
			});

		},
		/**
		 * 相册选取
		 */
		galleryImgs: function(attrname) {
			var self = this;
			plus.gallery.pick(function(e) {
				var fileArr = [];
				fileArr.push(e);
				self.getPrivatePath(fileArr, attrname);

			}, function(e) {
				console.log("取消选择图片");
			}, {
				filter: "image",
				multiple: false
			});
		},
		/**
		 * 获取私有路径
		 * @param {Object} files
		 */
		getPrivatePath: function(files, attrname) {
			var self = this;
			plus.io.requestFileSystem(plus.io.PRIVATE_DOC,
				function(fs) {
					fs.root.getDirectory(fs.root.fullPath, {
							create: true //如果不存在,则创建
						},
						function(dir) {
							for(var i in files) {
								var sPath = files[i];
								var tPath = fs.root.toLocalURL() + self.getFileName(sPath); //ios只支持绝对路径
								self.compressPhoto(sPath, tPath, files.length, attrname);
							}
						},
						function(e) {
							console.log("创建/获取目录失败:" + e.message)
						});
				},
				function(e) {
					console.log("获取文件私有路径失败:" + e.message);
				});
		},
		/**
		 * 图片压缩
		 * @param {Object} sPath
		 * @param {Object} tPath		
		 * @param {Object} targetLength
		 * @param {Object} attrname
		 */
		compressPhoto: function(sPath, tPath, targetLength, attrname) {
			var self = this;
			//必须声明新变量,否则js内存泄漏，filePath永远是最后一次传入值
			var fp = sPath,
				dfp = tPath;
			plus.zip.compressImage({
					src: fp,
					dst: dfp,
					quality: 20,
					overwrite: true
				},
				function() {
					self.Param.ImageArr[attrname] = dfp;
					document.getElementById("img_" + attrname).src = dfp;
					console.log("文件压缩成功.");
				},
				function(error) {
					console.log("文件压缩失败:" + error.code + "," + error.message);
				});
		},
		getFileName: function(filepath) { //获取文件名
			var pos = filepath.lastIndexOf("/");
			if(pos == -1) {
				pos = filepath.lastIndexOf("\\")
			}
			var filename = filepath.substring(pos + 1)
			return filename;
		},
		/**
		 * 添加卖方信息
		 */
		addEditTransferCar: function(isEdit) {
			var self = this;
			var reg = new RegExp('"', "g");
			var upurl = BMCW.baseUrl + self.Route.AddTransferCar;
			if(isEdit) {
				upurl = BMCW.baseUrl + self.Route.UpdateTransferCar;
			}
			var task = plus.uploader.createUpload(
				upurl, {
					method: "POST"
				},
				function(upload, status) {
					plus.nativeUI.closeWaiting();
					if(status == 200) {
						var jsonData = {
							TransferCarID: upload.responseText.replace(reg, "")
						};

						//调用回调函数,关闭当前页
						if(self.Param.SourcePage) {
							var callMethod = BMCW.format("{0}({1})", self.Param.CallBack, JSON.stringify(jsonData));
							var wb = BMCW.getWebviewById(self.Param.SourcePage);
							wb.evalJS(callMethod);
						}

						BMCW.closeWebview(BMCW.routeCfg.car.id);
					} else {
						console.log("文件上传失败.");
					}
				});

			for(var k in self.Param.ImageArr) {
				task.addFile(self.Param.ImageArr[k], {
					key: k
				})
			}
			if(isEdit) {
				task.addData('TransferCarID', self.Param.Data.TransferCarID.toString()); //task只接收字符串格式内容
			}
			task.start();
			plus.nativeUI.showWaiting("保存中...");
		},
		/**
		 * 显示示例
		 * @param {Object} imgId
		 */
		showImage: function(imgId) {
			var self = this;			
			document.getElementById(imgId).style.display = "block";
		},
		/**
		 * 关闭示例
		 * @param {Object} imgId
		 */
		slClose: function(imgId) {
			document.getElementById(imgId).style.display = "none";
		}
	});

	//实例化类
	window.page = new BMCW.BasePage();

})(mui, BMCW);