(function($, BMCW) {
	"use strict";

	BMCW.augment(BMCW.BasePage, {
		/**
		 * 页面路由
		 */
		Route: {
			GetAlipayInfo: "/Payment/GetAlipayInfo", //获取阿里支付信息
			GetWxpayInfo: "/Payment/GetWxpayInfo", //获取微信支付信息		
			GetAlipayV1: "/Payment/GetAlipayV1", //获取阿里支付信息
			GetWxpayV1: "/Payment/GetWxpayV1", //获取微信支付信息		
			AddPayment: "/Payment/AddPayment", //支付
			GetTransferPrice: "/RegTransfer/GetTransferPrice", //获取过户金额
			GetEnvironmentalPrice: "/Environmental/GetEnvironmentalPrice" //查询支付价格
		},
		/**
		 * 参数
		 */
		Param: {
			pays: {}, //支付通道
			payPrice: 0, //支付金额
			RegTransferID: 0,
			PayBusiness: 0, //支付业务类型
			SourcePage: "" //调用页面
		},
		/**
		 * 初始化方法
		 * 页面参数初始化  页面方法初始化  等
		 * @param {Object} options
		 */
		init: function(options) {
			var self = this,
				wb = plus.webview.currentWebview();
			self.Param.RegTransferID = wb.RegTransferID;
			self.Param.payPrice = wb.payPrice || 0;
			self.Param.PayBusiness = wb.PayBusiness || 0;
			self.Param.SourcePage = wb.SourcePage || "";

			mui.init({
				swipeBack: true //启用右滑关闭功能				
			});
		},
		/**
		 * 事件绑定
		 * @param {Object} options
		 */
		initEvent: function(options) {
			var self = this;
			var wb = plus.webview.currentWebview();

			//微信支付
			document.getElementById("li_wxpay").addEventListener("tap", function() {
				var ichk = document.getElementById("i_wxpay");
				if(ichk.classList.contains("checked")) {
					return false;
				}
				ichk.classList.add("checked");
				document.getElementById("i_alipay").classList.remove("checked");
			}, false);

			//阿里支付
			document.getElementById("li_alipay").addEventListener("tap", function() {
				var ichk = document.getElementById("i_alipay");
				if(ichk.classList.contains("checked")) {
					return false;
				}
				ichk.classList.add("checked");
				document.getElementById("i_wxpay").classList.remove("checked");
			}, false);

			//确认支付
			document.getElementById("btn_sure").addEventListener("tap", function() {
				if(self.Param.PayBusiness == 1) {
					self.pay.call(self);
				} else {
					self.payV1.call(self);
				}

			}, false);
		},
		/**
		 * 渲染页面
		 * 通过ajax对页面加载显示
		 * @param {Object} options
		 */
		initView: function(options) {
			var self = this;

			self.getPayPrice();

			plus.payment.getChannels(function(channels) {
				var content = document.getElementById('dcontent');
				for(var i in channels) {
					var channel = channels[i];
					if(channel.id == 'qhpay' || channel.id == 'qihoo') { // 过滤掉不支持的支付通道：暂不支持360相关支付
						continue;
					}
					switch(channel.id) {
						case "qhpay":
						case "qihoo":
							break;
						case "alipay":
							document.getElementById("li_alipay").style.display = "";
							break;
						case "wxpay":
							document.getElementById("li_wxpay").style.display = "";
							break;
					}
					self.Param.pays[channel.id] = channel;
				}
			}, function(e) {
				outLine('获取支付通道失败：' + e.message);
			});
		},
		/**
		 * 支付
		 */
		pay: function() {
			var self = this;
			var gurl = self.Route.GetAlipayInfo;
			var id = "alipay";
			if(document.getElementById("i_wxpay").classList.contains("checked")) {
				gurl = self.Route.GetWxpayInfo;
				id = "wxpay";
			}
			BMCW.Ajax.ajax({
				url: gurl,
				data: {
					registerID: self.Param.RegTransferID,
					total: self.Param.payPrice
				},
				success: function(rdata) {
					if(rdata.status == 0) {
						plus.payment.request(self.Param.pays[id], rdata.data, function(result) {
							self.addPayment(id, rdata.message);
						}, function(e) {
							BMCW.openWindow(BMCW.routeCfg.payerror, {
								extras: {
									code: e.code,
									message: e.message,
									RegTransferID: self.Param.RegTransferID
								}
							});
						});
					} else {
						BMCW.toast(rdata.message);
					}
				}
			});
		},
		payV1: function() {
			var self = this;
			var gurl = self.Route.GetAlipayV1;
			var id = "alipay";
			if(document.getElementById("i_wxpay").classList.contains("checked")) {
				gurl = self.Route.GetWxpayV1;
				id = "wxpay";
			}
			BMCW.Ajax.ajax({
				url: gurl,
				data: {
					registerID: self.Param.RegTransferID,
					total: self.Param.payPrice,
					payBody: "车管在线-排放标准"
				},
				success: function(rdata) {
					if(rdata.status == 0) {
						plus.payment.request(self.Param.pays[id], rdata.data, function(result) {
							self.addPayment(id, rdata.message);
						}, function(e) {
							BMCW.openWindow(BMCW.routeCfg.payerror, {
								extras: {
									code: e.code,
									message: e.message,
									RegTransferID: self.Param.RegTransferID
								}
							});
						});
					} else {
						BMCW.toast(rdata.message);
					}
				}
			});
		},
		/**
		 * 添加支付
		 * @param {Object} id
		 * @param {Object} tradeno
		 */
		addPayment: function(id, tradeno) {
			var self = this;
			var paytype = id == "alipay" ? 1 : 2;
			var data = {
				PayType: paytype,
				RegTransferID: self.Param.RegTransferID,
				PayPrice: self.Param.payPrice,
				PlatformCode: tradeno,
				PayBusiness: self.Param.PayBusiness
			};
			BMCW.Ajax.ajax({
				url: self.Route.AddPayment,
				type: "POST",
				data: data,
				showLoading: false,
				success: function(rdata) {
					if(rdata.status == 0) {
						self.paySuccess();
					} else {
						BMCW.openWindow(BMCW.routeCfg.payerror, {
							extras: {
								RegTransferID: rdata.data
							}
						});
					}
				}
			});
		},
		getPayPrice: function() {
			var self = this;
			if(self.Param.PayBusiness == 1) { //过户支付				
				BMCW.Ajax.ajax({
					url: self.Route.GetTransferPrice,
					showLoading: false,
					data: {
						regTransferID: self.Param.RegTransferID
					},
					success: function(rdata) {
						if(rdata.status == 0) {
							self.Param.payPrice = rdata.data;
							document.getElementById("span_PayPrice").innerHTML = rdata.data;
						} else {
							BMCW.toast(rdata.message);
						}
					}
				});
			} else if(self.Param.PayBusiness == 2) { //排放标准
				BMCW.Ajax.ajax({
					url: self.Route.GetEnvironmentalPrice,
					showLoading: false,
					success: function(rdata) {
						if(rdata.status == 0) {
							self.Param.payPrice = rdata.data;
							document.getElementById("span_PayPrice").innerHTML = rdata.data;
						} else {
							BMCW.toast(rdata.message);
						}
					}
				});
			}
		},
		paySuccess: function() {
			var self = this;
			if(self.Param.PayBusiness == 1) { //过户支付
				var wb = BMCW.getWebviewById(BMCW.routeCfg.transferlist.id);
				if(wb) {
					wb.evalJS("page.getCommonList()");
				}

				BMCW.openWindow(BMCW.routeCfg.transferlist, {
					extras: {
						RegTransferID: 1
					}
				});
			} else if(self.Param.PayBusiness == 2) { //排放标准
				var wb = BMCW.getWebviewById(BMCW.routeCfg.environmental.id);
				if(wb) {
					wb.evalJS("page.showList()");
				}
				BMCW.closeWebview(BMCW.routeCfg.payment.id);
			}
		}
	});

	//实例化类
	window.page = new BMCW.BasePage();

})(mui, BMCW);