(function($, BMCW) {
	"use strict";

	BMCW.augment(BMCW.BasePage, {
		/**
		 * 页面路由
		 */
		Route: {
			AddRegTransfer: "/RegTransfer/AddRegTransfer",
			GetRegTransfer: "/RegTransfer/GetRegTransfer",
			GetNoticeByCarOfficeAndBizType: "/Common/GetNoticeByCarOfficeAndBizType", //获取注意事项
			UpdateRegTransferStatus: "/RegTransfer/UpdateRegTransferStatus",
			GetRegTransferPrice: "/RegTransfer/GetRegTransferPrice"
		},
		/**
		 * 参数
		 */
		Param: {
			Data: {
				BizTypeID: 0, //预约业务类型ID
				SettleProvince: 0, //落户省份
				SettleCity: 0 //落户城市
			},
			MasterID: 1, //主类型
			MasterName: '', //主类型名称
			LocationID: 0, //当前登陆人城市
			RegTransferID: 0 //过户信息ID
		},
		/**
		 * 初始化方法
		 * 页面参数初始化  页面方法初始化  等
		 * @param {Object} options
		 */
		init: function(options) {
			var self = this,
				wb = plus.webview.currentWebview();
			self.Param.MasterID = wb.MasterID;
			self.Param.MasterName = wb.MasterName;
			self.Param.RegTransferID = wb.RegTransferID || 0;
			self.Param.LocationID = BMCW.getLocalStorage("LocationID");

			mui.init({
				swipeBack: true //启用右滑关闭功能
			});

			//如果外迁 显示落户城市
			if(wb.BizTypeID) {
				self.Param.Data.BizTypeID = wb.BizTypeID;
				if(wb.BizTypeID == 58) {
					document.getElementById("li_settlecity").style.display = "";
				}
			}
			if(wb.BizTypeName) {
				document.getElementById("span_biztypename").innerHTML = wb.BizTypeName;
			}

		},
		/**
		 * 事件绑定
		 * @param {Object} options
		 */
		initEvent: function(options) {
			var self = this;

			//省份城市选择
			var cityPicker = new $.PopPicker({
				layer: 2
			});
			cityPicker.setData(cityJson);
			var showCityPickerButton = document.getElementById('li_settlecity');
			//选择办理业务
			showCityPickerButton.addEventListener("tap", function() {
				cityPicker.show(function(items) {
					self.Param.Data.SettleProvince = items[0].value;
					self.Param.Data.SettleCity = items[1].value;
					document.getElementById("cityResult").innerText = items[0].text + " " + items[1].text;
					document.getElementById("cityResult").classList.remove('bjcg-high-color');
				});
			}, false);

			//选择车管所
			document.getElementById("li_selectcaroffice").addEventListener("tap", function() {
				if(self.Param.Data.BizTypeID && self.Param.Data.BizTypeID > 0) {
					self.selectCarOffice.call(self);
				} else {
					BMCW.toast("请选择办理业务");
					return false;
				}
			}, false);

			//选择卖方信息
			document.getElementById("a_selectseller").addEventListener("tap", function() {
				self.selectSeller.call(self);
			}, false);

			//选择买方信息
			document.getElementById("a_selectbuyer").addEventListener("tap", function() {
				self.selectBuyer.call(self);
			}, false);

			//选择车辆信息
			document.getElementById("a_selectcar").addEventListener("tap", function() {
				self.selectCar.call(self);
			}, false);

			//提交
			document.getElementById("btn_sure").addEventListener("tap", function() {
				if(!BMCW.checkUserAuth()) {
					BMCW.toast('请到[我的]-[实名认证]进行认证');
					return false;
				}
				self.beforeSubmit.call(self);

			}, false);
		},
		/**
		 * 渲染页面
		 * 通过ajax对页面加载显示
		 * @param {Object} options
		 */
		initView: function(options) {
			var self = this;

			if(self.Param.RegTransferID > 0) {
				BMCW.Ajax.ajax({
					url: self.Route.GetRegTransfer,
					showLoading: false,
					data: {
						regTransferID: self.Param.RegTransferID
					},
					success: function(rdata) {
						if(rdata.status == 0) {
							self.Param.Data = rdata.data[0];
							self.renderView(rdata.data[0]);

						} else {
							BMCW.toast(rdata.message);
						}
					}
				});
			}
		},
		renderView: function(data) {
			var self = this;
			//外迁显示城市
			if(data.BizTypeID == 58) {
				document.getElementById("li_settlecity").style.display = "";
				document.getElementById("cityResult").innerHTML = data.ProvinceName + ' ' + data.CityName;
				document.getElementById("cityResult").classList.remove('bjcg-high-color');
			}
			document.getElementById("span_biztypename").innerHTML = data.BizTypeName;
			document.getElementById("span_SellerName").innerHTML = data.SellerName;
			document.getElementById("span_SellerName").classList.remove('bjcg-high-color');
			document.getElementById("span_BuyerName").innerHTML = data.BuyerName;
			document.getElementById("span_BuyerName").classList.remove('bjcg-high-color');
			document.getElementById("span_CarName").innerHTML = "车辆照片已上传";
			document.getElementById("span_CarName").classList.remove('bjcg-high-color');
			document.getElementById("span_selectedcaroffice").innerHTML = data.Name;
			document.getElementById("span_selectedcaroffice").classList.remove('bjcg-high-color');
			//支付过的不需要再次支付
			if(data.RegStatus > 1) {
				document.getElementById("btn_sure").innerHTML = "提交审核";
			} else {
				document.getElementById("btn_sure").innerHTML = "立即下单";
			}

			self.getNoticeByCarOfficeAndBizType();
		},
		/**
		 * 选择买方信息
		 */
		selectBuyer: function() {
			var self = this;
			BMCW.openWindow(BMCW.routeCfg.buyer, {
				extras: {
					TransferUserID: self.Param.Data.BuyerID,
					SourcePage: BMCW.routeCfg.transferinvoice.id,
					BizTypeID: self.Param.Data.BizTypeID,
					CallBack: "page.reWriteBuyer"
				}
			});
		},
		/**
		 * 回填买方信息
		 * @param {Object} obj
		 */
		reWriteBuyer: function(obj) {
			var self = this;
			self.Param.Data.BuyerID = obj.TransferUserID;
			self.Param.Data.DealPrice = parseFloat(obj.DealPrice);
			document.getElementById("span_BuyerName").innerHTML = obj.TransferUserName;
			document.getElementById("span_BuyerName").classList.remove('bjcg-high-color');
		},
		/**
		 * 选择卖方信息
		 */
		selectSeller: function() {
			var self = this;
			BMCW.openWindow(BMCW.routeCfg.seller, {
				extras: {
					TransferUserID: self.Param.Data.SellerID,
					SourcePage: BMCW.routeCfg.transferinvoice.id,
					BizTypeID: self.Param.Data.BizTypeID,
					CallBack: "page.reWriteSeller"
				}
			});
		},
		/**
		 * 回填卖方信息
		 * @param {Object} obj
		 */
		reWriteSeller: function(obj) {
			var self = this;
			self.Param.Data.SellerID = obj.TransferUserID;
			document.getElementById("span_SellerName").innerHTML = obj.TransferUserName;
			document.getElementById("span_SellerName").classList.remove('bjcg-high-color');
		},
		/**
		 * 选择车辆信息
		 */
		selectCar: function() {
			var self = this;
			BMCW.openWindow(BMCW.routeCfg.car, {
				extras: {
					TransferCarID: self.Param.Data.CarID,
					SourcePage: BMCW.routeCfg.transferinvoice.id,
					CallBack: "page.reWriteCar"
				}
			});
		},
		/**
		 * 回填车辆信息
		 * @param {Object} obj
		 */
		reWriteCar: function(obj) {
			var self = this;
			self.Param.Data.CarID = obj.TransferCarID;
			document.getElementById("span_CarName").innerHTML = "车辆照片已上传";
			document.getElementById("span_CarName").classList.remove('bjcg-high-color');
		},
		/**
		 * 提交前验证
		 */
		beforeSubmit: function() {
			var self = this;

			self.Param.Data.RegisterUserID = BMCW.getLocalStorage("CurrentUserID");

			if(self.Param.Data.BizTypeID == 58) {
				if(BMCW.isNullOrEmpty(self.Param.Data.SettleCity)) {
					BMCW.toast("请选择落户城市");
					return false;
				}
			}

			if(BMCW.isNullOrEmpty(self.Param.Data.RegOfficeID)) {
				BMCW.toast("请选择取票地点");
				return false;
			}

			if(self.Param.Data.PayPrice && self.Param.Data.PayPrice != 0) {} else {
				BMCW.toast('暂未开通过户');
				return false;
			}

			if(BMCW.isNullOrEmpty(self.Param.Data.SellerID)) {
				BMCW.toast("请选择卖方信息");
				return false;
			}

			if(BMCW.isNullOrEmpty(self.Param.Data.BuyerID)) {
				BMCW.toast("请选择买方信息");
				return false;
			}
			if(BMCW.isNullOrEmpty(self.Param.Data.CarID)) {
				BMCW.toast("请选择车辆信息");
				return false;
			}

			self.addTransfer();
		},
		addTransfer: function() {
			var self = this;

			if(self.Param.RegTransferID > 0) {
				BMCW.Ajax.ajax({
					url: self.Route.UpdateRegTransferStatus,
					type: "POST",
					data: {
						RegTransferID: self.Param.RegTransferID,
						PayStatus: 2,
						RegStatus: 2
					},
					success: function(rdata) {
						if(rdata.status == 0) {
							BMCW.closeWebview(BMCW.routeCfg.transferinvoice.id);
						} else {
							BMCW.toast(rdata.message);
						}
					}
				});

			} else {
				BMCW.Ajax.ajax({
					url: self.Route.AddRegTransfer,
					type: "POST",
					data: self.Param.Data,
					success: function(rdata) {
						if(rdata.status == 0) {
							BMCW.openWindow(BMCW.routeCfg.transfersuccess, {
								extras: {
									RegTransferID: rdata.data
								}
							});
						} else {
							BMCW.toast(rdata.message);
						}
					}
				});
			}
		},
		/**
		 * 选择车管所
		 */
		selectCarOffice: function() {
			var self = this;
			BMCW.openWindow(BMCW.routeCfg.carofficesearch, {
				extras: {
					BizTypeID: self.Param.Data.BizTypeID,
					OfficeID: self.Param.Data.RegOfficeID,
					LocationID: self.Param.LocationID,
					SourcePage: BMCW.routeCfg.transferinvoice.id,
					CallBack: "page.reWriteCarOffice"
				}
			});
		},
		/**
		 * 回填车管所返回值
		 * @param {Object} obj
		 */
		reWriteCarOffice: function(obj) {
			var self = this;
			self.Param.Data.RegOfficeID = obj.OfficeID;
			self.Param.ExtData = obj;
			//显示已选
			document.getElementById("span_selectedcaroffice").innerHTML = obj.Name;
			document.getElementById("span_selectedcaroffice").classList.remove("bjcg-high-color");

			self.getNoticeByCarOfficeAndBizType();
			self.getRegTransferPrice(obj.OfficeID);
		},
		/**
		 * 获取过户金额
		 * @param {Object} officeId
		 */
		getRegTransferPrice: function(officeId) {
			var self = this;
			BMCW.Ajax.ajax({
				url: self.Route.GetRegTransferPrice,
				showLoading: false,
				data: {
					mobile: BMCW.getLocalStorage("CurrentUserMobile"),
					regOfficeId: officeId
				},
				success: function(rdata) {
					if(rdata.status == 0) {
						if(BMCW.isNullOrEmpty(rdata.data) || rdata.data == "0") {
							BMCW.toast(rdata.message);
							self.Param.Data.PayPrice = 0;
						} else {
							self.Param.Data.PayPrice = rdata.data;
						}
					} else {
						BMCW.toast(rdata.message);
					}
				}
			});
		},
		/**
		 * 获取注意事项
		 */
		getNoticeByCarOfficeAndBizType: function() {
			var self = this;

			BMCW.Ajax.ajax({
				url: self.Route.GetNoticeByCarOfficeAndBizType,
				showLoading: false,
				data: {
					officeID: self.Param.Data.RegOfficeID,
					bizTypeID: self.Param.Data.BizTypeID
				},
				success: function(rdata) {
					if(rdata.status == 0) {
						console.log(rdata.data)
						document.getElementById("div_Procedure").innerHTML = rdata.data.Procedure || "";
						document.getElementById("div_NoticeItem").innerHTML = rdata.data.NoticeItem || "";
					}
				}
			});
		}
	});

	//实例化类
	window.page = new BMCW.BasePage();

})(mui, BMCW);