(function($, BMCW) {
	"use strict";

	BMCW.augment(BMCW.BasePage, {
		/**
		 * 页面路由
		 */
		Route: {
			DeleteRegisterInfo: "/RegTransfer/DeleteRegisterInfo", //删除预约
			GetRegisterInfoStatusList: "/RegTransfer/GetRegisterInfoStatusList" //根状态获取列表
		},
		/**
		 * 参数
		 */
		Param: {
			PageIndex: 1, //页码
			PageSize: 10, //页大小
			PageCount: 0, //总数量
			RegStatus: 0, //类型
			SourcePage: "", //来源页面
			CallBack: "" //回调方法
		},
		/**
		 * 初始化方法
		 * 页面参数初始化  页面方法初始化  等
		 * @param {Object} options
		 */
		init: function(options) {
			var self = this,
				wb = plus.webview.currentWebview();
			self.Param.RegStatus = wb.RegStatus || 0;
			self.Param.SourcePage = wb.SourcePage;
			self.Param.CallBack = wb.CallBack;

			mui.init({
				swipeBack: true //启用右滑关闭功能				
			});

			//下拉刷新
			BMCW.setCirclePullToRefresh(function() {
				if(BMCW.getLocalStorage("CurrentUserID") > 0) {
					self.Param.PageIndex = 1;
					self.getCommonList();
				}
			});

			//滑动底部自动分页查询
			document.addEventListener("plusscrollbottom", function() {
				if(self.Param.PageIndex < self.Param.PageCount) {
					self.Param.PageIndex += 1;
					self.getCommonList();
				}
			}, false);
		},
		/**
		 * 事件绑定
		 * @param {Object} options
		 */
		initEvent: function(options) {
			var self = this;
			mui("#ul_register").on("tap", "li", function() {
				var regStatus = this.id.substring(12);
				//点击更多，显示隐藏
				if(regStatus == "-1") {
					var regMore = document.getElementById("div_registermore");
					if(regMore.style.display == "block") {
						regMore.style.display = "none";
					} else {
						regMore.style.display = "block";
					}
					return false;
				}

				document.getElementById("div_registermore").style.display = "none";
				//点击其他状态
				if(this.classList.contains("active")) {
					return false;
				} else {
					self.hideRegister("ul_register");
					self.hideRegister("ul_registermore");
					this.classList.add("active");
					self.Param.PageIndex = 1;
					self.Param.RegStatus = regStatus;
					self.getCommonList.call(self);
				}
			});
			//点击更多
			mui("#ul_registermore").on("tap", "li", function() {
				if(this.classList.contains("active")) {
					document.getElementById("div_registermore").style.display = "none";
					return false;
				} else {
					self.hideRegister("ul_registermore");
					self.hideRegister("ul_register");
					this.classList.add("active");
					self.Param.PageIndex = 1;
					self.Param.RegStatus = this.id.substring(12);
					self.getCommonList.call(self);
					document.getElementById("li_regstatus-1").classList.add("active");
					document.getElementById("div_registermore").style.display = "none";
				}
			});
		},
		/**
		 * 取消选中
		 */
		hideRegister: function(ulcontainer) {
			var chd = document.getElementById(ulcontainer).children;
			for(var i = 0; i < chd.length; i++) {
				if(chd[i].classList.contains("active")) {
					chd[i].classList.remove("active");
					break;
				}
			}
		},
		/**
		 * 渲染页面
		 * 通过ajax对页面加载显示
		 * @param {Object} options
		 */
		initView: function(options) {
			var self = this;

			BMCW.closeWebview(BMCW.routeCfg.transfersuccess.id, "none");
			BMCW.closeWebview(BMCW.routeCfg.payment.id, "none");

			document.getElementById("li_regstatus" + self.Param.RegStatus).classList.add("active");
			self.getCommonList();
		},
		getCommonList: function() {
			var self = this;
			self.GetRegisterInfoStatusList();
		},
		/**
		 * 根据状态获取列表
		 */
		GetRegisterInfoStatusList: function() {
			var self = this;
			BMCW.Ajax.ajax({
				url: self.Route.GetRegisterInfoStatusList,
				data: {
					userID: BMCW.getLocalStorage("CurrentUserID"),
					mobile: BMCW.getLocalStorage("CurrentUserMobile"),
					regStatus: self.Param.RegStatus,
					pageIndex: self.Param.PageIndex,
					pageSize: self.Param.PageSize
				},
				success: function(rdata) {
					if(rdata.status == 0) {
						//如果返回成功,Message赋值总记录数	
						self.renderView(rdata.data, rdata.message);
					} else {
						BMCW.toast(rdata.message);
					}
				}
			});
		},
		/**
		 * 渲染页面
		 * @param {Object} data
		 */
		renderView: function(data, pageCount) {
			var self = this,
				content = document.getElementById("muiContent");

			//如果首页,则清空内容
			if(self.Param.PageIndex == 1) {
				content.innerHTML = "";
				if(data.length < 1) {
					document.getElementById("div_nodata").style.display = "";
				} else {
					document.getElementById("div_nodata").style.display = "none";
				}
			}

			if(data.length > 0) {
				self.Param.PageCount = BMCW.getPageCount(parseInt(pageCount), self.Param.PageSize);

				var tpl = "";
				for(var i = 0; i < data.length; i++) {
					content.innerHTML += self.getTpl(data[i]);
				}

				content.innerHTML += tpl;
			}
		},
		/**
		 * 获取模版
		 */
		getTpl: function(item) {
			var self = this;
			var bittype = item.MasterBizTypeName + '-' + item.BizTypeName;
			var regCode = item.RegCode;
			if(self.Param.RegStatus == 0) {
				regCode = regCode + self.getRegStatusName(item.RegStatus);
			}
			var tpl = '<div class="bjcg-yuyue-item">';
			tpl += '<p onclick="page.registerDetail(' + item.RegTransferID + ');" class="bjcg-yuyue-item-p">订单编号：<span class="bjcg-yuyue-item-p-span">' + regCode + '</span></p>';
			tpl += '<p onclick="page.registerDetail(' + item.RegTransferID + ');" class="bjcg-yuyue-item-p">业务类型：<span class="bjcg-yuyue-item-p-span">' + bittype + '</span></p>';
			tpl += '<p onclick="page.registerDetail(' + item.RegTransferID + ');" class="bjcg-yuyue-item-p">订单时间：<span class="bjcg-yuyue-item-p-span">' + item.CreatedDate + '</span></p>';
			tpl += '<p onclick="page.registerDetail(' + item.RegTransferID + ');" class="bjcg-yuyue-item-p">取票地点：<span class="bjcg-yuyue-item-p-span">' + item.Name + '</span></p>';
			tpl += '<p onclick="page.registerDetail(' + item.RegTransferID + ');" class="bjcg-yuyue-item-p">卖方信息：<span class="bjcg-yuyue-item-p-span">' + item.SellerName + '</span></p>';
			tpl += '<p onclick="page.registerDetail(' + item.RegTransferID + ');" class="bjcg-yuyue-item-p">买方信息：<span class="bjcg-yuyue-item-p-span">' + item.BuyerName + '</span></p>';
			tpl += '<p onclick="page.registerDetail(' + item.RegTransferID + ');" class="bjcg-yuyue-item-p">开票费用：<em class="bjcg-yuyue-item-p-em">￥</em><span class="bjcg-yuyue-item-p-span bjcg-price-highColor">' + item.PayPrice + '</span><em class="bjcg-yuyue-item-p-em">元</em></p>';
			if(item.RegStatus == 1) { //待支付
				tpl += '<a onclick="page.registerEdit(' + item.RegTransferID + ');" class="bjcg-yuyue-item-a-left" href="###"><i class="icon iconfont icon-ai-edit"></i></a>';
				tpl += '<a onclick="page.registerDelete(' + item.RegTransferID + ');" class="bjcg-yuyue-item-a-right" href="###"><i class="icon iconfont icon-shanchu"></i></a>';
				tpl += '<a onclick="page.registerPay(' + item.RegTransferID + ');" class="bjcg-pay-btn" href="###">立即支付</a>';
			} else if(item.RegStatus == 2) { //开票中
				tpl += '<p onclick="page.registerDetail(' + item.RegTransferID + ');" class="bjcg-yuyue-item-p">支付时间：<span class="bjcg-yuyue-item-p-span">' + item.PayDate + '</span></p>';
			} else if(item.RegStatus == 3) { //已出票
				tpl += '<p onclick="page.registerDetail(' + item.RegTransferID + ');" class="bjcg-yuyue-item-p">出票时间：<span class="bjcg-yuyue-item-p-span">' + item.InvoiceDate + '</span></p>';
				tpl += '<p onclick="page.registerDetail(' + item.RegTransferID + ');" class="bjcg-yuyue-item-p">发票号码：<span class="bjcg-yuyue-item-p-span">' + item.InvoiceCode + '</span></p>';
			} else if(item.RegStatus == 4) { //已驳回				
				tpl += '<a onclick="page.registerEdit(' + item.RegTransferID + ');" class="bjcg-yuyue-item-a-right" href="###"><i class="icon iconfont icon-ai-edit"></i></a>';
				tpl += '<p onclick="page.registerDetail(' + item.RegTransferID + ');" class="bjcg-yuyue-item-p">驳回时间：<span class="bjcg-yuyue-item-p-span">' + item.RejectDate + '</span></p>';
				tpl += '<p onclick="page.registerDetail(' + item.RegTransferID + ');" class="bjcg-yuyue-item-p">驳回原因：<span class="bjcg-yuyue-item-p-span">' + item.RejectReason + '</span></p>';
			} else if(item.RegStatus == 5) { //已出票	
				tpl += '<p onclick="page.registerDetail(' + item.RegTransferID + ');" class="bjcg-yuyue-item-p">出票时间：<span class="bjcg-yuyue-item-p-span">' + item.GetInvoiceDate + '</span></p>';
			} else if(item.RegStatus == 6) { //已作废
				tpl += '<p onclick="page.registerDetail(' + item.RegTransferID + ');" class="bjcg-yuyue-item-p">作废时间：<span class="bjcg-yuyue-item-p-span">' + item.InvaliDate + '</span></p>';
				tpl += '<p onclick="page.registerDetail(' + item.RegTransferID + ');" class="bjcg-yuyue-item-p">作废原因：<span class="bjcg-yuyue-item-p-span">' + item.InvaliReason + '</span></p>';
			} else if(item.RegStatus == 7) { //已失败
				tpl += '<p onclick="page.registerDetail(' + item.RegTransferID + ');" class="bjcg-yuyue-item-p">失败时间：<span class="bjcg-yuyue-item-p-span">' + item.GetInvoiceFailDate + '</span></p>';
				tpl += '<p onclick="page.registerDetail(' + item.RegTransferID + ');" class="bjcg-yuyue-item-p">失败原因：<span class="bjcg-yuyue-item-p-span">' + item.GetInvoiceFailReason + '</span></p>';
			}
			tpl += '</div>';
			return tpl;
		},
		/**
		 * 编辑
		 * @param {Object} regId
		 */
		registerEdit: function(regId) {
			var self = this;
			BMCW.openWindow(BMCW.routeCfg.transferinvoice, {
				extras: {
					RegTransferID: regId
				}
			});
		},
		/**
		 * 删除
		 * @param {Object} regId
		 */
		registerDelete: function(regId) {
			var self = this;
			BMCW.confirm("确认删除预约信息?", '<img src="../../../images/bjcg-icon-tip.jpg" alt=""/>', "", function(e) {
				if(e.index == 1) {
					BMCW.Ajax.ajax({
						url: self.Route.DeleteRegisterInfo,
						type: "POST",
						data: {
							Id: regId
						},
						success: function(rdata) {
							if(rdata.status == 0) {
								BMCW.toast("删除成功");
								self.Param.PageIndex = 1;
								self.getCommonList();
							} else {
								BMCW.toast(rdata.message);
							}
						}
					});
				}
			});
		},
		/**
		 * 详情
		 * @param {Object} regId
		 */
		registerDetail: function(regId) {
			var self = this;
			BMCW.openWindow(BMCW.routeCfg.transfersuccess, {
				extras: {
					RegTransferID: regId
				}
			});
		},
		/**
		 * 支付
		 * @param {Object} regId
		 */
		registerPay: function(regId) {
			BMCW.openWindow(BMCW.routeCfg.payment, {
				extras: {
					RegTransferID: regId,
					payPrice: 0,
					PayBusiness: 1, //支付业务类型 
					SourcePage: "RegTransfer"
				}
			});
		},
		/**
		 * 获取名称
		 * @param {Object} regStatus
		 */
		getRegStatusName: function(regStatus) {
			var str = "【未知】";
			switch(regStatus) {
				case 1:
					str = "【待支付】";
					break;
				case 2:
					str = "【开票中】";
					break;
				case 3:
					str = "【已开票】";
					break;
				case 4:
					str = "【驳回】";
					break;
				case 5:
					str = "【已取票】";
					break;
				case 6:
					str = "【已作废】";
					break;
				case 7:
					str = "【取票失败】";
					break;
			}
			return str;
		}
	});

	//实例化类
	window.page = new BMCW.BasePage();

})(mui, BMCW);